/**
 * Copyright (c) 2025 Enzien Audio, Ltd.
 * 
 * Redistribution and use in source and binary forms, with or without modification,
 * are permitted provided that the following conditions are met:
 * 
 * 1. Redistributions of source code must retain the above copyright notice,
 *    this list of conditions, and the following disclaimer.
 * 
 * 2. Redistributions in binary form must reproduce the phrase "powered by heavy",
 *    the heavy logo, and a hyperlink to https://enzienaudio.com, all in a visible
 *    form.
 * 
 *   2.1 If the Application is distributed in a store system (for example,
 *       the Apple "App Store" or "Google Play"), the phrase "powered by heavy"
 *       shall be included in the app description or the copyright text as well as
 *       the in the app itself. The heavy logo will shall be visible in the app
 *       itself as well.
 * 
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO,
 * THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE
 * FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
 * DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR
 * SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER
 * CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
 * OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF
 * THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 * 
 */

#include "Heavy_WSTD_DL3Y.hpp"

#include <new>

#define Context(_c) static_cast<Heavy_WSTD_DL3Y *>(_c)


/*
 * C Functions
 */

extern "C" {
  HV_EXPORT HeavyContextInterface *hv_WSTD_DL3Y_new(double sampleRate) {
    // allocate aligned memory
    void *ptr = hv_malloc(sizeof(Heavy_WSTD_DL3Y));
    // ensure non-null
    if (!ptr) return nullptr;
    // call constructor
    new(ptr) Heavy_WSTD_DL3Y(sampleRate);
    return Context(ptr);
  }

  HV_EXPORT HeavyContextInterface *hv_WSTD_DL3Y_new_with_options(double sampleRate,
      int poolKb, int inQueueKb, int outQueueKb) {
    // allocate aligned memory
    void *ptr = hv_malloc(sizeof(Heavy_WSTD_DL3Y));
    // ensure non-null
    if (!ptr) return nullptr;
    // call constructor
    new(ptr) Heavy_WSTD_DL3Y(sampleRate, poolKb, inQueueKb, outQueueKb);
    return Context(ptr);
  }

  HV_EXPORT void hv_WSTD_DL3Y_free(HeavyContextInterface *instance) {
    // call destructor
    Context(instance)->~Heavy_WSTD_DL3Y();
    // free memory
    hv_free(instance);
  }
} // extern "C"







/*
 * Class Functions
 */

Heavy_WSTD_DL3Y::Heavy_WSTD_DL3Y(double sampleRate, int poolKb, int inQueueKb, int outQueueKb)
    : HeavyContext(sampleRate, poolKb, inQueueKb, outQueueKb) {
  numBytes += sLine_init(&sLine_g1Eeh1gB);
  numBytes += sLine_init(&sLine_dRMCKDYR);
  numBytes += sLine_init(&sLine_T2Ni0VT3);
  numBytes += sLine_init(&sLine_gwJwwESa);
  numBytes += sLine_init(&sLine_8J90UdGH);
  numBytes += sBiquad_init(&sBiquad_s_NLEtRWeG);
  numBytes += sLine_init(&sLine_6UHbdru9);
  numBytes += sLine_init(&sLine_bUbxW5n0);
  numBytes += sLine_init(&sLine_JPZ6pEbB);
  numBytes += sLine_init(&sLine_kAour652);
  numBytes += sBiquad_init(&sBiquad_s_frfqAQD7);
  numBytes += sLine_init(&sLine_JSwJ1phT);
  numBytes += sLine_init(&sLine_NglVKMHx);
  numBytes += sLine_init(&sLine_fIqxGAS9);
  numBytes += sLine_init(&sLine_FHBvJrMg);
  numBytes += sLine_init(&sLine_ud6Hyy69);
  numBytes += sBiquad_init(&sBiquad_s_dSGD5xHe);
  numBytes += sLine_init(&sLine_HfB4ww6h);
  numBytes += sLine_init(&sLine_P76tzSnX);
  numBytes += sLine_init(&sLine_IZDVhOxw);
  numBytes += sLine_init(&sLine_ddG77Yei);
  numBytes += sLine_init(&sLine_kqeAIo9A);
  numBytes += sBiquad_init(&sBiquad_s_SEXiaiVy);
  numBytes += sLine_init(&sLine_cOlEPnXL);
  numBytes += sLine_init(&sLine_JCe7ynWW);
  numBytes += sLine_init(&sLine_eczXoPdH);
  numBytes += sLine_init(&sLine_K1qlTqpL);
  numBytes += sBiquad_init(&sBiquad_s_JpYHwG6u);
  numBytes += sLine_init(&sLine_aa567uGa);
  numBytes += sLine_init(&sLine_UnkWnMXA);
  numBytes += sLine_init(&sLine_CzVHHzoo);
  numBytes += sLine_init(&sLine_cxRAF4cy);
  numBytes += sLine_init(&sLine_mm6FaRHO);
  numBytes += sBiquad_init(&sBiquad_s_lao49dND);
  numBytes += sLine_init(&sLine_eLFeYyxW);
  numBytes += sTabread_init(&sTabread_OvheTdEZ, &hTable_SuvEmq1G, true);
  numBytes += sLine_init(&sLine_euBMhtLL);
  numBytes += sLine_init(&sLine_RbaTnMnt);
  numBytes += sTabread_init(&sTabread_8ctWDKfL, &hTable_AFV9N3XC, true);
  numBytes += sLine_init(&sLine_hPgrwyT6);
  numBytes += sRPole_init(&sRPole_aaMuvHMy);
  numBytes += sDel1_init(&sDel1_IbnpKMBv);
  numBytes += sTabwrite_init(&sTabwrite_s0NMdATY, &hTable_SuvEmq1G);
  numBytes += sRPole_init(&sRPole_tnEYFDVv);
  numBytes += sDel1_init(&sDel1_ycaVuyAu);
  numBytes += sTabwrite_init(&sTabwrite_lvfmg2UE, &hTable_AFV9N3XC);
  numBytes += sLine_init(&sLine_OwNXV51q);
  numBytes += sLine_init(&sLine_G1Bc92pM);
  numBytes += sRPole_init(&sRPole_lY5EPS25);
  numBytes += sEnv_init(&sEnv_SwBoBkWr, 1024, 512);
  numBytes += sRPole_init(&sRPole_L5uNfqq9);
  numBytes += sLine_init(&sLine_vdZxpvBo);
  numBytes += sLine_init(&sLine_JRRCuPP3);
  numBytes += sRPole_init(&sRPole_nXld12uL);
  numBytes += sEnv_init(&sEnv_0GawZaWN, 1024, 512);
  numBytes += sRPole_init(&sRPole_noyK0DU5);
  numBytes += sLine_init(&sLine_UlqhqerW);
  numBytes += sTabread_init(&sTabread_b1wGD1vP, &hTable_Fi71Gc3J, true);
  numBytes += sLine_init(&sLine_muo0BVHG);
  numBytes += sLine_init(&sLine_t1mUprca);
  numBytes += sTabread_init(&sTabread_4cuL5DVh, &hTable_GuCIDNfd, true);
  numBytes += sLine_init(&sLine_oVRlatCU);
  numBytes += sRPole_init(&sRPole_cs0Qpin6);
  numBytes += sDel1_init(&sDel1_iQAiFrXd);
  numBytes += sTabwrite_init(&sTabwrite_x8DvrhQE, &hTable_Fi71Gc3J);
  numBytes += sRPole_init(&sRPole_lzswIGnQ);
  numBytes += sDel1_init(&sDel1_rcLM0Ghv);
  numBytes += sTabwrite_init(&sTabwrite_fflxi6Am, &hTable_GuCIDNfd);
  numBytes += sLine_init(&sLine_2v2GHjZf);
  numBytes += sLine_init(&sLine_Tt7JyTOM);
  numBytes += sRPole_init(&sRPole_UnYXAxfa);
  numBytes += sEnv_init(&sEnv_uJDcVDjK, 1024, 512);
  numBytes += sRPole_init(&sRPole_GUXcdVuZ);
  numBytes += sLine_init(&sLine_uvhU7sbN);
  numBytes += sLine_init(&sLine_8EwDxbaK);
  numBytes += sRPole_init(&sRPole_0rKIX4pY);
  numBytes += sEnv_init(&sEnv_ja9lRYb7, 1024, 512);
  numBytes += sRPole_init(&sRPole_qYDgP8Sf);
  numBytes += sLine_init(&sLine_ATUTJXY6);
  numBytes += sTabread_init(&sTabread_Q6OSucNZ, &hTable_oZ36avfO, true);
  numBytes += sLine_init(&sLine_Ow5hPZrK);
  numBytes += sLine_init(&sLine_ssh1ghQY);
  numBytes += sTabread_init(&sTabread_tH4bhOve, &hTable_nEj2Ecly, true);
  numBytes += sLine_init(&sLine_3GArsV0h);
  numBytes += sRPole_init(&sRPole_0oEwLLmh);
  numBytes += sDel1_init(&sDel1_f7rrKIHA);
  numBytes += sTabwrite_init(&sTabwrite_S3IcX84y, &hTable_oZ36avfO);
  numBytes += sRPole_init(&sRPole_BgG4PXsF);
  numBytes += sDel1_init(&sDel1_Jr9Eb9lB);
  numBytes += sTabwrite_init(&sTabwrite_KKGLprdo, &hTable_nEj2Ecly);
  numBytes += sLine_init(&sLine_Qzr4di1X);
  numBytes += sLine_init(&sLine_QahjCNHW);
  numBytes += sRPole_init(&sRPole_NBnWi4tZ);
  numBytes += sEnv_init(&sEnv_bJMBGZcx, 1024, 512);
  numBytes += sRPole_init(&sRPole_cU4dtgDg);
  numBytes += sLine_init(&sLine_NLvvwlFB);
  numBytes += sLine_init(&sLine_fqNIJPDm);
  numBytes += sRPole_init(&sRPole_0EO40lMc);
  numBytes += sEnv_init(&sEnv_njcGyCDv, 1024, 512);
  numBytes += sRPole_init(&sRPole_7xAjvKYI);
  numBytes += cVar_init_f(&cVar_D8WmDR5Z, 0.0f);
  numBytes += cVar_init_f(&cVar_0SWLibYN, 0.0f);
  numBytes += cVar_init_f(&cVar_Iml1QuDm, 0.0f);
  numBytes += cVar_init_f(&cVar_w56Lrt0V, 0.0f);
  numBytes += cSlice_init(&cSlice_U1T2XEDz, 1, -1);
  numBytes += cVar_init_f(&cVar_JiXHpUmq, 1337.0f);
  numBytes += cVar_init_f(&cVar_6t0wcwI8, 0.0f);
  numBytes += cIf_init(&cIf_M90bXtyH, false);
  numBytes += cIf_init(&cIf_1OFWsYww, false);
  numBytes += cBinop_init(&cBinop_tiX0Tdg5, 0.0f); // __pow
  numBytes += cIf_init(&cIf_JGCm9BOC, false);
  numBytes += cBinop_init(&cBinop_zYS940yW, 0.0f); // __add
  numBytes += cBinop_init(&cBinop_1OyEuo5k, -15.0f); // __gt
  numBytes += cBinop_init(&cBinop_ZXmuPMYo, -15.0f); // __eq
  numBytes += cVar_init_f(&cVar_zGSZ7uMm, 0.0f);
  numBytes += cIf_init(&cIf_mWkmsJbe, false);
  numBytes += cIf_init(&cIf_VteytaCr, false);
  numBytes += cBinop_init(&cBinop_hJ19LTS7, 0.0f); // __pow
  numBytes += cIf_init(&cIf_BWZKkQl3, false);
  numBytes += cBinop_init(&cBinop_k2RCT9fa, 0.0f); // __add
  numBytes += cBinop_init(&cBinop_HTNiYJlC, -15.0f); // __gt
  numBytes += cBinop_init(&cBinop_8AYimfm4, -15.0f); // __eq
  numBytes += cVar_init_f(&cVar_IxYd8BZY, 0.0f);
  numBytes += cIf_init(&cIf_L3ySP92G, false);
  numBytes += cIf_init(&cIf_kiJRaDZM, false);
  numBytes += cBinop_init(&cBinop_PI5rZEol, 0.0f); // __pow
  numBytes += cIf_init(&cIf_6kZ9ov1P, false);
  numBytes += cBinop_init(&cBinop_Qh2OP8xu, 0.0f); // __add
  numBytes += cBinop_init(&cBinop_mBswZg7F, -15.0f); // __gt
  numBytes += cBinop_init(&cBinop_txrJ61Nw, -15.0f); // __eq
  numBytes += cIf_init(&cIf_4bTJu7xk, false);
  numBytes += cSlice_init(&cSlice_iNjvW6zo, 1, -1);
  numBytes += cVar_init_f(&cVar_H1z8FLjH, 0.0f);
  numBytes += cSlice_init(&cSlice_r9LHDk23, 1, -1);
  numBytes += cVar_init_f(&cVar_h2BeBiec, 0.0f);
  numBytes += cSlice_init(&cSlice_aCxpw9uu, 1, -1);
  numBytes += cVar_init_f(&cVar_R87ErOZK, 0.0f);
  numBytes += cSlice_init(&cSlice_tQV4mzJh, 1, -1);
  numBytes += cVar_init_f(&cVar_3tjMy5FY, 0.313f);
  numBytes += cBinop_init(&cBinop_DhORTnFN, 44100.0f); // __div
  numBytes += cBinop_init(&cBinop_tTpc95xN, 0.0f); // __mul
  numBytes += cVar_init_f(&cVar_zMxyefE5, 0.0f);
  numBytes += cVar_init_f(&cVar_S2FnHzAa, 1337.0f);
  numBytes += cVar_init_f(&cVar_r44Fcpob, 0.3f);
  numBytes += cBinop_init(&cBinop_5qxKnxfz, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_BBO61ard, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_n9yuKD95, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_SXV6z1e3, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_bMFR8cUe, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_CuIcq5Gl, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_HfS3BPCE, 44100.0f); // __div
  numBytes += cBinop_init(&cBinop_qJmMMunC, 0.0f); // __mul
  numBytes += cVar_init_f(&cVar_PNsv2zpf, 0.0f);
  numBytes += cVar_init_f(&cVar_KdNlQHS7, 1337.0f);
  numBytes += cVar_init_f(&cVar_AHtzyZMg, 0.313f);
  numBytes += cBinop_init(&cBinop_bm2cUtUi, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_YvRWZlM4, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_QC3grlgC, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_oirWykH2, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_hqoDmNwm, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_kh7c9ofh, 44100.0f); // __div
  numBytes += cBinop_init(&cBinop_CHxY5us4, 0.0f); // __mul
  numBytes += cVar_init_f(&cVar_x1KRpgEx, 0.0f);
  numBytes += cVar_init_f(&cVar_xwHJrqs3, 1037.0f);
  numBytes += cVar_init_f(&cVar_lKtwe9o7, 0.4f);
  numBytes += cBinop_init(&cBinop_JWftv52H, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_fhG4unvs, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_aQpvluoe, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_AgQ3wfAS, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_sGCv4nUW, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_ccucuBVU, 0.0f); // __mul
  numBytes += sVarf_init(&sVarf_U6X8BmkL, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_viQfCm71, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_dBidPBLo, 0.0f, 0.0f, false);
  numBytes += cSlice_init(&cSlice_E4bM5iKW, 1, -1);
  numBytes += cVar_init_f(&cVar_zFFsgIX5, 1337.0f);
  numBytes += cVar_init_f(&cVar_sxS9dKVH, 0.0f);
  numBytes += cIf_init(&cIf_7cmenJaz, false);
  numBytes += cIf_init(&cIf_96ObpMgo, false);
  numBytes += cBinop_init(&cBinop_tqb0TFV1, 0.0f); // __pow
  numBytes += cIf_init(&cIf_MZ8aoq6N, false);
  numBytes += cBinop_init(&cBinop_H5zEtxvj, 0.0f); // __add
  numBytes += cBinop_init(&cBinop_zJnpuH61, -15.0f); // __gt
  numBytes += cBinop_init(&cBinop_2k6gY18S, -15.0f); // __eq
  numBytes += cVar_init_f(&cVar_zo4jBNa3, 0.0f);
  numBytes += cIf_init(&cIf_jjHY2q1Z, false);
  numBytes += cIf_init(&cIf_aSpSwsTX, false);
  numBytes += cBinop_init(&cBinop_5Izq9MTd, 0.0f); // __pow
  numBytes += cIf_init(&cIf_m448xVDZ, false);
  numBytes += cBinop_init(&cBinop_9WbtpD27, 0.0f); // __add
  numBytes += cBinop_init(&cBinop_URMkwB4c, -15.0f); // __gt
  numBytes += cBinop_init(&cBinop_gQHZNbFK, -15.0f); // __eq
  numBytes += cVar_init_f(&cVar_N8VtPLd8, 0.0f);
  numBytes += cIf_init(&cIf_qJulZYwT, false);
  numBytes += cIf_init(&cIf_9b1B416r, false);
  numBytes += cBinop_init(&cBinop_BGbTixHb, 0.0f); // __pow
  numBytes += cIf_init(&cIf_pvDccJ1I, false);
  numBytes += cBinop_init(&cBinop_ROIfKv89, 0.0f); // __add
  numBytes += cBinop_init(&cBinop_SjmRLhJO, -15.0f); // __gt
  numBytes += cBinop_init(&cBinop_y1CpaR9W, -15.0f); // __eq
  numBytes += cIf_init(&cIf_N2LeJ6tw, false);
  numBytes += cSlice_init(&cSlice_xIVYbaiM, 1, -1);
  numBytes += cVar_init_f(&cVar_k9O3uvFI, 0.0f);
  numBytes += cSlice_init(&cSlice_w6byAorp, 1, -1);
  numBytes += cVar_init_f(&cVar_MFUbvpCs, 0.0f);
  numBytes += cSlice_init(&cSlice_6kojTXGF, 1, -1);
  numBytes += cVar_init_f(&cVar_w6tysDjU, 0.0f);
  numBytes += cSlice_init(&cSlice_hGeA24cO, 1, -1);
  numBytes += cVar_init_f(&cVar_0F1J0yQb, 0.313f);
  numBytes += cBinop_init(&cBinop_Tp8iJH74, 44100.0f); // __div
  numBytes += cBinop_init(&cBinop_EtFfvuHE, 0.0f); // __mul
  numBytes += cVar_init_f(&cVar_MC5wrDz1, 0.0f);
  numBytes += cVar_init_f(&cVar_AESlzgvs, 1337.0f);
  numBytes += cVar_init_f(&cVar_Ib83oeb5, 0.3f);
  numBytes += cBinop_init(&cBinop_Dh2xty4y, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_hFgrWqei, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_QFECBR5x, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_nuSHHzV0, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_2Mnuq0GL, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_QE8DiOGa, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_e8NWAyBw, 44100.0f); // __div
  numBytes += cBinop_init(&cBinop_m6GiX6bD, 0.0f); // __mul
  numBytes += cVar_init_f(&cVar_xVD1HWdo, 0.0f);
  numBytes += cVar_init_f(&cVar_15keEgoi, 1337.0f);
  numBytes += cVar_init_f(&cVar_KNbhaNdW, 0.313f);
  numBytes += cBinop_init(&cBinop_PI85FqLh, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_1GqZGE1O, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_2MRoimdR, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_zomzDO1d, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_qzX4EgwF, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_vb5u4tKk, 44100.0f); // __div
  numBytes += cBinop_init(&cBinop_ITmgD6O1, 0.0f); // __mul
  numBytes += cVar_init_f(&cVar_0kzTP1Nj, 0.0f);
  numBytes += cVar_init_f(&cVar_6yCMuDdD, 1037.0f);
  numBytes += cVar_init_f(&cVar_Snwo4J33, 0.4f);
  numBytes += cBinop_init(&cBinop_RusIjfmo, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_EmcqZM1z, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_nvmfBnWe, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_B9cObZUZ, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_1MlXChJO, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_BtCIuCKq, 0.0f); // __mul
  numBytes += sVarf_init(&sVarf_F5JT6qfq, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_N6VtI5QJ, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_Zu64IzXV, 0.0f, 0.0f, false);
  numBytes += cVar_init_f(&cVar_gXNwFj6J, 5705.6f);
  numBytes += cVar_init_f(&cVar_NiA5OsPT, 313.3f);
  numBytes += cBinop_init(&cBinop_Xngz0Bhp, 0.0f); // __div
  numBytes += cBinop_init(&cBinop_V4kMugRJ, 0.0f); // __div
  numBytes += cBinop_init(&cBinop_jRidER1c, 0.0f); // __div
  numBytes += cVar_init_f(&cVar_01QURJwf, 0.0f);
  numBytes += cVar_init_f(&cVar_hA54wfHY, 0.0f);
  numBytes += cVar_init_f(&cVar_o2G2AgAP, 0.0f);
  numBytes += cVar_init_f(&cVar_CFsMZjiS, 0.0f);
  numBytes += cVar_init_f(&cVar_QQdUhnd1, 0.0f);
  numBytes += cVar_init_f(&cVar_FiWHpum8, 0.0f);
  numBytes += cVar_init_f(&cVar_o7IHboxy, 0.0f);
  numBytes += cVar_init_f(&cVar_0us5sJa8, 0.0f);
  numBytes += cVar_init_f(&cVar_DCV0EudC, 0.0f);
  numBytes += cVar_init_f(&cVar_igTw5lsY, 0.0f);
  numBytes += cVar_init_f(&cVar_zIqMPq9n, 0.0f);
  numBytes += cVar_init_f(&cVar_XFPMxAe8, 0.0f);
  numBytes += cSlice_init(&cSlice_UFTbYkUS, 1, -1);
  numBytes += cVar_init_f(&cVar_n68XL8JM, 0.5f);
  numBytes += cSlice_init(&cSlice_vthgGoXI, 1, -1);
  numBytes += cVar_init_f(&cVar_wuegmjRK, 0.2f);
  numBytes += cSlice_init(&cSlice_pS3FmVA8, 1, -1);
  numBytes += cVar_init_f(&cVar_OQKpa1tm, 500.0f);
  numBytes += sVarf_init(&sVarf_xEsqNN4C, 0.0f, 0.0f, false);
  numBytes += cVar_init_f(&cVar_dmzwSFPG, 600.0f);
  numBytes += cBinop_init(&cBinop_gYAJuBq5, 0.0f); // __div
  numBytes += sVarf_init(&sVarf_3iu4WzHj, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_dl1kc3ny, 0.0f, 0.0f, false);
  numBytes += cVar_init_f(&cVar_uBowDlEC, 600.0f);
  numBytes += cBinop_init(&cBinop_9W1DrDYl, 0.0f); // __div
  numBytes += sVarf_init(&sVarf_k6pZXZGP, 0.0f, 0.0f, false);
  numBytes += cVar_init_f(&cVar_866JjA7K, 4000.0f);
  numBytes += cBinop_init(&cBinop_e3rbAcTT, 0.0f); // __mul
  numBytes += sVarf_init(&sVarf_dUh8nEid, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_uBA11AWp, 0.0f, 0.0f, false);
  numBytes += cVar_init_f(&cVar_TKACTgDx, 4000.0f);
  numBytes += cBinop_init(&cBinop_gnClQd7V, 0.0f); // __mul
  numBytes += sVarf_init(&sVarf_nTEgW7ey, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_ffUJFP7F, 0.0f, 0.0f, false);
  numBytes += cIf_init(&cIf_8WLQE0LY, false);
  numBytes += cBinop_init(&cBinop_dsdvZHBO, 0.0f); // __pow
  numBytes += cVar_init_f(&cVar_hCsFva0g, 20.0f);
  numBytes += cBinop_init(&cBinop_zIalCAqA, 0.0f); // __mul
  numBytes += sVarf_init(&sVarf_XqzjSTPr, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_jlEX39WW, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_yby2x6zV, 0.0f, 0.0f, false);
  numBytes += cIf_init(&cIf_sXHcUQJA, false);
  numBytes += cBinop_init(&cBinop_W4FFXJfj, 0.0f); // __pow
  numBytes += cVar_init_f(&cVar_g4lwAWIL, 20.0f);
  numBytes += cBinop_init(&cBinop_Phahznev, 0.0f); // __mul
  numBytes += sVarf_init(&sVarf_l5xzyGnw, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_xWHUFUGs, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_hOdtiHRZ, 0.0f, 0.0f, false);
  numBytes += cSlice_init(&cSlice_0VJ2ALSo, 1, -1);
  numBytes += cVar_init_f(&cVar_sZ8JogDs, 0.25f);
  numBytes += cDelay_init(this, &cDelay_jLNF7Qu1, 0.0f);
  numBytes += cDelay_init(this, &cDelay_K94inu2k, 0.0f);
  numBytes += hTable_init(&hTable_SuvEmq1G, 256);
  numBytes += cTabhead_init(&cTabhead_ZKU1HCrI, &hTable_SuvEmq1G);
  numBytes += cVar_init_s(&cVar_x88GL5B8, "del-1349-delayL");
  numBytes += cDelay_init(this, &cDelay_OxweR9Dr, 0.0f);
  numBytes += cDelay_init(this, &cDelay_ocuU38jM, 0.0f);
  numBytes += cBinop_init(&cBinop_rAooRakH, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_LTBHBXMM, 0.0f); // __sub
  numBytes += cBinop_init(&cBinop_NQGDeH9r, 0.0f); // __max
  numBytes += cBinop_init(&cBinop_IJOrmDGy, 0.0f); // __sub
  numBytes += cDelay_init(this, &cDelay_HUy58zph, 0.0f);
  numBytes += cDelay_init(this, &cDelay_Du2uwtV5, 0.0f);
  numBytes += hTable_init(&hTable_AFV9N3XC, 256);
  numBytes += cTabhead_init(&cTabhead_hZDFpjvk, &hTable_AFV9N3XC);
  numBytes += cVar_init_s(&cVar_YFi9AuHy, "del-1349-delayR");
  numBytes += cDelay_init(this, &cDelay_MSZfvriF, 0.0f);
  numBytes += cDelay_init(this, &cDelay_bmcB2JoE, 0.0f);
  numBytes += cBinop_init(&cBinop_i1MXaYwS, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_E40b8Nme, 0.0f); // __sub
  numBytes += cBinop_init(&cBinop_5FMXdMW3, 0.0f); // __max
  numBytes += cBinop_init(&cBinop_6Yv1l92u, 0.0f); // __sub
  numBytes += sVarf_init(&sVarf_NVhxYz17, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_hKKheQna, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_gSHCHyqD, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_iYK4SP5L, 0.0f, 0.0f, false);
  numBytes += cSlice_init(&cSlice_n1ayCBk0, 1, -1);
  numBytes += cVar_init_f(&cVar_Fw0TLtxH, 0.5f);
  numBytes += cSlice_init(&cSlice_Yp0WgIeG, 1, -1);
  numBytes += cVar_init_f(&cVar_kWIOF8hd, 0.2f);
  numBytes += cSlice_init(&cSlice_lFvNxrGv, 1, -1);
  numBytes += cVar_init_f(&cVar_bM9Ygxdl, 500.0f);
  numBytes += sVarf_init(&sVarf_1ElL27q5, 0.0f, 0.0f, false);
  numBytes += cVar_init_f(&cVar_gz7rIqHf, 600.0f);
  numBytes += cBinop_init(&cBinop_XTVjZauq, 0.0f); // __div
  numBytes += sVarf_init(&sVarf_V9cyL1XR, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_yBncRYaA, 0.0f, 0.0f, false);
  numBytes += cVar_init_f(&cVar_hMMLlDmO, 600.0f);
  numBytes += cBinop_init(&cBinop_43UG05Y6, 0.0f); // __div
  numBytes += sVarf_init(&sVarf_3Ko9rKiv, 0.0f, 0.0f, false);
  numBytes += cVar_init_f(&cVar_Hm4udIqr, 4000.0f);
  numBytes += cBinop_init(&cBinop_AGvXfyKZ, 0.0f); // __mul
  numBytes += sVarf_init(&sVarf_mAgcoTuU, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_b3kgBa2g, 0.0f, 0.0f, false);
  numBytes += cVar_init_f(&cVar_W1Et6mJN, 4000.0f);
  numBytes += cBinop_init(&cBinop_2GQvfXC3, 0.0f); // __mul
  numBytes += sVarf_init(&sVarf_flRydUO5, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_LtVWp1zn, 0.0f, 0.0f, false);
  numBytes += cIf_init(&cIf_PBtzAUQP, false);
  numBytes += cBinop_init(&cBinop_c6ts9So5, 0.0f); // __pow
  numBytes += cVar_init_f(&cVar_djxw5BXX, 20.0f);
  numBytes += cBinop_init(&cBinop_XTjZdfuv, 0.0f); // __mul
  numBytes += sVarf_init(&sVarf_WlPiwc27, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_baK4BTOb, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_Eo4faav9, 0.0f, 0.0f, false);
  numBytes += cIf_init(&cIf_zpeJ60UI, false);
  numBytes += cBinop_init(&cBinop_SRjV5TmW, 0.0f); // __pow
  numBytes += cVar_init_f(&cVar_LYVXFPe4, 20.0f);
  numBytes += cBinop_init(&cBinop_N65MTjI5, 0.0f); // __mul
  numBytes += sVarf_init(&sVarf_HRTpzk5m, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_5SPkAxKc, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_0bdC8Nar, 0.0f, 0.0f, false);
  numBytes += cSlice_init(&cSlice_9UrJNzAF, 1, -1);
  numBytes += cVar_init_f(&cVar_BojHGObu, 0.25f);
  numBytes += cDelay_init(this, &cDelay_ICInARda, 0.0f);
  numBytes += cDelay_init(this, &cDelay_Y50FeanN, 0.0f);
  numBytes += hTable_init(&hTable_Fi71Gc3J, 256);
  numBytes += cTabhead_init(&cTabhead_5sRjkEwK, &hTable_Fi71Gc3J);
  numBytes += cVar_init_s(&cVar_Hppg8hr8, "del-1428-delayL");
  numBytes += cDelay_init(this, &cDelay_tbYOmLcb, 0.0f);
  numBytes += cDelay_init(this, &cDelay_BTWS90v5, 0.0f);
  numBytes += cBinop_init(&cBinop_qu0z6zJb, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_9nzHDetP, 0.0f); // __sub
  numBytes += cBinop_init(&cBinop_8asLxE67, 0.0f); // __max
  numBytes += cBinop_init(&cBinop_W9EZFXLF, 0.0f); // __sub
  numBytes += cDelay_init(this, &cDelay_KPPgwWFv, 0.0f);
  numBytes += cDelay_init(this, &cDelay_FV9n1JuS, 0.0f);
  numBytes += hTable_init(&hTable_GuCIDNfd, 256);
  numBytes += cTabhead_init(&cTabhead_Vdsejnn7, &hTable_GuCIDNfd);
  numBytes += cVar_init_s(&cVar_k0ddEbLk, "del-1428-delayR");
  numBytes += cDelay_init(this, &cDelay_AkhGWW5G, 0.0f);
  numBytes += cDelay_init(this, &cDelay_tiR0urKK, 0.0f);
  numBytes += cBinop_init(&cBinop_17OZuesF, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_iPpZMt3H, 0.0f); // __sub
  numBytes += cBinop_init(&cBinop_f85e3zwF, 0.0f); // __max
  numBytes += cBinop_init(&cBinop_17aqsUWQ, 0.0f); // __sub
  numBytes += sVarf_init(&sVarf_u0KSG9uV, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_k2DDlCUJ, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_Lcyy7tnU, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_gnF6iaaJ, 0.0f, 0.0f, false);
  numBytes += cSlice_init(&cSlice_RaS2CjJ7, 1, -1);
  numBytes += cVar_init_f(&cVar_PxFv334s, 0.5f);
  numBytes += cSlice_init(&cSlice_zCLDJDdd, 1, -1);
  numBytes += cVar_init_f(&cVar_qJHoIyBj, 0.2f);
  numBytes += cSlice_init(&cSlice_DFmzKjYJ, 1, -1);
  numBytes += cVar_init_f(&cVar_gcErxsRk, 500.0f);
  numBytes += sVarf_init(&sVarf_sJ4hmV62, 0.0f, 0.0f, false);
  numBytes += cVar_init_f(&cVar_53agGqRN, 600.0f);
  numBytes += cBinop_init(&cBinop_7mI2u1Ll, 0.0f); // __div
  numBytes += sVarf_init(&sVarf_p0k0jAkU, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_xzFkSdKT, 0.0f, 0.0f, false);
  numBytes += cVar_init_f(&cVar_Pe2HEZID, 600.0f);
  numBytes += cBinop_init(&cBinop_Qo0hQCTa, 0.0f); // __div
  numBytes += sVarf_init(&sVarf_LIaZ958w, 0.0f, 0.0f, false);
  numBytes += cVar_init_f(&cVar_ix2p16dk, 4000.0f);
  numBytes += cBinop_init(&cBinop_c6FHZ2xf, 0.0f); // __mul
  numBytes += sVarf_init(&sVarf_gILdzuMN, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_wAU5nXlk, 0.0f, 0.0f, false);
  numBytes += cVar_init_f(&cVar_0w4wa58Q, 4000.0f);
  numBytes += cBinop_init(&cBinop_hLMZUMhN, 0.0f); // __mul
  numBytes += sVarf_init(&sVarf_MF4FOrg4, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_gZP578zs, 0.0f, 0.0f, false);
  numBytes += cIf_init(&cIf_6uemW2Cu, false);
  numBytes += cBinop_init(&cBinop_fIPABZsb, 0.0f); // __pow
  numBytes += cVar_init_f(&cVar_lm9c61Sj, 20.0f);
  numBytes += cBinop_init(&cBinop_zOWFpHOy, 0.0f); // __mul
  numBytes += sVarf_init(&sVarf_rW7IPVUz, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_dntFmCh2, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_mwyiqzaM, 0.0f, 0.0f, false);
  numBytes += cIf_init(&cIf_dPvYWVnG, false);
  numBytes += cBinop_init(&cBinop_3YxGWSe8, 0.0f); // __pow
  numBytes += cVar_init_f(&cVar_wUZ09Bxj, 20.0f);
  numBytes += cBinop_init(&cBinop_A13J7IeN, 0.0f); // __mul
  numBytes += sVarf_init(&sVarf_pZlC9evG, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_AKDAFGCy, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_qwsBeSut, 0.0f, 0.0f, false);
  numBytes += cSlice_init(&cSlice_w13BwbCr, 1, -1);
  numBytes += cVar_init_f(&cVar_DeJfeGt3, 0.25f);
  numBytes += cDelay_init(this, &cDelay_ZTFNL9ws, 0.0f);
  numBytes += cDelay_init(this, &cDelay_S3VKSlYL, 0.0f);
  numBytes += hTable_init(&hTable_oZ36avfO, 256);
  numBytes += cTabhead_init(&cTabhead_YU2Sh6ov, &hTable_oZ36avfO);
  numBytes += cVar_init_s(&cVar_0kfGGsqs, "del-1507-delayL");
  numBytes += cDelay_init(this, &cDelay_PPgzOmBP, 0.0f);
  numBytes += cDelay_init(this, &cDelay_vIV6UIv0, 0.0f);
  numBytes += cBinop_init(&cBinop_GjbQeYqr, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_mINmljr6, 0.0f); // __sub
  numBytes += cBinop_init(&cBinop_DKmYZCTl, 0.0f); // __max
  numBytes += cBinop_init(&cBinop_HAFbUFCb, 0.0f); // __sub
  numBytes += cDelay_init(this, &cDelay_BLTWSDEf, 0.0f);
  numBytes += cDelay_init(this, &cDelay_7jL5OrrN, 0.0f);
  numBytes += hTable_init(&hTable_nEj2Ecly, 256);
  numBytes += cTabhead_init(&cTabhead_eZhNrjyZ, &hTable_nEj2Ecly);
  numBytes += cVar_init_s(&cVar_Ug2j6PCM, "del-1507-delayR");
  numBytes += cDelay_init(this, &cDelay_EAcdvim9, 0.0f);
  numBytes += cDelay_init(this, &cDelay_fspvZWSd, 0.0f);
  numBytes += cBinop_init(&cBinop_dJur6t05, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_p9R3iqb9, 0.0f); // __sub
  numBytes += cBinop_init(&cBinop_0tD5126C, 0.0f); // __max
  numBytes += cBinop_init(&cBinop_xe7cXupD, 0.0f); // __sub
  numBytes += sVarf_init(&sVarf_vm1zqRYb, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_gs54m2SV, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_fSuzIh6O, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_tmovl8yk, 0.0f, 0.0f, false);
  numBytes += cVar_init_f(&cVar_z9pSVdBR, 1.0f);
  numBytes += cIf_init(&cIf_BffxeTAm, false);
  numBytes += cIf_init(&cIf_2I9Fp8uQ, false);
  numBytes += cVar_init_f(&cVar_KTSNM5qb, 0.0f);
  numBytes += cVar_init_f(&cVar_a8jOr47g, 0.0f);
  numBytes += cVar_init_f(&cVar_xoh5MjSo, 1.0f);
  numBytes += cIf_init(&cIf_QWyXFJ7J, false);
  numBytes += cIf_init(&cIf_8qm7zsQI, false);
  numBytes += cVar_init_f(&cVar_aCrUJC4g, 0.0f);
  numBytes += cVar_init_f(&cVar_HiMBXEVf, 0.0f);
  numBytes += cVar_init_f(&cVar_GdGTBdXt, 1.0f);
  numBytes += cIf_init(&cIf_rOEo116H, false);
  numBytes += cIf_init(&cIf_jmGkcm2p, false);
  numBytes += cVar_init_f(&cVar_mMu9f0wv, 0.0f);
  numBytes += cVar_init_f(&cVar_IVTFQbcY, 0.0f);
  numBytes += cVar_init_f(&cVar_eeY8NB78, 60000.0f);
  numBytes += cVar_init_f(&cVar_c1o2M1oB, 500.0f);
  numBytes += cSlice_init(&cSlice_yIj8W0qV, 1, -1);
  numBytes += cSlice_init(&cSlice_dzwQa2OX, 1, -1);
  numBytes += cVar_init_f(&cVar_ng9Ds6He, 0.0f);
  numBytes += cIf_init(&cIf_j3JE8sMx, false);
  numBytes += cBinop_init(&cBinop_wnT7OQ3Y, 0.0f); // __neq
  numBytes += cVar_init_f(&cVar_1j9C6T7s, 120.0f);
  numBytes += cBinop_init(&cBinop_Mgdc7OUE, 0.0f); // __div
  numBytes += cBinop_init(&cBinop_D6ub5d1e, 0.0f); // __mul
  numBytes += cVar_init_f(&cVar_pddzqDAH, 60000.0f);
  numBytes += cVar_init_f(&cVar_NP5dAoqV, 500.0f);
  numBytes += cSlice_init(&cSlice_r5TBkaDS, 1, -1);
  numBytes += cSlice_init(&cSlice_JW4ShkhI, 1, -1);
  numBytes += cVar_init_f(&cVar_Uf8aCLcY, 0.0f);
  numBytes += cIf_init(&cIf_ooI6GAvQ, false);
  numBytes += cBinop_init(&cBinop_FkW9U8Mp, 0.0f); // __neq
  numBytes += cVar_init_f(&cVar_FyRMhvMg, 120.0f);
  numBytes += cBinop_init(&cBinop_quR1j7KP, 0.0f); // __div
  numBytes += cBinop_init(&cBinop_lZYeh6vY, 0.0f); // __mul
  numBytes += cVar_init_f(&cVar_FuwGp9Bn, 60000.0f);
  numBytes += cVar_init_f(&cVar_A9EgloHC, 500.0f);
  numBytes += cSlice_init(&cSlice_zlbRe5X8, 1, -1);
  numBytes += cSlice_init(&cSlice_UkGz3ydT, 1, -1);
  numBytes += cVar_init_f(&cVar_tMPCEVSe, 0.0f);
  numBytes += cIf_init(&cIf_QvZjLH9N, false);
  numBytes += cBinop_init(&cBinop_JuvvgzPk, 0.0f); // __neq
  numBytes += cVar_init_f(&cVar_h9UYmtAg, 120.0f);
  numBytes += cBinop_init(&cBinop_nCAOwvtF, 0.0f); // __div
  numBytes += cBinop_init(&cBinop_9ukRBvCU, 0.0f); // __mul
  numBytes += sVarf_init(&sVarf_jMT5o4VC, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_L0ppEIO2, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_X9quEZW0, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_L5N4XZnL, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_Ibt1zOG8, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_9LIAhPDt, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_sIxCYBr1, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_rLTRQHs7, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_c5i95c52, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_a4gsN194, 0.0f, 0.0f, false);
  
  // schedule a message to trigger all loadbangs via the __hv_init receiver
  scheduleMessageForReceiver(0xCE5CC65B, msg_initWithBang(HV_MESSAGE_ON_STACK(1), 0));
}

Heavy_WSTD_DL3Y::~Heavy_WSTD_DL3Y() {
  sEnv_free(&sEnv_SwBoBkWr);
  sEnv_free(&sEnv_0GawZaWN);
  sEnv_free(&sEnv_uJDcVDjK);
  sEnv_free(&sEnv_ja9lRYb7);
  sEnv_free(&sEnv_bJMBGZcx);
  sEnv_free(&sEnv_njcGyCDv);
  hTable_free(&hTable_SuvEmq1G);
  hTable_free(&hTable_AFV9N3XC);
  hTable_free(&hTable_Fi71Gc3J);
  hTable_free(&hTable_GuCIDNfd);
  hTable_free(&hTable_oZ36avfO);
  hTable_free(&hTable_nEj2Ecly);
}

HvTable *Heavy_WSTD_DL3Y::getTableForHash(hv_uint32_t tableHash) {switch (tableHash) {
    case 0x29B74AF: return &hTable_SuvEmq1G; // del-1349-delayL
    case 0x19A00729: return &hTable_AFV9N3XC; // del-1349-delayR
    case 0x584C8281: return &hTable_Fi71Gc3J; // del-1428-delayL
    case 0x54BF59F6: return &hTable_GuCIDNfd; // del-1428-delayR
    case 0xBCE693A: return &hTable_oZ36avfO; // del-1507-delayL
    case 0x95A380B3: return &hTable_nEj2Ecly; // del-1507-delayR
    default: return nullptr;
  }
}

void Heavy_WSTD_DL3Y::scheduleMessageForReceiver(hv_uint32_t receiverHash, HvMessage *m) {
  switch (receiverHash) {
    case 0xC9CE7B11: { // High
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_YIHOaU22_sendMessage);
      break;
    }
    case 0xBB584857: { // High_Cross
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_ILSFRh0y_sendMessage);
      break;
    }
    case 0xACE44B9C: { // High_Feedback
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_tW90TCZZ_sendMessage);
      break;
    }
    case 0xAC5FA57F: { // High_Mix
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_B9WQRlvL_sendMessage);
      break;
    }
    case 0xDD62B09F: { // High_Sync
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_upPohuRU_sendMessage);
      break;
    }
    case 0xABB0CBCF: { // High_Time
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_9tmJ1Jb2_sendMessage);
      break;
    }
    case 0xAE942A2: { // High_TimeSync
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_r0p3rraM_sendMessage);
      break;
    }
    case 0x87744544: { // Low
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_F1OptNiJ_sendMessage);
      break;
    }
    case 0xA2D68920: { // Low_Cross
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_a2pVVtLv_sendMessage);
      break;
    }
    case 0xDDAB7A0: { // Low_Feedback
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_HmP6TOLw_sendMessage);
      break;
    }
    case 0x91FEF7A: { // Low_Mix
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_m8gNfGIf_sendMessage);
      break;
    }
    case 0xFFFEE96: { // Low_Sync
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_zHY8N3Ma_sendMessage);
      break;
    }
    case 0xA3BD8A20: { // Low_Time
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_1BLRzA3y_sendMessage);
      break;
    }
    case 0x67F58CFB: { // Low_TimeSync
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_Fkc8cpm1_sendMessage);
      break;
    }
    case 0xBFDC48B6: { // Mid
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_NMuCWEdd_sendMessage);
      break;
    }
    case 0x59607D3: { // Mid_Cross
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_H99YO7hC_sendMessage);
      break;
    }
    case 0x9B44FA2D: { // Mid_Feedback
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_Y38Eq96W_sendMessage);
      break;
    }
    case 0x59CF21AC: { // Mid_Freq
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_yjbinuyf_sendMessage);
      break;
    }
    case 0x676FE235: { // Mid_Mix
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_9mVOD0l4_sendMessage);
      break;
    }
    case 0x96E19510: { // Mid_Sync
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_OSqiHt4f_sendMessage);
      break;
    }
    case 0xE1DB1774: { // Mid_Time
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_F9NO4DpG_sendMessage);
      break;
    }
    case 0xDB67B94E: { // Mid_TimeSync
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_pmlaqr8g_sendMessage);
      break;
    }
    case 0x24295C10: { // 1010-highvol
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_TVYZuOCE_sendMessage);
      break;
    }
    case 0x3649681E: { // 1010-lowvol
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_esqRdfFY_sendMessage);
      break;
    }
    case 0xD5A8E74D: { // 1010-midfreq
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_VqCZOEsI_sendMessage);
      break;
    }
    case 0x60D6F65: { // 1010-midq
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_JF2gJat3_sendMessage);
      break;
    }
    case 0x37E92263: { // 1010-midvol
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_i6SEP5JK_sendMessage);
      break;
    }
    case 0x2271964: { // 1069-alpha
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_SXWOyGRT_sendMessage);
      break;
    }
    case 0xA61C5543: { // 1069-wcos
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_VuPP32n3_sendMessage);
      break;
    }
    case 0x1E13C49D: { // 1069-wsin
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_bk1bYnJn_sendMessage);
      break;
    }
    case 0xE7448D12: { // 1110-alpha
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_NPFkF5Ze_sendMessage);
      break;
    }
    case 0x5F31ED81: { // 1110-wcos
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_GuN7lIS6_sendMessage);
      break;
    }
    case 0xC3520438: { // 1110-wsin
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_OrFggUkN_sendMessage);
      break;
    }
    case 0xB2DA8F9A: { // 1151-alpha
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_gBpW5Yt5_sendMessage);
      break;
    }
    case 0x668DC2C1: { // 1151-wcos
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_OrQQzB3r_sendMessage);
      break;
    }
    case 0x413B9F30: { // 1151-wsin
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_wETDpJeQ_sendMessage);
      break;
    }
    case 0x845815A0: { // 1163-highvol
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_idPyvD2n_sendMessage);
      break;
    }
    case 0x5CD8AF91: { // 1163-lowvol
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_dWeOKwMe_sendMessage);
      break;
    }
    case 0x188BB7A0: { // 1163-midfreq
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_8vSBaZHa_sendMessage);
      break;
    }
    case 0xE3BB13E4: { // 1163-midq
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_7NE2K9x4_sendMessage);
      break;
    }
    case 0x3693B415: { // 1163-midvol
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_ASxy4lNE_sendMessage);
      break;
    }
    case 0x1A14721E: { // 1222-alpha
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_UUr3ft4L_sendMessage);
      break;
    }
    case 0x446DC164: { // 1222-wcos
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_EAARJt7o_sendMessage);
      break;
    }
    case 0x32F45A8B: { // 1222-wsin
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_hKoFRC98_sendMessage);
      break;
    }
    case 0x1286072C: { // 1263-alpha
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_ikRfXfWV_sendMessage);
      break;
    }
    case 0x7902A17C: { // 1263-wcos
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_6tBqTAYJ_sendMessage);
      break;
    }
    case 0x7A57C19C: { // 1263-wsin
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_QLhkeuJu_sendMessage);
      break;
    }
    case 0x170C9887: { // 1304-alpha
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_FOKuksaM_sendMessage);
      break;
    }
    case 0xED0CBA1C: { // 1304-wcos
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_JlkWrMyG_sendMessage);
      break;
    }
    case 0xDA3A818C: { // 1304-wsin
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_M96gQdAE_sendMessage);
      break;
    }
    case 0x9FC1C9E5: { // 1349-cross
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_V4fO0Zpk_sendMessage);
      break;
    }
    case 0x5D7BD4E9: { // 1349-feedback
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_1zBm6Ndd_sendMessage);
      break;
    }
    case 0x371A347A: { // 1349-mix
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_mpZs7deU_sendMessage);
      break;
    }
    case 0x810E74BC: { // 1349-time
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_ZTVhANfK_sendMessage);
      break;
    }
    case 0xCC56B3CF: { // 1428-cross
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_MQXv8zZU_sendMessage);
      break;
    }
    case 0x499A953B: { // 1428-feedback
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_AYKlTuOy_sendMessage);
      break;
    }
    case 0xE0E7225B: { // 1428-mix
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_61c3LaMw_sendMessage);
      break;
    }
    case 0xE6486F5F: { // 1428-time
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_QO7LABFT_sendMessage);
      break;
    }
    case 0xF65E8330: { // 1507-cross
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_gh5EyZ09_sendMessage);
      break;
    }
    case 0x3B8B5FB8: { // 1507-feedback
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_9kpmztE7_sendMessage);
      break;
    }
    case 0xE5F26E0D: { // 1507-mix
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_NsHFswVU_sendMessage);
      break;
    }
    case 0xFDAB8735: { // 1507-time
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_xw9wQJgG_sendMessage);
      break;
    }
    case 0xDF8C2721: { // __hv_dpf_bpm
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_c8TSmwsE_sendMessage);
      break;
    }
    case 0xCE5CC65B: { // __hv_init
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_PQmPfaKP_sendMessage);
      break;
    }
    default: return;
  }
}

int Heavy_WSTD_DL3Y::getParameterInfo(int index, HvParameterInfo *info) {
  if (info != nullptr) {
    switch (index) {
      case 0: {
        info->name = "High";
        info->hash = 0xC9CE7B11;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = -15.0f;
        info->maxVal = 15.0f;
        info->defaultVal = 0.0f;
        break;
      }
      case 1: {
        info->name = "High_Cross";
        info->hash = 0xBB584857;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 100.0f;
        info->defaultVal = 20.0f;
        break;
      }
      case 2: {
        info->name = "High_Feedback";
        info->hash = 0xACE44B9C;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 100.0f;
        info->defaultVal = 25.0f;
        break;
      }
      case 3: {
        info->name = "High_Mix";
        info->hash = 0xAC5FA57F;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 100.0f;
        info->defaultVal = 50.0f;
        break;
      }
      case 4: {
        info->name = "High_Sync";
        info->hash = 0xDD62B09F;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 1.0f;
        info->defaultVal = 0.0f;
        break;
      }
      case 5: {
        info->name = "High_Time";
        info->hash = 0xABB0CBCF;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 50.0f;
        info->maxVal = 5000.0f;
        info->defaultVal = 500.0f;
        break;
      }
      case 6: {
        info->name = "High_TimeSync";
        info->hash = 0xAE942A2;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 12.0f;
        info->defaultVal = 6.0f;
        break;
      }
      case 7: {
        info->name = "Low";
        info->hash = 0x87744544;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = -15.0f;
        info->maxVal = 15.0f;
        info->defaultVal = 0.0f;
        break;
      }
      case 8: {
        info->name = "Low_Cross";
        info->hash = 0xA2D68920;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 100.0f;
        info->defaultVal = 20.0f;
        break;
      }
      case 9: {
        info->name = "Low_Feedback";
        info->hash = 0xDDAB7A0;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 100.0f;
        info->defaultVal = 25.0f;
        break;
      }
      case 10: {
        info->name = "Low_Mix";
        info->hash = 0x91FEF7A;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 100.0f;
        info->defaultVal = 50.0f;
        break;
      }
      case 11: {
        info->name = "Low_Sync";
        info->hash = 0xFFFEE96;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 1.0f;
        info->defaultVal = 0.0f;
        break;
      }
      case 12: {
        info->name = "Low_Time";
        info->hash = 0xA3BD8A20;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 50.0f;
        info->maxVal = 5000.0f;
        info->defaultVal = 500.0f;
        break;
      }
      case 13: {
        info->name = "Low_TimeSync";
        info->hash = 0x67F58CFB;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 12.0f;
        info->defaultVal = 6.0f;
        break;
      }
      case 14: {
        info->name = "Mid";
        info->hash = 0xBFDC48B6;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = -15.0f;
        info->maxVal = 15.0f;
        info->defaultVal = 0.0f;
        break;
      }
      case 15: {
        info->name = "Mid_Cross";
        info->hash = 0x59607D3;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 100.0f;
        info->defaultVal = 20.0f;
        break;
      }
      case 16: {
        info->name = "Mid_Feedback";
        info->hash = 0x9B44FA2D;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 100.0f;
        info->defaultVal = 25.0f;
        break;
      }
      case 17: {
        info->name = "Mid_Freq";
        info->hash = 0x59CF21AC;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 313.3f;
        info->maxVal = 5705.6f;
        info->defaultVal = 1337.0f;
        break;
      }
      case 18: {
        info->name = "Mid_Mix";
        info->hash = 0x676FE235;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 100.0f;
        info->defaultVal = 50.0f;
        break;
      }
      case 19: {
        info->name = "Mid_Sync";
        info->hash = 0x96E19510;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 1.0f;
        info->defaultVal = 0.0f;
        break;
      }
      case 20: {
        info->name = "Mid_Time";
        info->hash = 0xE1DB1774;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 50.0f;
        info->maxVal = 5000.0f;
        info->defaultVal = 500.0f;
        break;
      }
      case 21: {
        info->name = "Mid_TimeSync";
        info->hash = 0xDB67B94E;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 12.0f;
        info->defaultVal = 6.0f;
        break;
      }
      default: {
        info->name = "invalid parameter index";
        info->hash = 0;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 0.0f;
        info->defaultVal = 0.0f;
        break;
      }
    }
  }
  return 22;
}



/*
 * Send Function Implementations
 */


void Heavy_WSTD_DL3Y::cVar_D8WmDR5Z_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_X5wrbyTj_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cVar_0SWLibYN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_IYdR7HbO_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cVar_Iml1QuDm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_WVd0aNU1_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cVar_w56Lrt0V_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_Ud0ieM5m_sendMessage(_c, 0, m);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_ieBVU4Ic_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_GmZTFMkN_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_1T7KgycQ_sendMessage);
}

void Heavy_WSTD_DL3Y::cSwitchcase_pr8HF4sM_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0xE9AAC520: { // "midfreq"
      cSlice_onMessage(_c, &Context(_c)->cSlice_U1T2XEDz, 0, m, &cSlice_U1T2XEDz_sendMessage);
      break;
    }
    default: {
      cSwitchcase_VikQSv8T_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_DL3Y::cSlice_U1T2XEDz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_qwdHJkdW_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_qwdHJkdW_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cVar_JiXHpUmq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_qwdHJkdW_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cSend_qwdHJkdW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_VqCZOEsI_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cVar_6t0wcwI8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_UaOGop6G_sendMessage);
  cIf_onMessage(_c, &Context(_c)->cIf_M90bXtyH, 0, m, &cIf_M90bXtyH_sendMessage);
}

void Heavy_WSTD_DL3Y::cIf_M90bXtyH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_vVhrbeOH_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cIf_1OFWsYww_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cMsg_n1d8qX1P_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 485.0f, 0, m, &cBinop_gbgNnUB0_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cMsg_J2uzUthH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 10.0f);
  cBinop_onMessage(_c, &Context(_c)->cBinop_tiX0Tdg5, HV_BINOP_POW, 0, m, &cBinop_tiX0Tdg5_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_tiX0Tdg5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_JGCm9BOC, 0, m, &cIf_JGCm9BOC_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_WfrTnEgg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 20.0f, 0, m, &cBinop_atrIX6am_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_utGW8Rsq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_1OFWsYww, 0, m, &cIf_1OFWsYww_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_U42ucblp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_bZwpVzJs_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_bZwpVzJs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_1OFWsYww, 1, m, &cIf_1OFWsYww_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_gbgNnUB0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 100.0f, 0, m, &cBinop_WfrTnEgg_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_n1d8qX1P_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cIf_onMessage(_c, &Context(_c)->cIf_JGCm9BOC, 0, m, &cIf_JGCm9BOC_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_atrIX6am_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_tiX0Tdg5, HV_BINOP_POW, 1, m, &cBinop_tiX0Tdg5_sendMessage);
  cMsg_J2uzUthH_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cIf_JGCm9BOC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      sVarf_onMessage(_c, &Context(_c)->sVarf_U6X8BmkL, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cBinop_UaOGop6G_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_M90bXtyH, 1, m, &cIf_M90bXtyH_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_vVhrbeOH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_1OyEuo5k, HV_BINOP_GREATER_THAN, 1, m, &cBinop_1OyEuo5k_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_ZXmuPMYo, HV_BINOP_EQ, 1, m, &cBinop_ZXmuPMYo_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_nIvNkXw5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 100.0f);
  cBinop_onMessage(_c, &Context(_c)->cBinop_zYS940yW, HV_BINOP_ADD, 0, m, &cBinop_zYS940yW_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_zYS940yW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_U42ucblp_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_utGW8Rsq_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_1OyEuo5k_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_JGCm9BOC, 1, m, &cIf_JGCm9BOC_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_ZXmuPMYo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_Zlqz16aR_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cMsg_Zlqz16aR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  sVarf_onMessage(_c, &Context(_c)->sVarf_U6X8BmkL, m);
}

void Heavy_WSTD_DL3Y::cCast_mdZE6ifP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_zYS940yW, HV_BINOP_ADD, 1, m, &cBinop_zYS940yW_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_1OyEuo5k, HV_BINOP_GREATER_THAN, 0, m, &cBinop_1OyEuo5k_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_ZXmuPMYo, HV_BINOP_EQ, 0, m, &cBinop_ZXmuPMYo_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_vy0mqpbh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_6t0wcwI8, 0, m, &cVar_6t0wcwI8_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_x3lEgOGc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_nIvNkXw5_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cVar_zGSZ7uMm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_65PddUQp_sendMessage);
  cIf_onMessage(_c, &Context(_c)->cIf_mWkmsJbe, 0, m, &cIf_mWkmsJbe_sendMessage);
}

void Heavy_WSTD_DL3Y::cIf_mWkmsJbe_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_c5L99BTs_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cIf_VteytaCr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cMsg_nh8S0oFG_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 485.0f, 0, m, &cBinop_dVXdLk5I_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cMsg_csVGh7WX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 10.0f);
  cBinop_onMessage(_c, &Context(_c)->cBinop_hJ19LTS7, HV_BINOP_POW, 0, m, &cBinop_hJ19LTS7_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_hJ19LTS7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_BWZKkQl3, 0, m, &cIf_BWZKkQl3_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_Bc362CHv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 20.0f, 0, m, &cBinop_vzatX1F4_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_CQXG9ZXV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_0kTYDzIV_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_bzF1YmXW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_VteytaCr, 0, m, &cIf_VteytaCr_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_0kTYDzIV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_VteytaCr, 1, m, &cIf_VteytaCr_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_dVXdLk5I_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 100.0f, 0, m, &cBinop_Bc362CHv_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_nh8S0oFG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cIf_onMessage(_c, &Context(_c)->cIf_BWZKkQl3, 0, m, &cIf_BWZKkQl3_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_vzatX1F4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_hJ19LTS7, HV_BINOP_POW, 1, m, &cBinop_hJ19LTS7_sendMessage);
  cMsg_csVGh7WX_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cIf_BWZKkQl3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_vzy2bT6Z_sendMessage);
      cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_RwkFbpjc_sendMessage);
      cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 0.0313f, 0, m, &cBinop_66WNNtGt_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cBinop_65PddUQp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_mWkmsJbe, 1, m, &cIf_mWkmsJbe_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_c5L99BTs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_HTNiYJlC, HV_BINOP_GREATER_THAN, 1, m, &cBinop_HTNiYJlC_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_8AYimfm4, HV_BINOP_EQ, 1, m, &cBinop_8AYimfm4_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_RXXCSLbb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 100.0f);
  cBinop_onMessage(_c, &Context(_c)->cBinop_k2RCT9fa, HV_BINOP_ADD, 0, m, &cBinop_k2RCT9fa_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_k2RCT9fa_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_CQXG9ZXV_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_bzF1YmXW_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_HTNiYJlC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_BWZKkQl3, 1, m, &cIf_BWZKkQl3_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_8AYimfm4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_uSd2EDiP_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cMsg_uSd2EDiP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_vzy2bT6Z_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_RwkFbpjc_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 0.0313f, 0, m, &cBinop_66WNNtGt_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_ap0rrPAv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_zGSZ7uMm, 0, m, &cVar_zGSZ7uMm_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_uetwD1ZC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_RXXCSLbb_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cCast_cwGSfEqW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_k2RCT9fa, HV_BINOP_ADD, 1, m, &cBinop_k2RCT9fa_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_HTNiYJlC, HV_BINOP_GREATER_THAN, 0, m, &cBinop_HTNiYJlC_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_8AYimfm4, HV_BINOP_EQ, 0, m, &cBinop_8AYimfm4_sendMessage);
}

void Heavy_WSTD_DL3Y::cVar_IxYd8BZY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_33EKw2VS_sendMessage);
  cIf_onMessage(_c, &Context(_c)->cIf_L3ySP92G, 0, m, &cIf_L3ySP92G_sendMessage);
}

void Heavy_WSTD_DL3Y::cIf_L3ySP92G_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_kR5Y1U7l_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cIf_kiJRaDZM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cMsg_zf5KZDST_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 485.0f, 0, m, &cBinop_LzGUJIcY_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cMsg_vAWPkoHh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 10.0f);
  cBinop_onMessage(_c, &Context(_c)->cBinop_PI5rZEol, HV_BINOP_POW, 0, m, &cBinop_PI5rZEol_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_PI5rZEol_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_6kZ9ov1P, 0, m, &cIf_6kZ9ov1P_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_I3xD24Fd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 20.0f, 0, m, &cBinop_hLc28yvX_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_aCYuXna3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_bjrJ4cQM_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_DI3Sa6Yi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_kiJRaDZM, 0, m, &cIf_kiJRaDZM_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_bjrJ4cQM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_kiJRaDZM, 1, m, &cIf_kiJRaDZM_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_LzGUJIcY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 100.0f, 0, m, &cBinop_I3xD24Fd_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_zf5KZDST_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cIf_onMessage(_c, &Context(_c)->cIf_6kZ9ov1P, 0, m, &cIf_6kZ9ov1P_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_hLc28yvX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_PI5rZEol, HV_BINOP_POW, 1, m, &cBinop_PI5rZEol_sendMessage);
  cMsg_vAWPkoHh_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cIf_6kZ9ov1P_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      sVarf_onMessage(_c, &Context(_c)->sVarf_dBidPBLo, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cBinop_33EKw2VS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_L3ySP92G, 1, m, &cIf_L3ySP92G_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_kR5Y1U7l_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_mBswZg7F, HV_BINOP_GREATER_THAN, 1, m, &cBinop_mBswZg7F_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_txrJ61Nw, HV_BINOP_EQ, 1, m, &cBinop_txrJ61Nw_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_Gf0kAIPu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 100.0f);
  cBinop_onMessage(_c, &Context(_c)->cBinop_Qh2OP8xu, HV_BINOP_ADD, 0, m, &cBinop_Qh2OP8xu_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_Qh2OP8xu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_aCYuXna3_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_DI3Sa6Yi_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_mBswZg7F_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_6kZ9ov1P, 1, m, &cIf_6kZ9ov1P_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_txrJ61Nw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_PyrbIsUD_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cMsg_PyrbIsUD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  sVarf_onMessage(_c, &Context(_c)->sVarf_dBidPBLo, m);
}

void Heavy_WSTD_DL3Y::cCast_sRc82d1f_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_IxYd8BZY, 0, m, &cVar_IxYd8BZY_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_c7WDawPm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_Gf0kAIPu_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cCast_ddaT7Lw3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_Qh2OP8xu, HV_BINOP_ADD, 1, m, &cBinop_Qh2OP8xu_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_mBswZg7F, HV_BINOP_GREATER_THAN, 0, m, &cBinop_mBswZg7F_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_txrJ61Nw, HV_BINOP_EQ, 0, m, &cBinop_txrJ61Nw_sendMessage);
}

void Heavy_WSTD_DL3Y::cIf_4bTJu7xk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      sVarf_onMessage(_c, &Context(_c)->sVarf_viQfCm71, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cSwitchcase_GWW7tEc3_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x58220DA4: { // "highvol"
      cSlice_onMessage(_c, &Context(_c)->cSlice_iNjvW6zo, 0, m, &cSlice_iNjvW6zo_sendMessage);
      break;
    }
    default: {
      cSwitchcase_zXjcGWED_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_DL3Y::cSlice_iNjvW6zo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_GLOLheya_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_GLOLheya_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cVar_H1z8FLjH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_GLOLheya_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cSend_GLOLheya_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_TVYZuOCE_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cSwitchcase_zXjcGWED_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0xBDABF734: { // "midvol"
      cSlice_onMessage(_c, &Context(_c)->cSlice_r9LHDk23, 0, m, &cSlice_r9LHDk23_sendMessage);
      break;
    }
    default: {
      cSwitchcase_pr8HF4sM_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_DL3Y::cSlice_r9LHDk23_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_RrniYDiB_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_RrniYDiB_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cVar_h2BeBiec_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_RrniYDiB_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cSend_RrniYDiB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_i6SEP5JK_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cSwitchcase_VikQSv8T_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x1FF74688: { // "lowvol"
      cSlice_onMessage(_c, &Context(_c)->cSlice_aCxpw9uu, 0, m, &cSlice_aCxpw9uu_sendMessage);
      break;
    }
    default: {
      cSwitchcase_DF02K63Z_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_DL3Y::cSlice_aCxpw9uu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_NSI1uzhk_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_NSI1uzhk_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cVar_R87ErOZK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_NSI1uzhk_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cSend_NSI1uzhk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_esqRdfFY_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cSwitchcase_DF02K63Z_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x98D37786: { // "midq"
      cSlice_onMessage(_c, &Context(_c)->cSlice_tQV4mzJh, 0, m, &cSlice_tQV4mzJh_sendMessage);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_WSTD_DL3Y::cSlice_tQV4mzJh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_36QnOtVl_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_36QnOtVl_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cVar_3tjMy5FY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_36QnOtVl_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cSend_36QnOtVl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_JF2gJat3_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cMsg_gRc5eHDq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_g1Eeh1gB, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cMsg_VovKQlyD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_dRMCKDYR, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cMsg_bSCBXVGE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_T2Ni0VT3, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cMsg_4cEFMdbH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_gwJwwESa, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cMsg_O7WdG8j5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_8J90UdGH, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cMsg_eVCpTord_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_Ynh1RG3X_sendMessage);
}

void Heavy_WSTD_DL3Y::cSystem_Ynh1RG3X_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_DhORTnFN, HV_BINOP_DIVIDE, 1, m, &cBinop_DhORTnFN_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_bJqGUmFX_sendMessage);
}

void Heavy_WSTD_DL3Y::cUnop_b6qWIDkQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 8.0f, 0, m, &cBinop_fxbidSha_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_ThAeWtf3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cUnop_onMessage(_c, HV_UNOP_ATAN, m, &cUnop_b6qWIDkQ_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_fxbidSha_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_DhORTnFN, HV_BINOP_DIVIDE, 0, m, &cBinop_DhORTnFN_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_bJqGUmFX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_ThAeWtf3_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_DhORTnFN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_tTpc95xN, HV_BINOP_MULTIPLY, 1, m, &cBinop_tTpc95xN_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_tTpc95xN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_2ooISctJ_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_hLv9T7YL_sendMessage);
}

void Heavy_WSTD_DL3Y::cUnop_3SOGYfdp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_BpsgyBL5_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cUnop_qHgzwGgl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_rMmopCde_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_XYoDiYVR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 20.0f, 0, m, &cBinop_vvHwkAjA_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_vvHwkAjA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_tTpc95xN, HV_BINOP_MULTIPLY, 0, m, &cBinop_tTpc95xN_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_vFZxgpib_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.1f, 0, m, &cBinop_6qGyyTwc_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_6qGyyTwc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_gszz3WRe_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_Acpls1Zx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_zMxyefE5, 1, m, &cVar_zMxyefE5_sendMessage);
}

void Heavy_WSTD_DL3Y::cVar_zMxyefE5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_2WXesGsS_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_JOsYgvBg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_BBO61ard, HV_BINOP_MULTIPLY, 1, m, &cBinop_BBO61ard_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_aAr95BJ1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_JOsYgvBg_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_ykm2iT84_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_UtS96paj_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_UtS96paj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_n9yuKD95, HV_BINOP_MULTIPLY, 1, m, &cBinop_n9yuKD95_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_nnC90sxl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_SXV6z1e3, HV_BINOP_MULTIPLY, 1, m, &cBinop_SXV6z1e3_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_LGPL9osB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_nnC90sxl_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_cIoKWf32_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_bMFR8cUe, HV_BINOP_MULTIPLY, 1, m, &cBinop_bMFR8cUe_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_2zMzzV0F_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_iXHJGFyY_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_iXHJGFyY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_CuIcq5Gl, HV_BINOP_MULTIPLY, 1, m, &cBinop_CuIcq5Gl_sendMessage);
}

void Heavy_WSTD_DL3Y::cVar_S2FnHzAa_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_t4qJW1Lr_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 20000.0f, 0, m, &cBinop_XYoDiYVR_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_EU0Oa79i_sendMessage);
}

void Heavy_WSTD_DL3Y::cVar_r44Fcpob_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 100.0f, 0, m, &cBinop_vFZxgpib_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_hLv9T7YL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_COS, m, &cUnop_qHgzwGgl_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_2ooISctJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_SIN, m, &cUnop_3SOGYfdp_sendMessage);
}

void Heavy_WSTD_DL3Y::cSend_BpsgyBL5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_bk1bYnJn_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cSend_rMmopCde_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_VuPP32n3_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cSend_dQAQ9Eyu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_SXWOyGRT_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cMsg_gszz3WRe_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_5iYHdY6C_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_5iYHdY6C_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_5qxKnxfz, HV_BINOP_MULTIPLY, 1, m, &cBinop_5qxKnxfz_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_5qxKnxfz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_n2KbRVH3_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_n2KbRVH3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_dQAQ9Eyu_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cMsg_2WXesGsS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_HnkrVWOb_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_HnkrVWOb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_Y4eEYb0z_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_CgYYPjGK_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_9nfrHXBq_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_6VwVYcLY_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_nE2a6ysk_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_3tYeLsTa_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_BBO61ard_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_gRc5eHDq_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_n9yuKD95_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_VovKQlyD_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_SXV6z1e3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_bSCBXVGE_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_bMFR8cUe_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_4cEFMdbH_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_CuIcq5Gl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_O7WdG8j5_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cCast_ksAVEHjL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_S2FnHzAa, 0, m, &cVar_S2FnHzAa_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_ElA926S1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_r44Fcpob, 1, m, &cVar_r44Fcpob_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_nE2a6ysk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_n9yuKD95, HV_BINOP_MULTIPLY, 0, m, &cBinop_n9yuKD95_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_CgYYPjGK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_CuIcq5Gl, HV_BINOP_MULTIPLY, 0, m, &cBinop_CuIcq5Gl_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_6VwVYcLY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_SXV6z1e3, HV_BINOP_MULTIPLY, 0, m, &cBinop_SXV6z1e3_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_Y4eEYb0z_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
}

void Heavy_WSTD_DL3Y::cCast_3tYeLsTa_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_BBO61ard, HV_BINOP_MULTIPLY, 0, m, &cBinop_BBO61ard_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_9nfrHXBq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_bMFR8cUe, HV_BINOP_MULTIPLY, 0, m, &cBinop_bMFR8cUe_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_t4qJW1Lr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_r44Fcpob, 0, m, &cVar_r44Fcpob_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_EU0Oa79i_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_zMxyefE5, 0, m, &cVar_zMxyefE5_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_OU74sgqi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_6UHbdru9, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cMsg_8NfJp4A8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_bUbxW5n0, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cMsg_e6uHVEDe_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_JPZ6pEbB, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cMsg_GNgvnjbB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_kAour652, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cMsg_jex5Xyzv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_or5NepfE_sendMessage);
}

void Heavy_WSTD_DL3Y::cSystem_or5NepfE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_HfS3BPCE, HV_BINOP_DIVIDE, 1, m, &cBinop_HfS3BPCE_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_J1xAXBBz_sendMessage);
}

void Heavy_WSTD_DL3Y::cUnop_3fj29Ht3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 8.0f, 0, m, &cBinop_tSAwsYWn_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_qWITGWhG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cUnop_onMessage(_c, HV_UNOP_ATAN, m, &cUnop_3fj29Ht3_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_tSAwsYWn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_HfS3BPCE, HV_BINOP_DIVIDE, 0, m, &cBinop_HfS3BPCE_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_J1xAXBBz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_qWITGWhG_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_HfS3BPCE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_qJmMMunC, HV_BINOP_MULTIPLY, 1, m, &cBinop_qJmMMunC_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_qJmMMunC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_emiRXKeu_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_1qNlXWX9_sendMessage);
}

void Heavy_WSTD_DL3Y::cUnop_UF5cS76I_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_yQi3UR8R_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cUnop_VMosGAvh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_TOmVAbm4_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_kfz6mJ0f_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 20.0f, 0, m, &cBinop_Sv7rpZhL_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_Sv7rpZhL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_qJmMMunC, HV_BINOP_MULTIPLY, 0, m, &cBinop_qJmMMunC_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_fIxEzRMY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.1f, 0, m, &cBinop_HAqTdqO7_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_HAqTdqO7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_jBR2HiOW_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_Gr5g7rGX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_QC3grlgC, HV_BINOP_MULTIPLY, 1, m, &cBinop_QC3grlgC_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_LLDYQNvP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_PNsv2zpf, 1, m, &cVar_PNsv2zpf_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_ZPSM5ED3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_oirWykH2, HV_BINOP_MULTIPLY, 1, m, &cBinop_oirWykH2_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_SjkSmgtc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_0YFntMVZ_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_0YFntMVZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_hqoDmNwm, HV_BINOP_MULTIPLY, 1, m, &cBinop_hqoDmNwm_sendMessage);
}

void Heavy_WSTD_DL3Y::cVar_PNsv2zpf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_E7OT1rw9_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cVar_KdNlQHS7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_spdj6OCX_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 20000.0f, 0, m, &cBinop_kfz6mJ0f_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_A4goCSz5_sendMessage);
}

void Heavy_WSTD_DL3Y::cVar_AHtzyZMg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 100.0f, 0, m, &cBinop_fIxEzRMY_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_1qNlXWX9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_COS, m, &cUnop_VMosGAvh_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_emiRXKeu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_SIN, m, &cUnop_UF5cS76I_sendMessage);
}

void Heavy_WSTD_DL3Y::cSend_yQi3UR8R_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_OrFggUkN_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cSend_TOmVAbm4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_GuN7lIS6_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cSend_zposZjG9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_NPFkF5Ze_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cMsg_jBR2HiOW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_2AEiPvW3_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_2AEiPvW3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_bm2cUtUi, HV_BINOP_MULTIPLY, 1, m, &cBinop_bm2cUtUi_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_bm2cUtUi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_Y66xjYeN_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_Y66xjYeN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_zposZjG9_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cMsg_E7OT1rw9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_Jpj7EnkQ_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_Jpj7EnkQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_xcRey86q_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_69FdBPcD_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_TGVU2ouC_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_3WJ3FPxT_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_YvRWZlM4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_OU74sgqi_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_QC3grlgC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_8NfJp4A8_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_oirWykH2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_e6uHVEDe_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_hqoDmNwm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_GNgvnjbB_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cCast_kaiC1srV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_KdNlQHS7, 0, m, &cVar_KdNlQHS7_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_PmtlG92e_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_AHtzyZMg, 1, m, &cVar_AHtzyZMg_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_A4goCSz5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_PNsv2zpf, 0, m, &cVar_PNsv2zpf_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_spdj6OCX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_AHtzyZMg, 0, m, &cVar_AHtzyZMg_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_69FdBPcD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_oirWykH2, HV_BINOP_MULTIPLY, 0, m, &cBinop_oirWykH2_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_3WJ3FPxT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_YvRWZlM4, HV_BINOP_MULTIPLY, 0, m, &cBinop_YvRWZlM4_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_xcRey86q_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_hqoDmNwm, HV_BINOP_MULTIPLY, 0, m, &cBinop_hqoDmNwm_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_TGVU2ouC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_QC3grlgC, HV_BINOP_MULTIPLY, 0, m, &cBinop_QC3grlgC_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_SZA7YopI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_JSwJ1phT, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cMsg_K75Z9AJA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_NglVKMHx, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cMsg_8obj9dt0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_fIqxGAS9, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cMsg_75rSvAUM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_FHBvJrMg, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cMsg_FAqXmbBp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_ud6Hyy69, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cMsg_uqt2724L_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_CKXdCenw_sendMessage);
}

void Heavy_WSTD_DL3Y::cSystem_CKXdCenw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_kh7c9ofh, HV_BINOP_DIVIDE, 1, m, &cBinop_kh7c9ofh_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_fxlWHetT_sendMessage);
}

void Heavy_WSTD_DL3Y::cUnop_17VI3vXa_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 8.0f, 0, m, &cBinop_F0aRWi0H_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_BcfYXcS9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cUnop_onMessage(_c, HV_UNOP_ATAN, m, &cUnop_17VI3vXa_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_F0aRWi0H_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_kh7c9ofh, HV_BINOP_DIVIDE, 0, m, &cBinop_kh7c9ofh_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_fxlWHetT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_BcfYXcS9_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_kh7c9ofh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_CHxY5us4, HV_BINOP_MULTIPLY, 1, m, &cBinop_CHxY5us4_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_CHxY5us4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_NSKxL8CB_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_ZMcNizKW_sendMessage);
}

void Heavy_WSTD_DL3Y::cUnop_FkRbY7Sg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_1VtdEvJz_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cUnop_5BLKNI4c_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_fFH44sqc_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_PhjnhU6g_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 20.0f, 0, m, &cBinop_femHzJtG_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_femHzJtG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_CHxY5us4, HV_BINOP_MULTIPLY, 0, m, &cBinop_CHxY5us4_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_oP1cMgkr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.1f, 0, m, &cBinop_VEvLuUsz_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_VEvLuUsz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_GZxJ9itM_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_rTWCLaZs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_fhG4unvs, HV_BINOP_MULTIPLY, 1, m, &cBinop_fhG4unvs_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_mszXgqye_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_wJvN5Q1J_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_wJvN5Q1J_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_rTWCLaZs_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_WftNm2xp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_IVdbm8NM_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_IVdbm8NM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_aQpvluoe, HV_BINOP_MULTIPLY, 1, m, &cBinop_aQpvluoe_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_NuyzDC2r_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_AgQ3wfAS, HV_BINOP_MULTIPLY, 1, m, &cBinop_AgQ3wfAS_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_o1KrCWaP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_4LPkmBRO_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_4LPkmBRO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_NuyzDC2r_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_9quSnaIz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_x1KRpgEx, 1, m, &cVar_x1KRpgEx_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_84ggeXJ0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_sGCv4nUW, HV_BINOP_MULTIPLY, 1, m, &cBinop_sGCv4nUW_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_kpDsGWy0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_p5ucbUuF_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_p5ucbUuF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_ccucuBVU, HV_BINOP_MULTIPLY, 1, m, &cBinop_ccucuBVU_sendMessage);
}

void Heavy_WSTD_DL3Y::cVar_x1KRpgEx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_v7r9gjL4_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cVar_xwHJrqs3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_eYFGR3IX_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 20000.0f, 0, m, &cBinop_PhjnhU6g_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_xdMTZV1B_sendMessage);
}

void Heavy_WSTD_DL3Y::cVar_lKtwe9o7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 100.0f, 0, m, &cBinop_oP1cMgkr_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_ZMcNizKW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_COS, m, &cUnop_5BLKNI4c_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_NSKxL8CB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_SIN, m, &cUnop_FkRbY7Sg_sendMessage);
}

void Heavy_WSTD_DL3Y::cSend_1VtdEvJz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_wETDpJeQ_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cSend_fFH44sqc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_OrQQzB3r_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cSend_5hElGoEf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_gBpW5Yt5_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cMsg_GZxJ9itM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_1VPtOkhe_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_1VPtOkhe_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_JWftv52H, HV_BINOP_MULTIPLY, 1, m, &cBinop_JWftv52H_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_JWftv52H_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_FcIfCSE2_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_FcIfCSE2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_5hElGoEf_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cMsg_v7r9gjL4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_xsUcr03d_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_xsUcr03d_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_tgfJCrwu_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_nw4WTmee_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_wZbcwqp8_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_BiIETRf6_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_7RgHcQLH_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_IWMRAu86_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_fhG4unvs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_SZA7YopI_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_aQpvluoe_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_K75Z9AJA_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_AgQ3wfAS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_8obj9dt0_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_sGCv4nUW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_75rSvAUM_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_ccucuBVU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_FAqXmbBp_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cCast_wYiHO5jJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_xwHJrqs3, 0, m, &cVar_xwHJrqs3_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_YQCPmZO7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_lKtwe9o7, 1, m, &cVar_lKtwe9o7_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_IWMRAu86_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_fhG4unvs, HV_BINOP_MULTIPLY, 0, m, &cBinop_fhG4unvs_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_wZbcwqp8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_sGCv4nUW, HV_BINOP_MULTIPLY, 0, m, &cBinop_sGCv4nUW_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_7RgHcQLH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_aQpvluoe, HV_BINOP_MULTIPLY, 0, m, &cBinop_aQpvluoe_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_nw4WTmee_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_ccucuBVU, HV_BINOP_MULTIPLY, 0, m, &cBinop_ccucuBVU_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_BiIETRf6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_AgQ3wfAS, HV_BINOP_MULTIPLY, 0, m, &cBinop_AgQ3wfAS_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_tgfJCrwu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
}

void Heavy_WSTD_DL3Y::cCast_xdMTZV1B_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_x1KRpgEx, 0, m, &cVar_x1KRpgEx_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_eYFGR3IX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_lKtwe9o7, 0, m, &cVar_lKtwe9o7_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_vzy2bT6Z_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_4bTJu7xk, 1, m, &cIf_4bTJu7xk_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_tbErxyTV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  sVarf_onMessage(_c, &Context(_c)->sVarf_viQfCm71, m);
}

void Heavy_WSTD_DL3Y::cBinop_RwkFbpjc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_tbErxyTV_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_66WNNtGt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_4bTJu7xk, 0, m, &cIf_4bTJu7xk_sendMessage);
}

void Heavy_WSTD_DL3Y::cSwitchcase_85Y7tAi8_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0xE9AAC520: { // "midfreq"
      cSlice_onMessage(_c, &Context(_c)->cSlice_E4bM5iKW, 0, m, &cSlice_E4bM5iKW_sendMessage);
      break;
    }
    default: {
      cSwitchcase_MvxJnxET_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_DL3Y::cSlice_E4bM5iKW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_MxZUfq4j_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_MxZUfq4j_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cVar_zFFsgIX5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_MxZUfq4j_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cSend_MxZUfq4j_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_8vSBaZHa_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cVar_sxS9dKVH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_Fftgmds9_sendMessage);
  cIf_onMessage(_c, &Context(_c)->cIf_7cmenJaz, 0, m, &cIf_7cmenJaz_sendMessage);
}

void Heavy_WSTD_DL3Y::cIf_7cmenJaz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_44GWauQt_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cIf_96ObpMgo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cMsg_ueA0bn8i_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 485.0f, 0, m, &cBinop_yhQD6fKF_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cMsg_8SqEGIjT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 10.0f);
  cBinop_onMessage(_c, &Context(_c)->cBinop_tqb0TFV1, HV_BINOP_POW, 0, m, &cBinop_tqb0TFV1_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_tqb0TFV1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_MZ8aoq6N, 0, m, &cIf_MZ8aoq6N_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_J9tynJeW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 20.0f, 0, m, &cBinop_BQiarm9v_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_8UBieuIy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_C9o7HpSQ_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_fa9y0MbS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_96ObpMgo, 0, m, &cIf_96ObpMgo_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_C9o7HpSQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_96ObpMgo, 1, m, &cIf_96ObpMgo_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_yhQD6fKF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 100.0f, 0, m, &cBinop_J9tynJeW_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_ueA0bn8i_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cIf_onMessage(_c, &Context(_c)->cIf_MZ8aoq6N, 0, m, &cIf_MZ8aoq6N_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_BQiarm9v_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_tqb0TFV1, HV_BINOP_POW, 1, m, &cBinop_tqb0TFV1_sendMessage);
  cMsg_8SqEGIjT_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cIf_MZ8aoq6N_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      sVarf_onMessage(_c, &Context(_c)->sVarf_F5JT6qfq, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cBinop_Fftgmds9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_7cmenJaz, 1, m, &cIf_7cmenJaz_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_44GWauQt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_zJnpuH61, HV_BINOP_GREATER_THAN, 1, m, &cBinop_zJnpuH61_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_2k6gY18S, HV_BINOP_EQ, 1, m, &cBinop_2k6gY18S_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_FJVpNNOt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 100.0f);
  cBinop_onMessage(_c, &Context(_c)->cBinop_H5zEtxvj, HV_BINOP_ADD, 0, m, &cBinop_H5zEtxvj_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_H5zEtxvj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_8UBieuIy_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_fa9y0MbS_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_zJnpuH61_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_MZ8aoq6N, 1, m, &cIf_MZ8aoq6N_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_2k6gY18S_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_fltgwWLG_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cMsg_fltgwWLG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  sVarf_onMessage(_c, &Context(_c)->sVarf_F5JT6qfq, m);
}

void Heavy_WSTD_DL3Y::cCast_vehAzyNZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_FJVpNNOt_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cCast_XpZ8J0nj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_H5zEtxvj, HV_BINOP_ADD, 1, m, &cBinop_H5zEtxvj_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_zJnpuH61, HV_BINOP_GREATER_THAN, 0, m, &cBinop_zJnpuH61_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_2k6gY18S, HV_BINOP_EQ, 0, m, &cBinop_2k6gY18S_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_SDV9UpoW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_sxS9dKVH, 0, m, &cVar_sxS9dKVH_sendMessage);
}

void Heavy_WSTD_DL3Y::cVar_zo4jBNa3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_01XHZHT4_sendMessage);
  cIf_onMessage(_c, &Context(_c)->cIf_jjHY2q1Z, 0, m, &cIf_jjHY2q1Z_sendMessage);
}

void Heavy_WSTD_DL3Y::cIf_jjHY2q1Z_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_iXjHQVCs_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cIf_aSpSwsTX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cMsg_e3TbamEx_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 485.0f, 0, m, &cBinop_k2DTshy2_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cMsg_FvLQhmKz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 10.0f);
  cBinop_onMessage(_c, &Context(_c)->cBinop_5Izq9MTd, HV_BINOP_POW, 0, m, &cBinop_5Izq9MTd_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_5Izq9MTd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_m448xVDZ, 0, m, &cIf_m448xVDZ_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_dpojhWkk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 20.0f, 0, m, &cBinop_p3d6g7Fa_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_NEubV97M_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_jvxvSm17_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_sE7uT2Ho_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_aSpSwsTX, 0, m, &cIf_aSpSwsTX_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_jvxvSm17_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_aSpSwsTX, 1, m, &cIf_aSpSwsTX_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_k2DTshy2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 100.0f, 0, m, &cBinop_dpojhWkk_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_e3TbamEx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cIf_onMessage(_c, &Context(_c)->cIf_m448xVDZ, 0, m, &cIf_m448xVDZ_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_p3d6g7Fa_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_5Izq9MTd, HV_BINOP_POW, 1, m, &cBinop_5Izq9MTd_sendMessage);
  cMsg_FvLQhmKz_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cIf_m448xVDZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_IDm6uOfz_sendMessage);
      cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_p9LtpquN_sendMessage);
      cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 0.0313f, 0, m, &cBinop_Bzhk6Xlm_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cBinop_01XHZHT4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_jjHY2q1Z, 1, m, &cIf_jjHY2q1Z_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_iXjHQVCs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_URMkwB4c, HV_BINOP_GREATER_THAN, 1, m, &cBinop_URMkwB4c_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_gQHZNbFK, HV_BINOP_EQ, 1, m, &cBinop_gQHZNbFK_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_P6gGtO5g_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 100.0f);
  cBinop_onMessage(_c, &Context(_c)->cBinop_9WbtpD27, HV_BINOP_ADD, 0, m, &cBinop_9WbtpD27_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_9WbtpD27_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_NEubV97M_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_sE7uT2Ho_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_URMkwB4c_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_m448xVDZ, 1, m, &cIf_m448xVDZ_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_gQHZNbFK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_S0U0wYZN_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cMsg_S0U0wYZN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_IDm6uOfz_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_p9LtpquN_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 0.0313f, 0, m, &cBinop_Bzhk6Xlm_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_mPeD2e2W_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_zo4jBNa3, 0, m, &cVar_zo4jBNa3_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_Kqjn2cPF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_P6gGtO5g_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cCast_ydb0LzKC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_9WbtpD27, HV_BINOP_ADD, 1, m, &cBinop_9WbtpD27_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_URMkwB4c, HV_BINOP_GREATER_THAN, 0, m, &cBinop_URMkwB4c_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_gQHZNbFK, HV_BINOP_EQ, 0, m, &cBinop_gQHZNbFK_sendMessage);
}

void Heavy_WSTD_DL3Y::cVar_N8VtPLd8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_r1gnrMHb_sendMessage);
  cIf_onMessage(_c, &Context(_c)->cIf_qJulZYwT, 0, m, &cIf_qJulZYwT_sendMessage);
}

void Heavy_WSTD_DL3Y::cIf_qJulZYwT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_O6Sh4CD1_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cIf_9b1B416r_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cMsg_2T9CRtnb_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 485.0f, 0, m, &cBinop_6L7mgF0Z_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cMsg_qAT0YiCT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 10.0f);
  cBinop_onMessage(_c, &Context(_c)->cBinop_BGbTixHb, HV_BINOP_POW, 0, m, &cBinop_BGbTixHb_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_BGbTixHb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_pvDccJ1I, 0, m, &cIf_pvDccJ1I_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_K5zFPAT4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 20.0f, 0, m, &cBinop_a5E9mbQP_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_U3UR59It_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_2kRaME1h_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_z93Db6Fd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_9b1B416r, 0, m, &cIf_9b1B416r_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_2kRaME1h_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_9b1B416r, 1, m, &cIf_9b1B416r_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_6L7mgF0Z_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 100.0f, 0, m, &cBinop_K5zFPAT4_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_2T9CRtnb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cIf_onMessage(_c, &Context(_c)->cIf_pvDccJ1I, 0, m, &cIf_pvDccJ1I_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_a5E9mbQP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_BGbTixHb, HV_BINOP_POW, 1, m, &cBinop_BGbTixHb_sendMessage);
  cMsg_qAT0YiCT_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cIf_pvDccJ1I_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      sVarf_onMessage(_c, &Context(_c)->sVarf_Zu64IzXV, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cBinop_r1gnrMHb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_qJulZYwT, 1, m, &cIf_qJulZYwT_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_O6Sh4CD1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_SjmRLhJO, HV_BINOP_GREATER_THAN, 1, m, &cBinop_SjmRLhJO_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_y1CpaR9W, HV_BINOP_EQ, 1, m, &cBinop_y1CpaR9W_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_cSXh4YHg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 100.0f);
  cBinop_onMessage(_c, &Context(_c)->cBinop_ROIfKv89, HV_BINOP_ADD, 0, m, &cBinop_ROIfKv89_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_ROIfKv89_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_U3UR59It_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_z93Db6Fd_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_SjmRLhJO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_pvDccJ1I, 1, m, &cIf_pvDccJ1I_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_y1CpaR9W_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_nIOaEHwl_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cMsg_nIOaEHwl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  sVarf_onMessage(_c, &Context(_c)->sVarf_Zu64IzXV, m);
}

void Heavy_WSTD_DL3Y::cCast_6LdahSVH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_cSXh4YHg_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cCast_dvldP1PG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_ROIfKv89, HV_BINOP_ADD, 1, m, &cBinop_ROIfKv89_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_SjmRLhJO, HV_BINOP_GREATER_THAN, 0, m, &cBinop_SjmRLhJO_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_y1CpaR9W, HV_BINOP_EQ, 0, m, &cBinop_y1CpaR9W_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_kvaKNELy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_N8VtPLd8, 0, m, &cVar_N8VtPLd8_sendMessage);
}

void Heavy_WSTD_DL3Y::cIf_N2LeJ6tw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      sVarf_onMessage(_c, &Context(_c)->sVarf_N6VtI5QJ, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cSwitchcase_KVgikAdd_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x58220DA4: { // "highvol"
      cSlice_onMessage(_c, &Context(_c)->cSlice_xIVYbaiM, 0, m, &cSlice_xIVYbaiM_sendMessage);
      break;
    }
    default: {
      cSwitchcase_qyO7I9oX_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_DL3Y::cSlice_xIVYbaiM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_b21kEfTE_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_b21kEfTE_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cVar_k9O3uvFI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_b21kEfTE_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cSend_b21kEfTE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_idPyvD2n_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cSwitchcase_qyO7I9oX_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0xBDABF734: { // "midvol"
      cSlice_onMessage(_c, &Context(_c)->cSlice_w6byAorp, 0, m, &cSlice_w6byAorp_sendMessage);
      break;
    }
    default: {
      cSwitchcase_85Y7tAi8_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_DL3Y::cSlice_w6byAorp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_7OEzCmXa_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_7OEzCmXa_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cVar_MFUbvpCs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_7OEzCmXa_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cSend_7OEzCmXa_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_ASxy4lNE_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cSwitchcase_MvxJnxET_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x1FF74688: { // "lowvol"
      cSlice_onMessage(_c, &Context(_c)->cSlice_6kojTXGF, 0, m, &cSlice_6kojTXGF_sendMessage);
      break;
    }
    default: {
      cSwitchcase_fePTIjxP_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_DL3Y::cSlice_6kojTXGF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_sx2uSgAx_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_sx2uSgAx_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cVar_w6tysDjU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_sx2uSgAx_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cSend_sx2uSgAx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_dWeOKwMe_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cSwitchcase_fePTIjxP_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x98D37786: { // "midq"
      cSlice_onMessage(_c, &Context(_c)->cSlice_hGeA24cO, 0, m, &cSlice_hGeA24cO_sendMessage);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_WSTD_DL3Y::cSlice_hGeA24cO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_xghC6R4h_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_xghC6R4h_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cVar_0F1J0yQb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_xghC6R4h_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cSend_xghC6R4h_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_7NE2K9x4_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cMsg_maLFCtku_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_HfB4ww6h, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cMsg_kIZ2fxjn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_P76tzSnX, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cMsg_xFhd4ZGt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_IZDVhOxw, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cMsg_sPtnIFlo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_ddG77Yei, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cMsg_hPA90qoI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_kqeAIo9A, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cMsg_5KLLf38c_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_6iXLufMK_sendMessage);
}

void Heavy_WSTD_DL3Y::cSystem_6iXLufMK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_Tp8iJH74, HV_BINOP_DIVIDE, 1, m, &cBinop_Tp8iJH74_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_cePLMX4z_sendMessage);
}

void Heavy_WSTD_DL3Y::cUnop_zt3syw4L_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 8.0f, 0, m, &cBinop_rHr3s1ce_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_o3kaDT2b_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cUnop_onMessage(_c, HV_UNOP_ATAN, m, &cUnop_zt3syw4L_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_rHr3s1ce_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_Tp8iJH74, HV_BINOP_DIVIDE, 0, m, &cBinop_Tp8iJH74_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_cePLMX4z_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_o3kaDT2b_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_Tp8iJH74_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_EtFfvuHE, HV_BINOP_MULTIPLY, 1, m, &cBinop_EtFfvuHE_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_EtFfvuHE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_DuGh6VtG_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_FcecRd2h_sendMessage);
}

void Heavy_WSTD_DL3Y::cUnop_KYxhevVv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_T7ZM2Cu8_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cUnop_FBJjH18d_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_KqIorjPw_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_9UoKUsdR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 20.0f, 0, m, &cBinop_LtdvWlRy_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_LtdvWlRy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_EtFfvuHE, HV_BINOP_MULTIPLY, 0, m, &cBinop_EtFfvuHE_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_HjrcHUzm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.1f, 0, m, &cBinop_Ur78d6tC_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_Ur78d6tC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_ZfPU2On6_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_ft1GQeyG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_MC5wrDz1, 1, m, &cVar_MC5wrDz1_sendMessage);
}

void Heavy_WSTD_DL3Y::cVar_MC5wrDz1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_EBNi75rH_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_UhmQKjDx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_hFgrWqei, HV_BINOP_MULTIPLY, 1, m, &cBinop_hFgrWqei_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_TNfJZOkn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_UhmQKjDx_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_npZIzU75_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_2mXoVqmD_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_2mXoVqmD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_QFECBR5x, HV_BINOP_MULTIPLY, 1, m, &cBinop_QFECBR5x_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_NpFVRzrk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_nuSHHzV0, HV_BINOP_MULTIPLY, 1, m, &cBinop_nuSHHzV0_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_d6Jf5VvV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_NpFVRzrk_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_LLUOswtw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_2Mnuq0GL, HV_BINOP_MULTIPLY, 1, m, &cBinop_2Mnuq0GL_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_gxUyZ7jO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_1VsaaPqv_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_1VsaaPqv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_QE8DiOGa, HV_BINOP_MULTIPLY, 1, m, &cBinop_QE8DiOGa_sendMessage);
}

void Heavy_WSTD_DL3Y::cVar_AESlzgvs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_zAzxYYvx_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 20000.0f, 0, m, &cBinop_9UoKUsdR_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_ADqgsh87_sendMessage);
}

void Heavy_WSTD_DL3Y::cVar_Ib83oeb5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 100.0f, 0, m, &cBinop_HjrcHUzm_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_FcecRd2h_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_COS, m, &cUnop_FBJjH18d_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_DuGh6VtG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_SIN, m, &cUnop_KYxhevVv_sendMessage);
}

void Heavy_WSTD_DL3Y::cSend_T7ZM2Cu8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_hKoFRC98_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cSend_KqIorjPw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_EAARJt7o_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cSend_tW3HOaoB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_UUr3ft4L_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cMsg_ZfPU2On6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_LyW1yBoE_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_LyW1yBoE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_Dh2xty4y, HV_BINOP_MULTIPLY, 1, m, &cBinop_Dh2xty4y_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_Dh2xty4y_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_SIyhnGvj_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_SIyhnGvj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_tW3HOaoB_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cMsg_EBNi75rH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_3KtvWgU7_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_3KtvWgU7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_BzeSaNZt_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_JzoZtOIu_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_SHhoayWg_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_EZnRQ3kd_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_4kHGSDxK_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_8sNjVMla_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_hFgrWqei_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_maLFCtku_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_QFECBR5x_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_kIZ2fxjn_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_nuSHHzV0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_xFhd4ZGt_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_2Mnuq0GL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_sPtnIFlo_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_QE8DiOGa_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_hPA90qoI_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cCast_vYYU1tHo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_AESlzgvs, 0, m, &cVar_AESlzgvs_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_nfJnfpA9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_Ib83oeb5, 1, m, &cVar_Ib83oeb5_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_EZnRQ3kd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_nuSHHzV0, HV_BINOP_MULTIPLY, 0, m, &cBinop_nuSHHzV0_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_BzeSaNZt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
}

void Heavy_WSTD_DL3Y::cCast_8sNjVMla_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_hFgrWqei, HV_BINOP_MULTIPLY, 0, m, &cBinop_hFgrWqei_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_SHhoayWg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_2Mnuq0GL, HV_BINOP_MULTIPLY, 0, m, &cBinop_2Mnuq0GL_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_4kHGSDxK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_QFECBR5x, HV_BINOP_MULTIPLY, 0, m, &cBinop_QFECBR5x_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_JzoZtOIu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_QE8DiOGa, HV_BINOP_MULTIPLY, 0, m, &cBinop_QE8DiOGa_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_ADqgsh87_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_MC5wrDz1, 0, m, &cVar_MC5wrDz1_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_zAzxYYvx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_Ib83oeb5, 0, m, &cVar_Ib83oeb5_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_JJPZs3UO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_cOlEPnXL, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cMsg_bSP6yb7M_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_JCe7ynWW, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cMsg_DTPis0Pv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_eczXoPdH, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cMsg_voPanNNq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_K1qlTqpL, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cMsg_RyWSmM2b_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_EWn3UMgY_sendMessage);
}

void Heavy_WSTD_DL3Y::cSystem_EWn3UMgY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_e8NWAyBw, HV_BINOP_DIVIDE, 1, m, &cBinop_e8NWAyBw_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_gY0Bj15X_sendMessage);
}

void Heavy_WSTD_DL3Y::cUnop_lRtrS6Tq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 8.0f, 0, m, &cBinop_dYHrN79t_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_05U2QfDI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cUnop_onMessage(_c, HV_UNOP_ATAN, m, &cUnop_lRtrS6Tq_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_dYHrN79t_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_e8NWAyBw, HV_BINOP_DIVIDE, 0, m, &cBinop_e8NWAyBw_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_gY0Bj15X_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_05U2QfDI_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_e8NWAyBw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_m6GiX6bD, HV_BINOP_MULTIPLY, 1, m, &cBinop_m6GiX6bD_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_m6GiX6bD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_a0GDedC4_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_EzdYqorJ_sendMessage);
}

void Heavy_WSTD_DL3Y::cUnop_NJxFCrnc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_32jdq51t_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cUnop_iHbeRm4p_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_tnLNLbLS_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_r8lKB31F_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 20.0f, 0, m, &cBinop_J3gWYnh2_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_J3gWYnh2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_m6GiX6bD, HV_BINOP_MULTIPLY, 0, m, &cBinop_m6GiX6bD_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_7NgxMbUO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.1f, 0, m, &cBinop_QyL1Mp7j_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_QyL1Mp7j_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_qbychHqX_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_IPd3r4jF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_2MRoimdR, HV_BINOP_MULTIPLY, 1, m, &cBinop_2MRoimdR_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_cLCw8TId_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_xVD1HWdo, 1, m, &cVar_xVD1HWdo_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_yg95cEHn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_zomzDO1d, HV_BINOP_MULTIPLY, 1, m, &cBinop_zomzDO1d_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_PLeIFQXr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_inoMcAK8_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_inoMcAK8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_qzX4EgwF, HV_BINOP_MULTIPLY, 1, m, &cBinop_qzX4EgwF_sendMessage);
}

void Heavy_WSTD_DL3Y::cVar_xVD1HWdo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_LrwnAiUh_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cVar_15keEgoi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_3HYzClID_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 20000.0f, 0, m, &cBinop_r8lKB31F_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_vZNQ9Yno_sendMessage);
}

void Heavy_WSTD_DL3Y::cVar_KNbhaNdW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 100.0f, 0, m, &cBinop_7NgxMbUO_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_EzdYqorJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_COS, m, &cUnop_iHbeRm4p_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_a0GDedC4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_SIN, m, &cUnop_NJxFCrnc_sendMessage);
}

void Heavy_WSTD_DL3Y::cSend_32jdq51t_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_QLhkeuJu_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cSend_tnLNLbLS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_6tBqTAYJ_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cSend_xvDObzsx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_ikRfXfWV_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cMsg_qbychHqX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_dS3SptpF_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_dS3SptpF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_PI85FqLh, HV_BINOP_MULTIPLY, 1, m, &cBinop_PI85FqLh_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_PI85FqLh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_uAxW04MU_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_uAxW04MU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_xvDObzsx_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cMsg_LrwnAiUh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_vtkyq4oa_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_vtkyq4oa_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_jjmNWJr8_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_s9qxjosc_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_uq6WxMId_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_zx9gFQgN_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_1GqZGE1O_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_JJPZs3UO_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_2MRoimdR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_bSP6yb7M_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_zomzDO1d_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_DTPis0Pv_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_qzX4EgwF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_voPanNNq_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cCast_jA0iGdk2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_15keEgoi, 0, m, &cVar_15keEgoi_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_mm9Qmmir_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_KNbhaNdW, 1, m, &cVar_KNbhaNdW_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_vZNQ9Yno_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_xVD1HWdo, 0, m, &cVar_xVD1HWdo_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_3HYzClID_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_KNbhaNdW, 0, m, &cVar_KNbhaNdW_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_s9qxjosc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_zomzDO1d, HV_BINOP_MULTIPLY, 0, m, &cBinop_zomzDO1d_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_zx9gFQgN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_1GqZGE1O, HV_BINOP_MULTIPLY, 0, m, &cBinop_1GqZGE1O_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_jjmNWJr8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_qzX4EgwF, HV_BINOP_MULTIPLY, 0, m, &cBinop_qzX4EgwF_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_uq6WxMId_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_2MRoimdR, HV_BINOP_MULTIPLY, 0, m, &cBinop_2MRoimdR_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_05w8d3yA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_aa567uGa, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cMsg_Tkr3NlIa_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_UnkWnMXA, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cMsg_bGqJQqIN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_CzVHHzoo, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cMsg_gN8u5dg2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_cxRAF4cy, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cMsg_bsiozvCN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_mm6FaRHO, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cMsg_Zt3zo1zd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_J2rELvAw_sendMessage);
}

void Heavy_WSTD_DL3Y::cSystem_J2rELvAw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_vb5u4tKk, HV_BINOP_DIVIDE, 1, m, &cBinop_vb5u4tKk_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_yIV1VqQW_sendMessage);
}

void Heavy_WSTD_DL3Y::cUnop_2WuFENwG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 8.0f, 0, m, &cBinop_Sn9AVGHC_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_WpD1iyvu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cUnop_onMessage(_c, HV_UNOP_ATAN, m, &cUnop_2WuFENwG_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_Sn9AVGHC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_vb5u4tKk, HV_BINOP_DIVIDE, 0, m, &cBinop_vb5u4tKk_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_yIV1VqQW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_WpD1iyvu_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_vb5u4tKk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_ITmgD6O1, HV_BINOP_MULTIPLY, 1, m, &cBinop_ITmgD6O1_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_ITmgD6O1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_iW4vphSy_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_rCQUCkmd_sendMessage);
}

void Heavy_WSTD_DL3Y::cUnop_yh4L5jQJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_zRYiDQFL_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cUnop_fJfAL0Z9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_VGKPNYsf_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_YuTvuBtX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 20.0f, 0, m, &cBinop_MGBhoOUX_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_MGBhoOUX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_ITmgD6O1, HV_BINOP_MULTIPLY, 0, m, &cBinop_ITmgD6O1_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_nggMfIwE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.1f, 0, m, &cBinop_yHKc2O3X_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_yHKc2O3X_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_6fmjbItd_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_DctOl9mp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_EmcqZM1z, HV_BINOP_MULTIPLY, 1, m, &cBinop_EmcqZM1z_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_v4uW9i0h_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_4sQgkPyJ_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_4sQgkPyJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_DctOl9mp_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_8sejfpAl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_frjo2ApW_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_frjo2ApW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_nvmfBnWe, HV_BINOP_MULTIPLY, 1, m, &cBinop_nvmfBnWe_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_LRRG9OzC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_B9cObZUZ, HV_BINOP_MULTIPLY, 1, m, &cBinop_B9cObZUZ_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_kIgmrC2p_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_bYFFb6dV_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_bYFFb6dV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_LRRG9OzC_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_T4ncjAwp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_0kzTP1Nj, 1, m, &cVar_0kzTP1Nj_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_GVl3VQyP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_1MlXChJO, HV_BINOP_MULTIPLY, 1, m, &cBinop_1MlXChJO_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_YkHi3Bn0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_kOXUqSRb_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_kOXUqSRb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_BtCIuCKq, HV_BINOP_MULTIPLY, 1, m, &cBinop_BtCIuCKq_sendMessage);
}

void Heavy_WSTD_DL3Y::cVar_0kzTP1Nj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_0WBD0i9C_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cVar_6yCMuDdD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_pwaR4pV9_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 20000.0f, 0, m, &cBinop_YuTvuBtX_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_fReZlZSP_sendMessage);
}

void Heavy_WSTD_DL3Y::cVar_Snwo4J33_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 100.0f, 0, m, &cBinop_nggMfIwE_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_rCQUCkmd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_COS, m, &cUnop_fJfAL0Z9_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_iW4vphSy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_SIN, m, &cUnop_yh4L5jQJ_sendMessage);
}

void Heavy_WSTD_DL3Y::cSend_zRYiDQFL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_M96gQdAE_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cSend_VGKPNYsf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_JlkWrMyG_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cSend_BWjP4iGO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_FOKuksaM_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cMsg_6fmjbItd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_u3SPaIgg_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_u3SPaIgg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_RusIjfmo, HV_BINOP_MULTIPLY, 1, m, &cBinop_RusIjfmo_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_RusIjfmo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_Voxt7Qcv_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_Voxt7Qcv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_BWjP4iGO_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cMsg_0WBD0i9C_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_t33EtN4q_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_t33EtN4q_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_SJUw6w5k_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_fXJphsbG_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_IiNUsFnF_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_wBWufg7S_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_EgL6iQTN_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_2FOwtcEd_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_EmcqZM1z_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_05w8d3yA_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_nvmfBnWe_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_Tkr3NlIa_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_B9cObZUZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_bGqJQqIN_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_1MlXChJO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_gN8u5dg2_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_BtCIuCKq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_bsiozvCN_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cCast_srL7miQA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_6yCMuDdD, 0, m, &cVar_6yCMuDdD_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_NOvUsGUs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_Snwo4J33, 1, m, &cVar_Snwo4J33_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_IiNUsFnF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_1MlXChJO, HV_BINOP_MULTIPLY, 0, m, &cBinop_1MlXChJO_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_EgL6iQTN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_nvmfBnWe, HV_BINOP_MULTIPLY, 0, m, &cBinop_nvmfBnWe_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_fXJphsbG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_BtCIuCKq, HV_BINOP_MULTIPLY, 0, m, &cBinop_BtCIuCKq_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_wBWufg7S_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_B9cObZUZ, HV_BINOP_MULTIPLY, 0, m, &cBinop_B9cObZUZ_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_SJUw6w5k_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
}

void Heavy_WSTD_DL3Y::cCast_2FOwtcEd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_EmcqZM1z, HV_BINOP_MULTIPLY, 0, m, &cBinop_EmcqZM1z_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_fReZlZSP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_0kzTP1Nj, 0, m, &cVar_0kzTP1Nj_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_pwaR4pV9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_Snwo4J33, 0, m, &cVar_Snwo4J33_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_IDm6uOfz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_N2LeJ6tw, 1, m, &cIf_N2LeJ6tw_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_8DeNI6ry_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  sVarf_onMessage(_c, &Context(_c)->sVarf_N6VtI5QJ, m);
}

void Heavy_WSTD_DL3Y::cBinop_p9LtpquN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_8DeNI6ry_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_Bzhk6Xlm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_N2LeJ6tw, 0, m, &cIf_N2LeJ6tw_sendMessage);
}

void Heavy_WSTD_DL3Y::cVar_gXNwFj6J_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_V4kMugRJ, HV_BINOP_DIVIDE, 0, m, &cBinop_V4kMugRJ_sendMessage);
}

void Heavy_WSTD_DL3Y::cVar_NiA5OsPT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_Xngz0Bhp, HV_BINOP_DIVIDE, 1, m, &cBinop_Xngz0Bhp_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_V4kMugRJ, HV_BINOP_DIVIDE, 1, m, &cBinop_V4kMugRJ_sendMessage);
}

void Heavy_WSTD_DL3Y::cUnop_ka7ZjEoG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_jRidER1c, HV_BINOP_DIVIDE, 0, m, &cBinop_jRidER1c_sendMessage);
}

void Heavy_WSTD_DL3Y::cUnop_VsOcU8Rb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_jRidER1c, HV_BINOP_DIVIDE, 1, m, &cBinop_jRidER1c_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_GmZTFMkN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_gXNwFj6J, 0, m, &cVar_gXNwFj6J_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_ieBVU4Ic_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_NiA5OsPT, 0, m, &cVar_NiA5OsPT_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_1T7KgycQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_Xngz0Bhp, HV_BINOP_DIVIDE, 0, m, &cBinop_Xngz0Bhp_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_Xngz0Bhp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_LOG, m, &cUnop_ka7ZjEoG_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_V4kMugRJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_LOG, m, &cUnop_VsOcU8Rb_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_jRidER1c_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 2.0f, 0, m, &cBinop_MjzRoxKn_sendMessage);
}

void Heavy_WSTD_DL3Y::cUnop_26AXrNhd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 0.313f, 0, m, &cBinop_tIXiYLwC_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_5YdDQn8v_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.313f, 0, m, &cBinop_r7RjgPQu_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_MjzRoxKn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_5YdDQn8v_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_r7RjgPQu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_ABS, m, &cUnop_26AXrNhd_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_tIXiYLwC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_X4SqjULN_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cVar_01QURJwf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_tL3Ix4La_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cVar_hA54wfHY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_PJxxQovH_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cVar_o2G2AgAP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_j6IlEQHG_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cVar_CFsMZjiS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_DeuFJQTD_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cVar_QQdUhnd1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_ZcI23LS7_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cVar_FiWHpum8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_uewRwhk6_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cVar_o7IHboxy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_2NcsGtCh_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cVar_0us5sJa8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_DrYqhLK8_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cVar_DCV0EudC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_4tRZvW6z_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cVar_igTw5lsY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_beYweui3_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cVar_zIqMPq9n_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_9YWiI0BX_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cVar_XFPMxAe8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_OH1SbBPX_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cSwitchcase_rZFmwZQh_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x764F1C36: { // "mix"
      cSlice_onMessage(_c, &Context(_c)->cSlice_UFTbYkUS, 0, m, &cSlice_UFTbYkUS_sendMessage);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_WSTD_DL3Y::cSlice_UFTbYkUS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_MmzYbj4f_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_MmzYbj4f_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cVar_n68XL8JM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_MmzYbj4f_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cSend_MmzYbj4f_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_mpZs7deU_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cSwitchcase_VQUJ8MAU_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0xC8CCFEC1: { // "cross"
      cSlice_onMessage(_c, &Context(_c)->cSlice_vthgGoXI, 0, m, &cSlice_vthgGoXI_sendMessage);
      break;
    }
    default: {
      cSwitchcase_LYyy35xL_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_DL3Y::cSlice_vthgGoXI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_kDM54Eg1_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_kDM54Eg1_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cVar_wuegmjRK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_kDM54Eg1_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cSend_kDM54Eg1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_V4fO0Zpk_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cSwitchcase_8RkfGaD5_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x8E55AA5F: { // "time"
      cSlice_onMessage(_c, &Context(_c)->cSlice_pS3FmVA8, 0, m, &cSlice_pS3FmVA8_sendMessage);
      break;
    }
    default: {
      cSwitchcase_rZFmwZQh_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_DL3Y::cSlice_pS3FmVA8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_DpQG0lmL_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_DpQG0lmL_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cVar_OQKpa1tm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_DpQG0lmL_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cSend_DpQG0lmL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_ZTVhANfK_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_pQPGdTj0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.0f, 0, m, &cBinop_qmKqWHqU_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_qmKqWHqU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 2.0f, 0, m, &cBinop_AqlKVHD2_sendMessage);
}

void Heavy_WSTD_DL3Y::cUnop_OBiPndqO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_ZnCK44JL_sendMessage(_c, 0, m);
  cMsg_kSWB7s9e_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cUnop_hK3zyAxf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_l5EAZoNK_sendMessage(_c, 0, m);
  cMsg_hKV5zIRd_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_AqlKVHD2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_po9S63WU_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_po9S63WU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_Hg6oTZfg_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_0gGTGl5F_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_0gGTGl5F_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_HcXKwU0u_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cCast_Hg6oTZfg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_PcUWTitO_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_PcUWTitO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_zNPavnSq_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_HcXKwU0u_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_dgKJElop_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_dgKJElop_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_jInztosD_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_zNPavnSq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_SQRT, m, &cUnop_OBiPndqO_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_jInztosD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_SQRT, m, &cUnop_hK3zyAxf_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_IU4V3FLq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.0f, 0, m, &cBinop_mFNhrd5R_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_mFNhrd5R_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 2.0f, 0, m, &cBinop_PyXYmJuJ_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_PyXYmJuJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_A70L5yW6_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_A70L5yW6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_9waALjGq_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_fqSChrLm_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_fqSChrLm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_hwObJCGg_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cCast_9waALjGq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_CRFSZ7u2_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_CRFSZ7u2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_qVS1c3Si_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_hwObJCGg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_rdFRajEU_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_rdFRajEU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_lVhoPKpF_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_lVhoPKpF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_VEvcbAA4_sendMessage(_c, 0, m);
  cMsg_VIbvgNkA_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_qVS1c3Si_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_vFBGAjLm_sendMessage(_c, 0, m);
  cMsg_hmQMrNCZ_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_ojhwNXtG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.0f, 0, m, &cBinop_gnVk70jG_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_gnVk70jG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_dc39YQp8_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_52fby9YO_sendMessage);
}

void Heavy_WSTD_DL3Y::cVar_dmzwSFPG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 1.0f, 0, m, &cBinop_dJnCwprp_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_l7537s4j_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_CtSHUsDh_sendMessage);
}

void Heavy_WSTD_DL3Y::cSystem_CtSHUsDh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_gYAJuBq5, HV_BINOP_DIVIDE, 1, m, &cBinop_gYAJuBq5_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_dc39YQp8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_ws7rCwJL_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_ws7rCwJL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_3iu4WzHj, m);
}

void Heavy_WSTD_DL3Y::cMsg_xywEANvu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_HvZL4BXF_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_HvZL4BXF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 1.0f, 0, m, &cBinop_ojhwNXtG_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_52fby9YO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_xEsqNN4C, m);
}

void Heavy_WSTD_DL3Y::cBinop_dJnCwprp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 6.28319f, 0, m, &cBinop_CQBPIfKV_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_CQBPIfKV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_gYAJuBq5, HV_BINOP_DIVIDE, 0, m, &cBinop_gYAJuBq5_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_gYAJuBq5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_xywEANvu_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_BgSqoXih_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.0f, 0, m, &cBinop_hggnOX1C_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_hggnOX1C_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_dk7t9LpD_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_zPo9toFF_sendMessage);
}

void Heavy_WSTD_DL3Y::cVar_uBowDlEC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 1.0f, 0, m, &cBinop_csriK42y_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_zA3wx9eW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_UF1ZezMg_sendMessage);
}

void Heavy_WSTD_DL3Y::cSystem_UF1ZezMg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_9W1DrDYl, HV_BINOP_DIVIDE, 1, m, &cBinop_9W1DrDYl_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_dk7t9LpD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_RqDlxCo9_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_RqDlxCo9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_k6pZXZGP, m);
}

void Heavy_WSTD_DL3Y::cMsg_aXxFS3Qv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_c2M1g2T0_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_c2M1g2T0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 1.0f, 0, m, &cBinop_BgSqoXih_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_zPo9toFF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_dl1kc3ny, m);
}

void Heavy_WSTD_DL3Y::cBinop_csriK42y_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 6.28319f, 0, m, &cBinop_T3fercB4_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_T3fercB4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_9W1DrDYl, HV_BINOP_DIVIDE, 0, m, &cBinop_9W1DrDYl_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_9W1DrDYl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_aXxFS3Qv_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cVar_866JjA7K_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_e3rbAcTT, HV_BINOP_MULTIPLY, 0, m, &cBinop_e3rbAcTT_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_EIBJvzgN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_UAUpf56e_sendMessage);
}

void Heavy_WSTD_DL3Y::cSystem_UAUpf56e_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_9VbvRaj4_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_e3rbAcTT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 1.0f, 0, m, &cBinop_iQA4puwd_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_mgAMkro6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_e3rbAcTT, HV_BINOP_MULTIPLY, 1, m, &cBinop_e3rbAcTT_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_9VbvRaj4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 6.28319f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_mgAMkro6_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_iQA4puwd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.0f, 0, m, &cBinop_RSSJvuNU_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_RSSJvuNU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_xFqS3v9i_sendMessage);
  sVarf_onMessage(_c, &Context(_c)->sVarf_uBA11AWp, m);
}

void Heavy_WSTD_DL3Y::cBinop_xFqS3v9i_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_dUh8nEid, m);
}

void Heavy_WSTD_DL3Y::cVar_TKACTgDx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_gnClQd7V, HV_BINOP_MULTIPLY, 0, m, &cBinop_gnClQd7V_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_DjFPkLfy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_Cv8eCN0C_sendMessage);
}

void Heavy_WSTD_DL3Y::cSystem_Cv8eCN0C_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_XVQ7R5Gi_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_gnClQd7V_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 1.0f, 0, m, &cBinop_WYDaTVkk_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_EE92QuF0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_gnClQd7V, HV_BINOP_MULTIPLY, 1, m, &cBinop_gnClQd7V_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_XVQ7R5Gi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 6.28319f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_EE92QuF0_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_WYDaTVkk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.0f, 0, m, &cBinop_VcjbNGtP_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_VcjbNGtP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_W2brHvIR_sendMessage);
  sVarf_onMessage(_c, &Context(_c)->sVarf_ffUJFP7F, m);
}

void Heavy_WSTD_DL3Y::cBinop_W2brHvIR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_nTEgW7ey, m);
}

void Heavy_WSTD_DL3Y::sEnv_SwBoBkWr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_HNFaGp2Q_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_c3USVz7C_sendMessage);
}

void Heavy_WSTD_DL3Y::cIf_8WLQE0LY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cMsg_Epl9iBWF_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 485.0f, 0, m, &cBinop_7FiqsjUu_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cMsg_0qgxI2nh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 10.0f);
  cBinop_onMessage(_c, &Context(_c)->cBinop_dsdvZHBO, HV_BINOP_POW, 0, m, &cBinop_dsdvZHBO_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_dsdvZHBO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_OTY1bpGU_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_3iWGpmO3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 20.0f, 0, m, &cBinop_P1qyihh6_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_HNFaGp2Q_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_US6V7VQD_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_c3USVz7C_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_8WLQE0LY, 0, m, &cIf_8WLQE0LY_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_US6V7VQD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_8WLQE0LY, 1, m, &cIf_8WLQE0LY_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_7FiqsjUu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 100.0f, 0, m, &cBinop_3iWGpmO3_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_Epl9iBWF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cMsg_OTY1bpGU_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_P1qyihh6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_dsdvZHBO, HV_BINOP_POW, 1, m, &cBinop_dsdvZHBO_sendMessage);
  cMsg_0qgxI2nh_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cVar_hCsFva0g_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_zIalCAqA, HV_BINOP_MULTIPLY, 0, m, &cBinop_zIalCAqA_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_0cu241lK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_fCeKS8S4_sendMessage);
}

void Heavy_WSTD_DL3Y::cSystem_fCeKS8S4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_eS1OO8yJ_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_zIalCAqA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 1.0f, 0, m, &cBinop_6Y9J6YY0_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_05Buaeqa_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_zIalCAqA, HV_BINOP_MULTIPLY, 1, m, &cBinop_zIalCAqA_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_eS1OO8yJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 6.28319f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_05Buaeqa_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_6Y9J6YY0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.0f, 0, m, &cBinop_TqhbrImd_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_TqhbrImd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_kl0rAIlt_sendMessage);
  sVarf_onMessage(_c, &Context(_c)->sVarf_jlEX39WW, m);
}

void Heavy_WSTD_DL3Y::cBinop_kl0rAIlt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_XqzjSTPr, m);
}

void Heavy_WSTD_DL3Y::cMsg_OTY1bpGU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_jBEppDLZ_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_jBEppDLZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_yby2x6zV, m);
}

void Heavy_WSTD_DL3Y::sEnv_0GawZaWN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_xoVCOkme_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_kxNDhbNv_sendMessage);
}

void Heavy_WSTD_DL3Y::cIf_sXHcUQJA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cMsg_mz9h4pJ9_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 485.0f, 0, m, &cBinop_M3ajv9Iy_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cMsg_FrxiIXWB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 10.0f);
  cBinop_onMessage(_c, &Context(_c)->cBinop_W4FFXJfj, HV_BINOP_POW, 0, m, &cBinop_W4FFXJfj_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_W4FFXJfj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_BVn8DpDj_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_59uSz3QJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 20.0f, 0, m, &cBinop_tecV3VZP_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_kxNDhbNv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_sXHcUQJA, 0, m, &cIf_sXHcUQJA_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_xoVCOkme_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_nX0n1SPv_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_nX0n1SPv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_sXHcUQJA, 1, m, &cIf_sXHcUQJA_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_M3ajv9Iy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 100.0f, 0, m, &cBinop_59uSz3QJ_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_mz9h4pJ9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cMsg_BVn8DpDj_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_tecV3VZP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_W4FFXJfj, HV_BINOP_POW, 1, m, &cBinop_W4FFXJfj_sendMessage);
  cMsg_FrxiIXWB_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cVar_g4lwAWIL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_Phahznev, HV_BINOP_MULTIPLY, 0, m, &cBinop_Phahznev_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_ywqiYwcW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_SgHQdkWu_sendMessage);
}

void Heavy_WSTD_DL3Y::cSystem_SgHQdkWu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_eHNOwRX9_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_Phahznev_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 1.0f, 0, m, &cBinop_YYachLUT_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_pC2N9DDT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_Phahznev, HV_BINOP_MULTIPLY, 1, m, &cBinop_Phahznev_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_eHNOwRX9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 6.28319f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_pC2N9DDT_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_YYachLUT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.0f, 0, m, &cBinop_HjX1nUHC_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_HjX1nUHC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_mwPi7Y3F_sendMessage);
  sVarf_onMessage(_c, &Context(_c)->sVarf_xWHUFUGs, m);
}

void Heavy_WSTD_DL3Y::cBinop_mwPi7Y3F_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_l5xzyGnw, m);
}

void Heavy_WSTD_DL3Y::cMsg_BVn8DpDj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_bsVepuzB_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_bsVepuzB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_hOdtiHRZ, m);
}

void Heavy_WSTD_DL3Y::cSwitchcase_LYyy35xL_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0xF1E7CD16: { // "feedback"
      cSlice_onMessage(_c, &Context(_c)->cSlice_0VJ2ALSo, 0, m, &cSlice_0VJ2ALSo_sendMessage);
      break;
    }
    default: {
      cSwitchcase_8RkfGaD5_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_DL3Y::cSlice_0VJ2ALSo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_ptilcGJa_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_ptilcGJa_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cVar_sZ8JogDs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_ptilcGJa_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cSend_ptilcGJa_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_1zBm6Ndd_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cMsg_g4050QOP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_7SjMmm0G_sendMessage);
}

void Heavy_WSTD_DL3Y::cSystem_7SjMmm0G_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_X2KoSpbg_sendMessage);
}

void Heavy_WSTD_DL3Y::cDelay_jLNF7Qu1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_jLNF7Qu1, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_K94inu2k, 0, m, &cDelay_K94inu2k_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_jLNF7Qu1, 0, m, &cDelay_jLNF7Qu1_sendMessage);
  sTabwrite_onMessage(_c, &Context(_c)->sTabwrite_s0NMdATY, 1, m, NULL);
}

void Heavy_WSTD_DL3Y::cDelay_K94inu2k_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_K94inu2k, m);
  cMsg_aR6fyFvG_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cSwitchcase_KunxlhX0_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x47BE8354: { // "clear"
      cMsg_yEbyYaVq_sendMessage(_c, 0, m);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_WSTD_DL3Y::cBinop_11DpLVlw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_383zmDCL_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::hTable_SuvEmq1G_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_iQPxXqD4_sendMessage(_c, 0, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_jLNF7Qu1, 2, m, &cDelay_jLNF7Qu1_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_WldO1xAF_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_383zmDCL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "resize");
  msg_setElementToFrom(m, 1, n, 0);
  hTable_onMessage(_c, &Context(_c)->hTable_SuvEmq1G, 0, m, &hTable_SuvEmq1G_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_X2KoSpbg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 5000.0f, 0, m, &cBinop_11DpLVlw_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_aR6fyFvG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "mirror");
  hTable_onMessage(_c, &Context(_c)->hTable_SuvEmq1G, 0, m, &hTable_SuvEmq1G_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_WldO1xAF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_jLNF7Qu1, 0, m, &cDelay_jLNF7Qu1_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_iQPxXqD4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0,  static_cast<float>(HV_N_SIMD));
  cDelay_onMessage(_c, &Context(_c)->cDelay_K94inu2k, 2, m, &cDelay_K94inu2k_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_yEbyYaVq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  sTabwrite_onMessage(_c, &Context(_c)->sTabwrite_s0NMdATY, 1, m, NULL);
}

void Heavy_WSTD_DL3Y::cTabhead_ZKU1HCrI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_LTBHBXMM, HV_BINOP_SUBTRACT, 0, m, &cBinop_LTBHBXMM_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_uYuiA0yP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_o0rxWU6w_sendMessage);
}

void Heavy_WSTD_DL3Y::cSystem_o0rxWU6w_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_RKV3A2vF_sendMessage);
}

void Heavy_WSTD_DL3Y::cVar_x88GL5B8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_onRaemnx_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cDelay_OxweR9Dr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_OxweR9Dr, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_ocuU38jM, 0, m, &cDelay_ocuU38jM_sendMessage);
  sTabread_onMessage(_c, &Context(_c)->sTabread_OvheTdEZ, 0, m, &sTabread_OvheTdEZ_sendMessage);
}

void Heavy_WSTD_DL3Y::cDelay_ocuU38jM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_ocuU38jM, m);
  sTabread_onMessage(_c, &Context(_c)->sTabread_OvheTdEZ, 0, m, &sTabread_OvheTdEZ_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_ocuU38jM, 0, m, &cDelay_ocuU38jM_sendMessage);
}

void Heavy_WSTD_DL3Y::sTabread_OvheTdEZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cBinop_onMessage(_c, &Context(_c)->cBinop_IJOrmDGy, HV_BINOP_SUBTRACT, 0, m, &cBinop_IJOrmDGy_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cBinop_rAooRakH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_NQGDeH9r, HV_BINOP_MAX, 0, m, &cBinop_NQGDeH9r_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_RKV3A2vF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_rAooRakH, HV_BINOP_MULTIPLY, 0, m, &cBinop_rAooRakH_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_LTBHBXMM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_ObERASOZ_sendMessage(_c, 0, m);
  sTabread_onMessage(_c, &Context(_c)->sTabread_OvheTdEZ, 0, m, &sTabread_OvheTdEZ_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_aRVQQnJo_sendMessage);
}

void Heavy_WSTD_DL3Y::cSystem_brmiP4sn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_IJOrmDGy, HV_BINOP_SUBTRACT, 1, m, &cBinop_IJOrmDGy_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_ocuU38jM, 2, m, &cDelay_ocuU38jM_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_onRaemnx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(3);
  msg_init(m, 3, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "table");
  msg_setElementToFrom(m, 1, n, 0);
  msg_setSymbol(m, 2, "size");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_brmiP4sn_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_ObERASOZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_OxweR9Dr, 0, m, &cDelay_OxweR9Dr_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_ocuU38jM, 0, m, &cDelay_ocuU38jM_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_s7sQGzLa_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0,  static_cast<float>(HV_N_SIMD));
  cBinop_onMessage(_c, &Context(_c)->cBinop_NQGDeH9r, HV_BINOP_MAX, 1, m, &cBinop_NQGDeH9r_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_NQGDeH9r_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_LTBHBXMM, HV_BINOP_SUBTRACT, 1, m, &cBinop_LTBHBXMM_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_aRVQQnJo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_OxweR9Dr, 0, m, &cDelay_OxweR9Dr_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_puFtm9FJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_OxweR9Dr, 2, m, &cDelay_OxweR9Dr_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_IJOrmDGy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_puFtm9FJ_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_oux6iRZQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_x88GL5B8, 0, m, &cVar_x88GL5B8_sendMessage);
  cMsg_uYuiA0yP_sendMessage(_c, 0, m);
  cTabhead_onMessage(_c, &Context(_c)->cTabhead_ZKU1HCrI, 0, m, &cTabhead_ZKU1HCrI_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_JCj8t1Zn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_dH7Q4qhR_sendMessage);
}

void Heavy_WSTD_DL3Y::cSystem_dH7Q4qhR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_t7IN8yZv_sendMessage);
}

void Heavy_WSTD_DL3Y::cDelay_HUy58zph_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_HUy58zph, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_Du2uwtV5, 0, m, &cDelay_Du2uwtV5_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_HUy58zph, 0, m, &cDelay_HUy58zph_sendMessage);
  sTabwrite_onMessage(_c, &Context(_c)->sTabwrite_lvfmg2UE, 1, m, NULL);
}

void Heavy_WSTD_DL3Y::cDelay_Du2uwtV5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_Du2uwtV5, m);
  cMsg_Sgw096Jm_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cSwitchcase_KGek7ENX_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x47BE8354: { // "clear"
      cMsg_mY54Bf7U_sendMessage(_c, 0, m);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_WSTD_DL3Y::cBinop_LWYleYbl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_Nu9tqleD_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::hTable_AFV9N3XC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_k9PHw0AO_sendMessage(_c, 0, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_HUy58zph, 2, m, &cDelay_HUy58zph_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_bzUHDLZm_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_Nu9tqleD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "resize");
  msg_setElementToFrom(m, 1, n, 0);
  hTable_onMessage(_c, &Context(_c)->hTable_AFV9N3XC, 0, m, &hTable_AFV9N3XC_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_t7IN8yZv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 5000.0f, 0, m, &cBinop_LWYleYbl_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_Sgw096Jm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "mirror");
  hTable_onMessage(_c, &Context(_c)->hTable_AFV9N3XC, 0, m, &hTable_AFV9N3XC_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_bzUHDLZm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_HUy58zph, 0, m, &cDelay_HUy58zph_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_k9PHw0AO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0,  static_cast<float>(HV_N_SIMD));
  cDelay_onMessage(_c, &Context(_c)->cDelay_Du2uwtV5, 2, m, &cDelay_Du2uwtV5_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_mY54Bf7U_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  sTabwrite_onMessage(_c, &Context(_c)->sTabwrite_lvfmg2UE, 1, m, NULL);
}

void Heavy_WSTD_DL3Y::cTabhead_hZDFpjvk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_E40b8Nme, HV_BINOP_SUBTRACT, 0, m, &cBinop_E40b8Nme_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_gvrV4clK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_WBPH1ooV_sendMessage);
}

void Heavy_WSTD_DL3Y::cSystem_WBPH1ooV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_1kLXPHWl_sendMessage);
}

void Heavy_WSTD_DL3Y::cVar_YFi9AuHy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_tGJBr6GO_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cDelay_MSZfvriF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_MSZfvriF, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_bmcB2JoE, 0, m, &cDelay_bmcB2JoE_sendMessage);
  sTabread_onMessage(_c, &Context(_c)->sTabread_8ctWDKfL, 0, m, &sTabread_8ctWDKfL_sendMessage);
}

void Heavy_WSTD_DL3Y::cDelay_bmcB2JoE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_bmcB2JoE, m);
  sTabread_onMessage(_c, &Context(_c)->sTabread_8ctWDKfL, 0, m, &sTabread_8ctWDKfL_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_bmcB2JoE, 0, m, &cDelay_bmcB2JoE_sendMessage);
}

void Heavy_WSTD_DL3Y::sTabread_8ctWDKfL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cBinop_onMessage(_c, &Context(_c)->cBinop_6Yv1l92u, HV_BINOP_SUBTRACT, 0, m, &cBinop_6Yv1l92u_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cBinop_i1MXaYwS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_5FMXdMW3, HV_BINOP_MAX, 0, m, &cBinop_5FMXdMW3_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_1kLXPHWl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_i1MXaYwS, HV_BINOP_MULTIPLY, 0, m, &cBinop_i1MXaYwS_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_E40b8Nme_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_JJOcGU9E_sendMessage(_c, 0, m);
  sTabread_onMessage(_c, &Context(_c)->sTabread_8ctWDKfL, 0, m, &sTabread_8ctWDKfL_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_NkdKfLwM_sendMessage);
}

void Heavy_WSTD_DL3Y::cSystem_ekFKUkfz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_6Yv1l92u, HV_BINOP_SUBTRACT, 1, m, &cBinop_6Yv1l92u_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_bmcB2JoE, 2, m, &cDelay_bmcB2JoE_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_tGJBr6GO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(3);
  msg_init(m, 3, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "table");
  msg_setElementToFrom(m, 1, n, 0);
  msg_setSymbol(m, 2, "size");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_ekFKUkfz_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_JJOcGU9E_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_MSZfvriF, 0, m, &cDelay_MSZfvriF_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_bmcB2JoE, 0, m, &cDelay_bmcB2JoE_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_Dns0cXns_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0,  static_cast<float>(HV_N_SIMD));
  cBinop_onMessage(_c, &Context(_c)->cBinop_5FMXdMW3, HV_BINOP_MAX, 1, m, &cBinop_5FMXdMW3_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_5FMXdMW3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_E40b8Nme, HV_BINOP_SUBTRACT, 1, m, &cBinop_E40b8Nme_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_NkdKfLwM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_MSZfvriF, 0, m, &cDelay_MSZfvriF_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_sPCf06FQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_MSZfvriF, 2, m, &cDelay_MSZfvriF_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_6Yv1l92u_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_sPCf06FQ_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_gUeCsYQj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_YFi9AuHy, 0, m, &cVar_YFi9AuHy_sendMessage);
  cMsg_gvrV4clK_sendMessage(_c, 0, m);
  cTabhead_onMessage(_c, &Context(_c)->cTabhead_hZDFpjvk, 0, m, &cTabhead_hZDFpjvk_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_ZnCK44JL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 100.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_euBMhtLL, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cMsg_l5EAZoNK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 100.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_eLFeYyxW, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cMsg_hKV5zIRd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 100.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_RbaTnMnt, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cMsg_kSWB7s9e_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 100.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_hPgrwyT6, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cMsg_hmQMrNCZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 100.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_G1Bc92pM, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cMsg_VEvcbAA4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 100.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_OwNXV51q, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cMsg_vFBGAjLm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 100.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_JRRCuPP3, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cMsg_VIbvgNkA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 100.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_vdZxpvBo, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cSwitchcase_Hl5AypDC_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x764F1C36: { // "mix"
      cSlice_onMessage(_c, &Context(_c)->cSlice_n1ayCBk0, 0, m, &cSlice_n1ayCBk0_sendMessage);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_WSTD_DL3Y::cSlice_n1ayCBk0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_KcpEjYoV_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_KcpEjYoV_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cVar_Fw0TLtxH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_KcpEjYoV_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cSend_KcpEjYoV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_61c3LaMw_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cSwitchcase_ANTMaM0b_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0xC8CCFEC1: { // "cross"
      cSlice_onMessage(_c, &Context(_c)->cSlice_Yp0WgIeG, 0, m, &cSlice_Yp0WgIeG_sendMessage);
      break;
    }
    default: {
      cSwitchcase_T9L6EHSi_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_DL3Y::cSlice_Yp0WgIeG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_SsiA3cQz_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_SsiA3cQz_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cVar_kWIOF8hd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_SsiA3cQz_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cSend_SsiA3cQz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_MQXv8zZU_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cSwitchcase_WiDi3CPU_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x8E55AA5F: { // "time"
      cSlice_onMessage(_c, &Context(_c)->cSlice_lFvNxrGv, 0, m, &cSlice_lFvNxrGv_sendMessage);
      break;
    }
    default: {
      cSwitchcase_Hl5AypDC_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_DL3Y::cSlice_lFvNxrGv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_qJc9GhV8_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_qJc9GhV8_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cVar_bM9Ygxdl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_qJc9GhV8_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cSend_qJc9GhV8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_QO7LABFT_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_mJlPfVgB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.0f, 0, m, &cBinop_qPG5tbm8_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_qPG5tbm8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 2.0f, 0, m, &cBinop_bcjiGokT_sendMessage);
}

void Heavy_WSTD_DL3Y::cUnop_QghbZyFf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_jI8rzv4b_sendMessage(_c, 0, m);
  cMsg_A3UNbFoi_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cUnop_EhUCQRws_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_gdvHRhXM_sendMessage(_c, 0, m);
  cMsg_fsaKUKod_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_bcjiGokT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_kw8qd7ic_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_kw8qd7ic_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_4KoGbg3G_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_L05pc5sE_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_L05pc5sE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_x4d7e4fA_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cCast_4KoGbg3G_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_zQCZkXXX_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_zQCZkXXX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_MuHtPaOa_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_x4d7e4fA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_xSGni8X3_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_xSGni8X3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_FKmAeWYY_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_MuHtPaOa_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_SQRT, m, &cUnop_QghbZyFf_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_FKmAeWYY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_SQRT, m, &cUnop_EhUCQRws_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_6P5tSjFw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.0f, 0, m, &cBinop_XytOlHcH_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_XytOlHcH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 2.0f, 0, m, &cBinop_mcFDyw2S_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_mcFDyw2S_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_1akUQ8gc_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_1akUQ8gc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_EgYYFwmV_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_iyuGeCkv_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_iyuGeCkv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_68jxMSYT_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cCast_EgYYFwmV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_zWza9Hus_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_zWza9Hus_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_WSemsukq_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_68jxMSYT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_hDDwrOT2_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_hDDwrOT2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_h4eUaivd_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_h4eUaivd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_zMBxhleX_sendMessage(_c, 0, m);
  cMsg_wj24JR3b_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_WSemsukq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_lVjrQthL_sendMessage(_c, 0, m);
  cMsg_yb9PFY8g_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_ACxH0eWs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.0f, 0, m, &cBinop_SS9fsEdA_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_SS9fsEdA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_ovuLREXN_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_jpMeg8ZO_sendMessage);
}

void Heavy_WSTD_DL3Y::cVar_gz7rIqHf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 1.0f, 0, m, &cBinop_7lapJK8I_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_NWV2iISe_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_yk2akwQl_sendMessage);
}

void Heavy_WSTD_DL3Y::cSystem_yk2akwQl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_XTVjZauq, HV_BINOP_DIVIDE, 1, m, &cBinop_XTVjZauq_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_ovuLREXN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_CDm5Kayt_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_CDm5Kayt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_V9cyL1XR, m);
}

void Heavy_WSTD_DL3Y::cMsg_9Q0zGD8c_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_TqJxyBhf_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_TqJxyBhf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 1.0f, 0, m, &cBinop_ACxH0eWs_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_jpMeg8ZO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_1ElL27q5, m);
}

void Heavy_WSTD_DL3Y::cBinop_7lapJK8I_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 6.28319f, 0, m, &cBinop_vw25MF49_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_vw25MF49_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_XTVjZauq, HV_BINOP_DIVIDE, 0, m, &cBinop_XTVjZauq_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_XTVjZauq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_9Q0zGD8c_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_ZlXyeybC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.0f, 0, m, &cBinop_LOM29z3p_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_LOM29z3p_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_kvqmbAq7_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_wYp65nId_sendMessage);
}

void Heavy_WSTD_DL3Y::cVar_hMMLlDmO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 1.0f, 0, m, &cBinop_Ob7gW5ai_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_aBWW3h5n_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_tI9LsT0p_sendMessage);
}

void Heavy_WSTD_DL3Y::cSystem_tI9LsT0p_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_43UG05Y6, HV_BINOP_DIVIDE, 1, m, &cBinop_43UG05Y6_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_kvqmbAq7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_ezumziU7_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_ezumziU7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_3Ko9rKiv, m);
}

void Heavy_WSTD_DL3Y::cMsg_blAIv1vf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_qSyVXSmQ_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_qSyVXSmQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 1.0f, 0, m, &cBinop_ZlXyeybC_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_wYp65nId_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_yBncRYaA, m);
}

void Heavy_WSTD_DL3Y::cBinop_Ob7gW5ai_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 6.28319f, 0, m, &cBinop_M732JRsf_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_M732JRsf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_43UG05Y6, HV_BINOP_DIVIDE, 0, m, &cBinop_43UG05Y6_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_43UG05Y6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_blAIv1vf_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cVar_Hm4udIqr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_AGvXfyKZ, HV_BINOP_MULTIPLY, 0, m, &cBinop_AGvXfyKZ_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_NylDhsny_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_Oczj78ci_sendMessage);
}

void Heavy_WSTD_DL3Y::cSystem_Oczj78ci_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_DAP3Pk9o_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_AGvXfyKZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 1.0f, 0, m, &cBinop_u9GJeQIS_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_8gBxJgIB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_AGvXfyKZ, HV_BINOP_MULTIPLY, 1, m, &cBinop_AGvXfyKZ_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_DAP3Pk9o_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 6.28319f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_8gBxJgIB_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_u9GJeQIS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.0f, 0, m, &cBinop_S8ljwAIq_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_S8ljwAIq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_VtvmYUv9_sendMessage);
  sVarf_onMessage(_c, &Context(_c)->sVarf_b3kgBa2g, m);
}

void Heavy_WSTD_DL3Y::cBinop_VtvmYUv9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_mAgcoTuU, m);
}

void Heavy_WSTD_DL3Y::cVar_W1Et6mJN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_2GQvfXC3, HV_BINOP_MULTIPLY, 0, m, &cBinop_2GQvfXC3_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_ZL58MV4s_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_L508geKm_sendMessage);
}

void Heavy_WSTD_DL3Y::cSystem_L508geKm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_3JZTlka6_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_2GQvfXC3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 1.0f, 0, m, &cBinop_lhzoueAd_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_i5R2pLHC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_2GQvfXC3, HV_BINOP_MULTIPLY, 1, m, &cBinop_2GQvfXC3_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_3JZTlka6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 6.28319f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_i5R2pLHC_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_lhzoueAd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.0f, 0, m, &cBinop_6drZFRR3_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_6drZFRR3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_9ojCq8dW_sendMessage);
  sVarf_onMessage(_c, &Context(_c)->sVarf_LtVWp1zn, m);
}

void Heavy_WSTD_DL3Y::cBinop_9ojCq8dW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_flRydUO5, m);
}

void Heavy_WSTD_DL3Y::sEnv_uJDcVDjK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_ElG6y1ml_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_scHGgIik_sendMessage);
}

void Heavy_WSTD_DL3Y::cIf_PBtzAUQP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cMsg_76yd0m57_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 485.0f, 0, m, &cBinop_7XUuAoML_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cMsg_ro7i3CXR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 10.0f);
  cBinop_onMessage(_c, &Context(_c)->cBinop_c6ts9So5, HV_BINOP_POW, 0, m, &cBinop_c6ts9So5_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_c6ts9So5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_OLeEEbJb_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_KxUbjNzS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 20.0f, 0, m, &cBinop_pd4WE7Y1_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_ElG6y1ml_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_qtFdHOtx_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_scHGgIik_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_PBtzAUQP, 0, m, &cIf_PBtzAUQP_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_qtFdHOtx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_PBtzAUQP, 1, m, &cIf_PBtzAUQP_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_7XUuAoML_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 100.0f, 0, m, &cBinop_KxUbjNzS_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_76yd0m57_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cMsg_OLeEEbJb_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_pd4WE7Y1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_c6ts9So5, HV_BINOP_POW, 1, m, &cBinop_c6ts9So5_sendMessage);
  cMsg_ro7i3CXR_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cVar_djxw5BXX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_XTjZdfuv, HV_BINOP_MULTIPLY, 0, m, &cBinop_XTjZdfuv_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_f80m9x40_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_i0ANewTd_sendMessage);
}

void Heavy_WSTD_DL3Y::cSystem_i0ANewTd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_lCQYYC4f_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_XTjZdfuv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 1.0f, 0, m, &cBinop_rVzbmBlM_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_7RPQG6ko_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_XTjZdfuv, HV_BINOP_MULTIPLY, 1, m, &cBinop_XTjZdfuv_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_lCQYYC4f_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 6.28319f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_7RPQG6ko_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_rVzbmBlM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.0f, 0, m, &cBinop_3iUaNGGO_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_3iUaNGGO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_PHsX1PrB_sendMessage);
  sVarf_onMessage(_c, &Context(_c)->sVarf_baK4BTOb, m);
}

void Heavy_WSTD_DL3Y::cBinop_PHsX1PrB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_WlPiwc27, m);
}

void Heavy_WSTD_DL3Y::cMsg_OLeEEbJb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_B5sxtgLs_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_B5sxtgLs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_Eo4faav9, m);
}

void Heavy_WSTD_DL3Y::sEnv_ja9lRYb7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_VVtNHKPT_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_DcbsdT00_sendMessage);
}

void Heavy_WSTD_DL3Y::cIf_zpeJ60UI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cMsg_AYnXzsQg_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 485.0f, 0, m, &cBinop_RUZl1PpN_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cMsg_oxcyV580_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 10.0f);
  cBinop_onMessage(_c, &Context(_c)->cBinop_SRjV5TmW, HV_BINOP_POW, 0, m, &cBinop_SRjV5TmW_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_SRjV5TmW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_bHbwfAlI_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_hSafwBKd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 20.0f, 0, m, &cBinop_lyriAbBX_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_DcbsdT00_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_zpeJ60UI, 0, m, &cIf_zpeJ60UI_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_VVtNHKPT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_93d7RwaV_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_93d7RwaV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_zpeJ60UI, 1, m, &cIf_zpeJ60UI_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_RUZl1PpN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 100.0f, 0, m, &cBinop_hSafwBKd_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_AYnXzsQg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cMsg_bHbwfAlI_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_lyriAbBX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_SRjV5TmW, HV_BINOP_POW, 1, m, &cBinop_SRjV5TmW_sendMessage);
  cMsg_oxcyV580_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cVar_LYVXFPe4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_N65MTjI5, HV_BINOP_MULTIPLY, 0, m, &cBinop_N65MTjI5_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_A0puEiWQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_53gHg0Bc_sendMessage);
}

void Heavy_WSTD_DL3Y::cSystem_53gHg0Bc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_5SzEqyYf_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_N65MTjI5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 1.0f, 0, m, &cBinop_CMQ3BgIb_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_RTiZuRND_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_N65MTjI5, HV_BINOP_MULTIPLY, 1, m, &cBinop_N65MTjI5_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_5SzEqyYf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 6.28319f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_RTiZuRND_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_CMQ3BgIb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.0f, 0, m, &cBinop_4qLLAXvG_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_4qLLAXvG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_oqVEjbXq_sendMessage);
  sVarf_onMessage(_c, &Context(_c)->sVarf_5SPkAxKc, m);
}

void Heavy_WSTD_DL3Y::cBinop_oqVEjbXq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_HRTpzk5m, m);
}

void Heavy_WSTD_DL3Y::cMsg_bHbwfAlI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_nJnRSZC2_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_nJnRSZC2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_0bdC8Nar, m);
}

void Heavy_WSTD_DL3Y::cSwitchcase_T9L6EHSi_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0xF1E7CD16: { // "feedback"
      cSlice_onMessage(_c, &Context(_c)->cSlice_9UrJNzAF, 0, m, &cSlice_9UrJNzAF_sendMessage);
      break;
    }
    default: {
      cSwitchcase_WiDi3CPU_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_DL3Y::cSlice_9UrJNzAF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_Z8q4CeqO_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_Z8q4CeqO_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cVar_BojHGObu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_Z8q4CeqO_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cSend_Z8q4CeqO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_AYKlTuOy_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cMsg_VhYIUcXK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_v85RDsvs_sendMessage);
}

void Heavy_WSTD_DL3Y::cSystem_v85RDsvs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_DPfgGov8_sendMessage);
}

void Heavy_WSTD_DL3Y::cDelay_ICInARda_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_ICInARda, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_Y50FeanN, 0, m, &cDelay_Y50FeanN_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_ICInARda, 0, m, &cDelay_ICInARda_sendMessage);
  sTabwrite_onMessage(_c, &Context(_c)->sTabwrite_x8DvrhQE, 1, m, NULL);
}

void Heavy_WSTD_DL3Y::cDelay_Y50FeanN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_Y50FeanN, m);
  cMsg_zx0w2QNf_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cSwitchcase_FsviuTWO_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x47BE8354: { // "clear"
      cMsg_zAoyUKmC_sendMessage(_c, 0, m);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_WSTD_DL3Y::cBinop_gFQatuQF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_qSy49I0x_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::hTable_Fi71Gc3J_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_lEirykaK_sendMessage(_c, 0, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_ICInARda, 2, m, &cDelay_ICInARda_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_bx2odoWi_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_qSy49I0x_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "resize");
  msg_setElementToFrom(m, 1, n, 0);
  hTable_onMessage(_c, &Context(_c)->hTable_Fi71Gc3J, 0, m, &hTable_Fi71Gc3J_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_DPfgGov8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 5000.0f, 0, m, &cBinop_gFQatuQF_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_zx0w2QNf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "mirror");
  hTable_onMessage(_c, &Context(_c)->hTable_Fi71Gc3J, 0, m, &hTable_Fi71Gc3J_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_bx2odoWi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_ICInARda, 0, m, &cDelay_ICInARda_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_lEirykaK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0,  static_cast<float>(HV_N_SIMD));
  cDelay_onMessage(_c, &Context(_c)->cDelay_Y50FeanN, 2, m, &cDelay_Y50FeanN_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_zAoyUKmC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  sTabwrite_onMessage(_c, &Context(_c)->sTabwrite_x8DvrhQE, 1, m, NULL);
}

void Heavy_WSTD_DL3Y::cTabhead_5sRjkEwK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_9nzHDetP, HV_BINOP_SUBTRACT, 0, m, &cBinop_9nzHDetP_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_lkaCE40E_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_62tvc4fF_sendMessage);
}

void Heavy_WSTD_DL3Y::cSystem_62tvc4fF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_2AvDo0XA_sendMessage);
}

void Heavy_WSTD_DL3Y::cVar_Hppg8hr8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_kC4CaVE7_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cDelay_tbYOmLcb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_tbYOmLcb, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_BTWS90v5, 0, m, &cDelay_BTWS90v5_sendMessage);
  sTabread_onMessage(_c, &Context(_c)->sTabread_b1wGD1vP, 0, m, &sTabread_b1wGD1vP_sendMessage);
}

void Heavy_WSTD_DL3Y::cDelay_BTWS90v5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_BTWS90v5, m);
  sTabread_onMessage(_c, &Context(_c)->sTabread_b1wGD1vP, 0, m, &sTabread_b1wGD1vP_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_BTWS90v5, 0, m, &cDelay_BTWS90v5_sendMessage);
}

void Heavy_WSTD_DL3Y::sTabread_b1wGD1vP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cBinop_onMessage(_c, &Context(_c)->cBinop_W9EZFXLF, HV_BINOP_SUBTRACT, 0, m, &cBinop_W9EZFXLF_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cBinop_qu0z6zJb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_8asLxE67, HV_BINOP_MAX, 0, m, &cBinop_8asLxE67_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_2AvDo0XA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_qu0z6zJb, HV_BINOP_MULTIPLY, 0, m, &cBinop_qu0z6zJb_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_9nzHDetP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_hYgITHHI_sendMessage(_c, 0, m);
  sTabread_onMessage(_c, &Context(_c)->sTabread_b1wGD1vP, 0, m, &sTabread_b1wGD1vP_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_v8f27QUD_sendMessage);
}

void Heavy_WSTD_DL3Y::cSystem_ucOzAgQw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_W9EZFXLF, HV_BINOP_SUBTRACT, 1, m, &cBinop_W9EZFXLF_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_BTWS90v5, 2, m, &cDelay_BTWS90v5_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_kC4CaVE7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(3);
  msg_init(m, 3, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "table");
  msg_setElementToFrom(m, 1, n, 0);
  msg_setSymbol(m, 2, "size");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_ucOzAgQw_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_hYgITHHI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_tbYOmLcb, 0, m, &cDelay_tbYOmLcb_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_BTWS90v5, 0, m, &cDelay_BTWS90v5_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_gQqJDrO5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0,  static_cast<float>(HV_N_SIMD));
  cBinop_onMessage(_c, &Context(_c)->cBinop_8asLxE67, HV_BINOP_MAX, 1, m, &cBinop_8asLxE67_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_8asLxE67_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_9nzHDetP, HV_BINOP_SUBTRACT, 1, m, &cBinop_9nzHDetP_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_v8f27QUD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_tbYOmLcb, 0, m, &cDelay_tbYOmLcb_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_wQfdZ4h3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_tbYOmLcb, 2, m, &cDelay_tbYOmLcb_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_W9EZFXLF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_wQfdZ4h3_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_KqFHaIqV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_Hppg8hr8, 0, m, &cVar_Hppg8hr8_sendMessage);
  cMsg_lkaCE40E_sendMessage(_c, 0, m);
  cTabhead_onMessage(_c, &Context(_c)->cTabhead_5sRjkEwK, 0, m, &cTabhead_5sRjkEwK_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_478XRsTX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_Pnq9k3Jp_sendMessage);
}

void Heavy_WSTD_DL3Y::cSystem_Pnq9k3Jp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_6Ckga2M2_sendMessage);
}

void Heavy_WSTD_DL3Y::cDelay_KPPgwWFv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_KPPgwWFv, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_FV9n1JuS, 0, m, &cDelay_FV9n1JuS_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_KPPgwWFv, 0, m, &cDelay_KPPgwWFv_sendMessage);
  sTabwrite_onMessage(_c, &Context(_c)->sTabwrite_fflxi6Am, 1, m, NULL);
}

void Heavy_WSTD_DL3Y::cDelay_FV9n1JuS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_FV9n1JuS, m);
  cMsg_vKcw6Xh0_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cSwitchcase_3jtFhTC0_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x47BE8354: { // "clear"
      cMsg_qoqtoxyD_sendMessage(_c, 0, m);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_WSTD_DL3Y::cBinop_nI4YWS5F_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_I0MnDPOY_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::hTable_GuCIDNfd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_3KQz5HuY_sendMessage(_c, 0, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_KPPgwWFv, 2, m, &cDelay_KPPgwWFv_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_cinvxhsc_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_I0MnDPOY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "resize");
  msg_setElementToFrom(m, 1, n, 0);
  hTable_onMessage(_c, &Context(_c)->hTable_GuCIDNfd, 0, m, &hTable_GuCIDNfd_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_6Ckga2M2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 5000.0f, 0, m, &cBinop_nI4YWS5F_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_vKcw6Xh0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "mirror");
  hTable_onMessage(_c, &Context(_c)->hTable_GuCIDNfd, 0, m, &hTable_GuCIDNfd_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_cinvxhsc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_KPPgwWFv, 0, m, &cDelay_KPPgwWFv_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_3KQz5HuY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0,  static_cast<float>(HV_N_SIMD));
  cDelay_onMessage(_c, &Context(_c)->cDelay_FV9n1JuS, 2, m, &cDelay_FV9n1JuS_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_qoqtoxyD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  sTabwrite_onMessage(_c, &Context(_c)->sTabwrite_fflxi6Am, 1, m, NULL);
}

void Heavy_WSTD_DL3Y::cTabhead_Vdsejnn7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_iPpZMt3H, HV_BINOP_SUBTRACT, 0, m, &cBinop_iPpZMt3H_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_aUOFYcyW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_Xw21JTEE_sendMessage);
}

void Heavy_WSTD_DL3Y::cSystem_Xw21JTEE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_7TqATtIn_sendMessage);
}

void Heavy_WSTD_DL3Y::cVar_k0ddEbLk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_amP2yVuf_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cDelay_AkhGWW5G_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_AkhGWW5G, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_tiR0urKK, 0, m, &cDelay_tiR0urKK_sendMessage);
  sTabread_onMessage(_c, &Context(_c)->sTabread_4cuL5DVh, 0, m, &sTabread_4cuL5DVh_sendMessage);
}

void Heavy_WSTD_DL3Y::cDelay_tiR0urKK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_tiR0urKK, m);
  sTabread_onMessage(_c, &Context(_c)->sTabread_4cuL5DVh, 0, m, &sTabread_4cuL5DVh_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_tiR0urKK, 0, m, &cDelay_tiR0urKK_sendMessage);
}

void Heavy_WSTD_DL3Y::sTabread_4cuL5DVh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cBinop_onMessage(_c, &Context(_c)->cBinop_17aqsUWQ, HV_BINOP_SUBTRACT, 0, m, &cBinop_17aqsUWQ_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cBinop_17OZuesF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_f85e3zwF, HV_BINOP_MAX, 0, m, &cBinop_f85e3zwF_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_7TqATtIn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_17OZuesF, HV_BINOP_MULTIPLY, 0, m, &cBinop_17OZuesF_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_iPpZMt3H_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_HoJB0MWc_sendMessage(_c, 0, m);
  sTabread_onMessage(_c, &Context(_c)->sTabread_4cuL5DVh, 0, m, &sTabread_4cuL5DVh_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_05ycevez_sendMessage);
}

void Heavy_WSTD_DL3Y::cSystem_1dci763b_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_17aqsUWQ, HV_BINOP_SUBTRACT, 1, m, &cBinop_17aqsUWQ_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_tiR0urKK, 2, m, &cDelay_tiR0urKK_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_amP2yVuf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(3);
  msg_init(m, 3, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "table");
  msg_setElementToFrom(m, 1, n, 0);
  msg_setSymbol(m, 2, "size");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_1dci763b_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_HoJB0MWc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_AkhGWW5G, 0, m, &cDelay_AkhGWW5G_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_tiR0urKK, 0, m, &cDelay_tiR0urKK_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_CdxZoUjo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0,  static_cast<float>(HV_N_SIMD));
  cBinop_onMessage(_c, &Context(_c)->cBinop_f85e3zwF, HV_BINOP_MAX, 1, m, &cBinop_f85e3zwF_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_f85e3zwF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_iPpZMt3H, HV_BINOP_SUBTRACT, 1, m, &cBinop_iPpZMt3H_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_05ycevez_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_AkhGWW5G, 0, m, &cDelay_AkhGWW5G_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_5Of2MVGJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_AkhGWW5G, 2, m, &cDelay_AkhGWW5G_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_17aqsUWQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_5Of2MVGJ_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_cDUy8PUK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_k0ddEbLk, 0, m, &cVar_k0ddEbLk_sendMessage);
  cMsg_aUOFYcyW_sendMessage(_c, 0, m);
  cTabhead_onMessage(_c, &Context(_c)->cTabhead_Vdsejnn7, 0, m, &cTabhead_Vdsejnn7_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_jI8rzv4b_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 100.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_muo0BVHG, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cMsg_gdvHRhXM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 100.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_UlqhqerW, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cMsg_fsaKUKod_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 100.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_t1mUprca, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cMsg_A3UNbFoi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 100.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_oVRlatCU, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cMsg_yb9PFY8g_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 100.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_Tt7JyTOM, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cMsg_zMBxhleX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 100.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_2v2GHjZf, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cMsg_lVjrQthL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 100.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_8EwDxbaK, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cMsg_wj24JR3b_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 100.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_uvhU7sbN, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cSwitchcase_22i37dFz_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x764F1C36: { // "mix"
      cSlice_onMessage(_c, &Context(_c)->cSlice_RaS2CjJ7, 0, m, &cSlice_RaS2CjJ7_sendMessage);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_WSTD_DL3Y::cSlice_RaS2CjJ7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_NVVvxEDV_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_NVVvxEDV_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cVar_PxFv334s_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_NVVvxEDV_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cSend_NVVvxEDV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_NsHFswVU_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cSwitchcase_3xOLzmQq_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0xC8CCFEC1: { // "cross"
      cSlice_onMessage(_c, &Context(_c)->cSlice_zCLDJDdd, 0, m, &cSlice_zCLDJDdd_sendMessage);
      break;
    }
    default: {
      cSwitchcase_P5GrDUos_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_DL3Y::cSlice_zCLDJDdd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_n19TDqMW_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_n19TDqMW_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cVar_qJHoIyBj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_n19TDqMW_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cSend_n19TDqMW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_gh5EyZ09_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cSwitchcase_BPBY1Cer_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x8E55AA5F: { // "time"
      cSlice_onMessage(_c, &Context(_c)->cSlice_DFmzKjYJ, 0, m, &cSlice_DFmzKjYJ_sendMessage);
      break;
    }
    default: {
      cSwitchcase_22i37dFz_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_DL3Y::cSlice_DFmzKjYJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_hQkRQERh_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_hQkRQERh_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cVar_gcErxsRk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_hQkRQERh_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cSend_hQkRQERh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_xw9wQJgG_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_VhGqTpG0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.0f, 0, m, &cBinop_LMmnbTMB_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_LMmnbTMB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 2.0f, 0, m, &cBinop_vQLPWis7_sendMessage);
}

void Heavy_WSTD_DL3Y::cUnop_LZy5XuDg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_OI5cXU7C_sendMessage(_c, 0, m);
  cMsg_AAJheok7_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cUnop_Lk6oE5qe_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_E9YcGJyb_sendMessage(_c, 0, m);
  cMsg_tynhNU1Q_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_vQLPWis7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_99ruEwyJ_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_99ruEwyJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_ozhnNNGj_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_KcGorTKN_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_KcGorTKN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_f8Ioid0N_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cCast_ozhnNNGj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_XTUuZj6P_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_XTUuZj6P_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_K7CxA5bU_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_f8Ioid0N_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_x7qYC4rO_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_x7qYC4rO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_7HphG36Y_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_K7CxA5bU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_SQRT, m, &cUnop_LZy5XuDg_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_7HphG36Y_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_SQRT, m, &cUnop_Lk6oE5qe_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_kPvYakmy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.0f, 0, m, &cBinop_RgjDqqXA_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_RgjDqqXA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 2.0f, 0, m, &cBinop_uP3xzXQx_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_uP3xzXQx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_uqwzEhRB_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_uqwzEhRB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_QN3Q0MYq_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_68V0eB3j_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_68V0eB3j_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_RSqPoxJK_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cCast_QN3Q0MYq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_9txlh730_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_9txlh730_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_FemZi8ZM_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_RSqPoxJK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_4BloIsl5_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_4BloIsl5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_TFmezQDy_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_TFmezQDy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_bzdeOwNl_sendMessage(_c, 0, m);
  cMsg_tMmqft2C_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_FemZi8ZM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_zfW2gIrw_sendMessage(_c, 0, m);
  cMsg_UvCZcNYe_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_TljrPMXs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.0f, 0, m, &cBinop_TBhIAD8n_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_TBhIAD8n_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_fI1kxHaf_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_EPKYmv3E_sendMessage);
}

void Heavy_WSTD_DL3Y::cVar_53agGqRN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 1.0f, 0, m, &cBinop_y3j1KFNT_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_qfEHrji8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_KPtLXrut_sendMessage);
}

void Heavy_WSTD_DL3Y::cSystem_KPtLXrut_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_7mI2u1Ll, HV_BINOP_DIVIDE, 1, m, &cBinop_7mI2u1Ll_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_fI1kxHaf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_EUQvva4K_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_EUQvva4K_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_p0k0jAkU, m);
}

void Heavy_WSTD_DL3Y::cMsg_lB3XQ29i_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_2ngma5Mh_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_2ngma5Mh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 1.0f, 0, m, &cBinop_TljrPMXs_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_EPKYmv3E_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_sJ4hmV62, m);
}

void Heavy_WSTD_DL3Y::cBinop_y3j1KFNT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 6.28319f, 0, m, &cBinop_yDlUkLp5_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_yDlUkLp5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_7mI2u1Ll, HV_BINOP_DIVIDE, 0, m, &cBinop_7mI2u1Ll_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_7mI2u1Ll_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_lB3XQ29i_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_Ss0yi1TL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.0f, 0, m, &cBinop_XIVpFKhT_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_XIVpFKhT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_3hFakbHH_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_4uzhRKCe_sendMessage);
}

void Heavy_WSTD_DL3Y::cVar_Pe2HEZID_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 1.0f, 0, m, &cBinop_cfrvxSsf_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_6GC8SqlV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_hC2B5l7N_sendMessage);
}

void Heavy_WSTD_DL3Y::cSystem_hC2B5l7N_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_Qo0hQCTa, HV_BINOP_DIVIDE, 1, m, &cBinop_Qo0hQCTa_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_3hFakbHH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_5zXrPwu6_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_5zXrPwu6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_LIaZ958w, m);
}

void Heavy_WSTD_DL3Y::cMsg_gZdwdJOZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_PKTrR56N_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_PKTrR56N_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 1.0f, 0, m, &cBinop_Ss0yi1TL_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_4uzhRKCe_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_xzFkSdKT, m);
}

void Heavy_WSTD_DL3Y::cBinop_cfrvxSsf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 6.28319f, 0, m, &cBinop_Vy4VJbZZ_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_Vy4VJbZZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_Qo0hQCTa, HV_BINOP_DIVIDE, 0, m, &cBinop_Qo0hQCTa_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_Qo0hQCTa_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_gZdwdJOZ_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cVar_ix2p16dk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_c6FHZ2xf, HV_BINOP_MULTIPLY, 0, m, &cBinop_c6FHZ2xf_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_ir3dKohv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_XON8UZQH_sendMessage);
}

void Heavy_WSTD_DL3Y::cSystem_XON8UZQH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_fVybYhfY_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_c6FHZ2xf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 1.0f, 0, m, &cBinop_oumCFEwj_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_6GujpVz1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_c6FHZ2xf, HV_BINOP_MULTIPLY, 1, m, &cBinop_c6FHZ2xf_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_fVybYhfY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 6.28319f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_6GujpVz1_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_oumCFEwj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.0f, 0, m, &cBinop_zKGmZF7u_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_zKGmZF7u_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_jcOm3ot7_sendMessage);
  sVarf_onMessage(_c, &Context(_c)->sVarf_wAU5nXlk, m);
}

void Heavy_WSTD_DL3Y::cBinop_jcOm3ot7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_gILdzuMN, m);
}

void Heavy_WSTD_DL3Y::cVar_0w4wa58Q_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_hLMZUMhN, HV_BINOP_MULTIPLY, 0, m, &cBinop_hLMZUMhN_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_s5PYGZ8H_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_JpaG0Apx_sendMessage);
}

void Heavy_WSTD_DL3Y::cSystem_JpaG0Apx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_f4XPyqz7_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_hLMZUMhN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 1.0f, 0, m, &cBinop_Jt1YHat2_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_tAJZ9IMH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_hLMZUMhN, HV_BINOP_MULTIPLY, 1, m, &cBinop_hLMZUMhN_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_f4XPyqz7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 6.28319f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_tAJZ9IMH_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_Jt1YHat2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.0f, 0, m, &cBinop_B23CqP8x_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_B23CqP8x_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_AoYF1NBj_sendMessage);
  sVarf_onMessage(_c, &Context(_c)->sVarf_gZP578zs, m);
}

void Heavy_WSTD_DL3Y::cBinop_AoYF1NBj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_MF4FOrg4, m);
}

void Heavy_WSTD_DL3Y::sEnv_bJMBGZcx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_TG9p1G2P_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_QNC6u2Cm_sendMessage);
}

void Heavy_WSTD_DL3Y::cIf_6uemW2Cu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cMsg_YvbrrfQs_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 485.0f, 0, m, &cBinop_edn6gW94_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cMsg_THq2hwZc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 10.0f);
  cBinop_onMessage(_c, &Context(_c)->cBinop_fIPABZsb, HV_BINOP_POW, 0, m, &cBinop_fIPABZsb_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_fIPABZsb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_IOnl2fL6_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_zKOqUz0U_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 20.0f, 0, m, &cBinop_GTtsSTWj_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_QNC6u2Cm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_6uemW2Cu, 0, m, &cIf_6uemW2Cu_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_TG9p1G2P_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_O4i2AA8E_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_O4i2AA8E_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_6uemW2Cu, 1, m, &cIf_6uemW2Cu_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_edn6gW94_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 100.0f, 0, m, &cBinop_zKOqUz0U_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_YvbrrfQs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cMsg_IOnl2fL6_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_GTtsSTWj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_fIPABZsb, HV_BINOP_POW, 1, m, &cBinop_fIPABZsb_sendMessage);
  cMsg_THq2hwZc_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cVar_lm9c61Sj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_zOWFpHOy, HV_BINOP_MULTIPLY, 0, m, &cBinop_zOWFpHOy_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_hMM4gOEp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_HL81U1my_sendMessage);
}

void Heavy_WSTD_DL3Y::cSystem_HL81U1my_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_WQWcLT4q_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_zOWFpHOy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 1.0f, 0, m, &cBinop_0KM7L5Px_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_WKLiapLI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_zOWFpHOy, HV_BINOP_MULTIPLY, 1, m, &cBinop_zOWFpHOy_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_WQWcLT4q_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 6.28319f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_WKLiapLI_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_0KM7L5Px_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.0f, 0, m, &cBinop_zvmPJ8mU_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_zvmPJ8mU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_OisHzDb2_sendMessage);
  sVarf_onMessage(_c, &Context(_c)->sVarf_dntFmCh2, m);
}

void Heavy_WSTD_DL3Y::cBinop_OisHzDb2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_rW7IPVUz, m);
}

void Heavy_WSTD_DL3Y::cMsg_IOnl2fL6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_wy70ZLsS_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_wy70ZLsS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_mwyiqzaM, m);
}

void Heavy_WSTD_DL3Y::sEnv_njcGyCDv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_9FGokMaX_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_54TKKPth_sendMessage);
}

void Heavy_WSTD_DL3Y::cIf_dPvYWVnG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cMsg_MpD3qEVL_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 485.0f, 0, m, &cBinop_qNtqHIMM_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cMsg_8zJXOlVD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 10.0f);
  cBinop_onMessage(_c, &Context(_c)->cBinop_3YxGWSe8, HV_BINOP_POW, 0, m, &cBinop_3YxGWSe8_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_3YxGWSe8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_z7CVkq0U_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_PtDevwnn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 20.0f, 0, m, &cBinop_zGMyXrw2_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_54TKKPth_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_dPvYWVnG, 0, m, &cIf_dPvYWVnG_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_9FGokMaX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_OxT5g4GU_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_OxT5g4GU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_dPvYWVnG, 1, m, &cIf_dPvYWVnG_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_qNtqHIMM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 100.0f, 0, m, &cBinop_PtDevwnn_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_MpD3qEVL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cMsg_z7CVkq0U_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_zGMyXrw2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_3YxGWSe8, HV_BINOP_POW, 1, m, &cBinop_3YxGWSe8_sendMessage);
  cMsg_8zJXOlVD_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cVar_wUZ09Bxj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_A13J7IeN, HV_BINOP_MULTIPLY, 0, m, &cBinop_A13J7IeN_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_6vr575bg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_FVN6MwGj_sendMessage);
}

void Heavy_WSTD_DL3Y::cSystem_FVN6MwGj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_F2Kw6pBK_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_A13J7IeN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 1.0f, 0, m, &cBinop_MvIUV0a1_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_tZdJ3jZ8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_A13J7IeN, HV_BINOP_MULTIPLY, 1, m, &cBinop_A13J7IeN_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_F2Kw6pBK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 6.28319f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_tZdJ3jZ8_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_MvIUV0a1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.0f, 0, m, &cBinop_GHkUC9sx_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_GHkUC9sx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_9znLfoT2_sendMessage);
  sVarf_onMessage(_c, &Context(_c)->sVarf_AKDAFGCy, m);
}

void Heavy_WSTD_DL3Y::cBinop_9znLfoT2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_pZlC9evG, m);
}

void Heavy_WSTD_DL3Y::cMsg_z7CVkq0U_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_fVye1Mj1_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_fVye1Mj1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_qwsBeSut, m);
}

void Heavy_WSTD_DL3Y::cSwitchcase_P5GrDUos_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0xF1E7CD16: { // "feedback"
      cSlice_onMessage(_c, &Context(_c)->cSlice_w13BwbCr, 0, m, &cSlice_w13BwbCr_sendMessage);
      break;
    }
    default: {
      cSwitchcase_BPBY1Cer_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_DL3Y::cSlice_w13BwbCr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_VyhjpF1M_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_VyhjpF1M_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cVar_DeJfeGt3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_VyhjpF1M_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cSend_VyhjpF1M_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_9kpmztE7_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cMsg_KGKMp0Vy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_i4i1FiXu_sendMessage);
}

void Heavy_WSTD_DL3Y::cSystem_i4i1FiXu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_RgmiU9Nl_sendMessage);
}

void Heavy_WSTD_DL3Y::cDelay_ZTFNL9ws_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_ZTFNL9ws, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_S3VKSlYL, 0, m, &cDelay_S3VKSlYL_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_ZTFNL9ws, 0, m, &cDelay_ZTFNL9ws_sendMessage);
  sTabwrite_onMessage(_c, &Context(_c)->sTabwrite_S3IcX84y, 1, m, NULL);
}

void Heavy_WSTD_DL3Y::cDelay_S3VKSlYL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_S3VKSlYL, m);
  cMsg_R3B5V2pq_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cSwitchcase_8eWtNhzK_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x47BE8354: { // "clear"
      cMsg_0Lzr6qjw_sendMessage(_c, 0, m);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_WSTD_DL3Y::cBinop_ZUh3y1hw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_1njVhQwM_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::hTable_oZ36avfO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_wqrYWT26_sendMessage(_c, 0, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_ZTFNL9ws, 2, m, &cDelay_ZTFNL9ws_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_IhXnjDsh_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_1njVhQwM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "resize");
  msg_setElementToFrom(m, 1, n, 0);
  hTable_onMessage(_c, &Context(_c)->hTable_oZ36avfO, 0, m, &hTable_oZ36avfO_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_RgmiU9Nl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 5000.0f, 0, m, &cBinop_ZUh3y1hw_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_R3B5V2pq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "mirror");
  hTable_onMessage(_c, &Context(_c)->hTable_oZ36avfO, 0, m, &hTable_oZ36avfO_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_IhXnjDsh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_ZTFNL9ws, 0, m, &cDelay_ZTFNL9ws_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_wqrYWT26_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0,  static_cast<float>(HV_N_SIMD));
  cDelay_onMessage(_c, &Context(_c)->cDelay_S3VKSlYL, 2, m, &cDelay_S3VKSlYL_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_0Lzr6qjw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  sTabwrite_onMessage(_c, &Context(_c)->sTabwrite_S3IcX84y, 1, m, NULL);
}

void Heavy_WSTD_DL3Y::cTabhead_YU2Sh6ov_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_mINmljr6, HV_BINOP_SUBTRACT, 0, m, &cBinop_mINmljr6_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_vGk3oulp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_2CLBIqed_sendMessage);
}

void Heavy_WSTD_DL3Y::cSystem_2CLBIqed_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_BJQHlhWt_sendMessage);
}

void Heavy_WSTD_DL3Y::cVar_0kfGGsqs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_ZZa6wwpX_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cDelay_PPgzOmBP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_PPgzOmBP, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_vIV6UIv0, 0, m, &cDelay_vIV6UIv0_sendMessage);
  sTabread_onMessage(_c, &Context(_c)->sTabread_Q6OSucNZ, 0, m, &sTabread_Q6OSucNZ_sendMessage);
}

void Heavy_WSTD_DL3Y::cDelay_vIV6UIv0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_vIV6UIv0, m);
  sTabread_onMessage(_c, &Context(_c)->sTabread_Q6OSucNZ, 0, m, &sTabread_Q6OSucNZ_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_vIV6UIv0, 0, m, &cDelay_vIV6UIv0_sendMessage);
}

void Heavy_WSTD_DL3Y::sTabread_Q6OSucNZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cBinop_onMessage(_c, &Context(_c)->cBinop_HAFbUFCb, HV_BINOP_SUBTRACT, 0, m, &cBinop_HAFbUFCb_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cBinop_GjbQeYqr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_DKmYZCTl, HV_BINOP_MAX, 0, m, &cBinop_DKmYZCTl_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_BJQHlhWt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_GjbQeYqr, HV_BINOP_MULTIPLY, 0, m, &cBinop_GjbQeYqr_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_mINmljr6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_jf7lwUZe_sendMessage(_c, 0, m);
  sTabread_onMessage(_c, &Context(_c)->sTabread_Q6OSucNZ, 0, m, &sTabread_Q6OSucNZ_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_GW9UPZzh_sendMessage);
}

void Heavy_WSTD_DL3Y::cSystem_tM4RRcck_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_HAFbUFCb, HV_BINOP_SUBTRACT, 1, m, &cBinop_HAFbUFCb_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_vIV6UIv0, 2, m, &cDelay_vIV6UIv0_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_ZZa6wwpX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(3);
  msg_init(m, 3, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "table");
  msg_setElementToFrom(m, 1, n, 0);
  msg_setSymbol(m, 2, "size");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_tM4RRcck_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_jf7lwUZe_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_PPgzOmBP, 0, m, &cDelay_PPgzOmBP_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_vIV6UIv0, 0, m, &cDelay_vIV6UIv0_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_3W5EYgsl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0,  static_cast<float>(HV_N_SIMD));
  cBinop_onMessage(_c, &Context(_c)->cBinop_DKmYZCTl, HV_BINOP_MAX, 1, m, &cBinop_DKmYZCTl_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_DKmYZCTl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_mINmljr6, HV_BINOP_SUBTRACT, 1, m, &cBinop_mINmljr6_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_GW9UPZzh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_PPgzOmBP, 0, m, &cDelay_PPgzOmBP_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_1nykpqGx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_PPgzOmBP, 2, m, &cDelay_PPgzOmBP_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_HAFbUFCb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_1nykpqGx_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_x9ETNRft_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_0kfGGsqs, 0, m, &cVar_0kfGGsqs_sendMessage);
  cMsg_vGk3oulp_sendMessage(_c, 0, m);
  cTabhead_onMessage(_c, &Context(_c)->cTabhead_YU2Sh6ov, 0, m, &cTabhead_YU2Sh6ov_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_qwCCI4KG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_WSiJFIFB_sendMessage);
}

void Heavy_WSTD_DL3Y::cSystem_WSiJFIFB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_dhZR70P1_sendMessage);
}

void Heavy_WSTD_DL3Y::cDelay_BLTWSDEf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_BLTWSDEf, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_7jL5OrrN, 0, m, &cDelay_7jL5OrrN_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_BLTWSDEf, 0, m, &cDelay_BLTWSDEf_sendMessage);
  sTabwrite_onMessage(_c, &Context(_c)->sTabwrite_KKGLprdo, 1, m, NULL);
}

void Heavy_WSTD_DL3Y::cDelay_7jL5OrrN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_7jL5OrrN, m);
  cMsg_xRLfncve_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cSwitchcase_SUmggtcC_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x47BE8354: { // "clear"
      cMsg_a8L4T2O4_sendMessage(_c, 0, m);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_WSTD_DL3Y::cBinop_Uvu8wqTr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_8QfE5RJy_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::hTable_nEj2Ecly_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_k4Nwa9Bu_sendMessage(_c, 0, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_BLTWSDEf, 2, m, &cDelay_BLTWSDEf_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_zscEvrH7_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_8QfE5RJy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "resize");
  msg_setElementToFrom(m, 1, n, 0);
  hTable_onMessage(_c, &Context(_c)->hTable_nEj2Ecly, 0, m, &hTable_nEj2Ecly_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_dhZR70P1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 5000.0f, 0, m, &cBinop_Uvu8wqTr_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_xRLfncve_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "mirror");
  hTable_onMessage(_c, &Context(_c)->hTable_nEj2Ecly, 0, m, &hTable_nEj2Ecly_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_zscEvrH7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_BLTWSDEf, 0, m, &cDelay_BLTWSDEf_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_k4Nwa9Bu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0,  static_cast<float>(HV_N_SIMD));
  cDelay_onMessage(_c, &Context(_c)->cDelay_7jL5OrrN, 2, m, &cDelay_7jL5OrrN_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_a8L4T2O4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  sTabwrite_onMessage(_c, &Context(_c)->sTabwrite_KKGLprdo, 1, m, NULL);
}

void Heavy_WSTD_DL3Y::cTabhead_eZhNrjyZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_p9R3iqb9, HV_BINOP_SUBTRACT, 0, m, &cBinop_p9R3iqb9_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_1AaO5w9Z_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_RIUx4iig_sendMessage);
}

void Heavy_WSTD_DL3Y::cSystem_RIUx4iig_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_ZHSYsNuL_sendMessage);
}

void Heavy_WSTD_DL3Y::cVar_Ug2j6PCM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_4waLlVmx_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cDelay_EAcdvim9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_EAcdvim9, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_fspvZWSd, 0, m, &cDelay_fspvZWSd_sendMessage);
  sTabread_onMessage(_c, &Context(_c)->sTabread_tH4bhOve, 0, m, &sTabread_tH4bhOve_sendMessage);
}

void Heavy_WSTD_DL3Y::cDelay_fspvZWSd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_fspvZWSd, m);
  sTabread_onMessage(_c, &Context(_c)->sTabread_tH4bhOve, 0, m, &sTabread_tH4bhOve_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_fspvZWSd, 0, m, &cDelay_fspvZWSd_sendMessage);
}

void Heavy_WSTD_DL3Y::sTabread_tH4bhOve_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cBinop_onMessage(_c, &Context(_c)->cBinop_xe7cXupD, HV_BINOP_SUBTRACT, 0, m, &cBinop_xe7cXupD_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cBinop_dJur6t05_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_0tD5126C, HV_BINOP_MAX, 0, m, &cBinop_0tD5126C_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_ZHSYsNuL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_dJur6t05, HV_BINOP_MULTIPLY, 0, m, &cBinop_dJur6t05_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_p9R3iqb9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_f7cikNvu_sendMessage(_c, 0, m);
  sTabread_onMessage(_c, &Context(_c)->sTabread_tH4bhOve, 0, m, &sTabread_tH4bhOve_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_xycRbJyR_sendMessage);
}

void Heavy_WSTD_DL3Y::cSystem_acb69SBF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_xe7cXupD, HV_BINOP_SUBTRACT, 1, m, &cBinop_xe7cXupD_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_fspvZWSd, 2, m, &cDelay_fspvZWSd_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_4waLlVmx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(3);
  msg_init(m, 3, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "table");
  msg_setElementToFrom(m, 1, n, 0);
  msg_setSymbol(m, 2, "size");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_acb69SBF_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_f7cikNvu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_EAcdvim9, 0, m, &cDelay_EAcdvim9_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_fspvZWSd, 0, m, &cDelay_fspvZWSd_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_y5H9kAUE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0,  static_cast<float>(HV_N_SIMD));
  cBinop_onMessage(_c, &Context(_c)->cBinop_0tD5126C, HV_BINOP_MAX, 1, m, &cBinop_0tD5126C_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_0tD5126C_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_p9R3iqb9, HV_BINOP_SUBTRACT, 1, m, &cBinop_p9R3iqb9_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_xycRbJyR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_EAcdvim9, 0, m, &cDelay_EAcdvim9_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_G3Qp9ari_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_EAcdvim9, 2, m, &cDelay_EAcdvim9_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_xe7cXupD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_G3Qp9ari_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_rn220Vq5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_Ug2j6PCM, 0, m, &cVar_Ug2j6PCM_sendMessage);
  cMsg_1AaO5w9Z_sendMessage(_c, 0, m);
  cTabhead_onMessage(_c, &Context(_c)->cTabhead_eZhNrjyZ, 0, m, &cTabhead_eZhNrjyZ_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_OI5cXU7C_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 100.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_Ow5hPZrK, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cMsg_E9YcGJyb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 100.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_ATUTJXY6, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cMsg_tynhNU1Q_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 100.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_ssh1ghQY, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cMsg_AAJheok7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 100.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_3GArsV0h, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cMsg_UvCZcNYe_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 100.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_QahjCNHW, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cMsg_bzdeOwNl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 100.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_Qzr4di1X, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cMsg_zfW2gIrw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 100.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_fqNIJPDm, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cMsg_tMmqft2C_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 100.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_NLvvwlFB, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cVar_z9pSVdBR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_9fssQZ9n_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_Mcy7TCYV_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_qB4xk477_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_9fssQZ9n_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_z9pSVdBR, 1, m, &cVar_z9pSVdBR_sendMessage);
}

void Heavy_WSTD_DL3Y::cIf_BffxeTAm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cVar_onMessage(_c, &Context(_c)->cVar_hA54wfHY, 0, m, &cVar_hA54wfHY_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cIf_2I9Fp8uQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cVar_onMessage(_c, &Context(_c)->cVar_hA54wfHY, 0, m, &cVar_hA54wfHY_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cVar_KTSNM5qb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_2I9Fp8uQ, 0, m, &cIf_2I9Fp8uQ_sendMessage);
}

void Heavy_WSTD_DL3Y::cVar_a8jOr47g_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_BffxeTAm, 0, m, &cIf_BffxeTAm_sendMessage);
}

void Heavy_WSTD_DL3Y::cVar_xoh5MjSo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_rYS4SynM_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_aoxF2aZu_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_Fv9s4bDq_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_rYS4SynM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_xoh5MjSo, 1, m, &cVar_xoh5MjSo_sendMessage);
}

void Heavy_WSTD_DL3Y::cIf_QWyXFJ7J_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cVar_onMessage(_c, &Context(_c)->cVar_FiWHpum8, 0, m, &cVar_FiWHpum8_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cIf_8qm7zsQI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cVar_onMessage(_c, &Context(_c)->cVar_FiWHpum8, 0, m, &cVar_FiWHpum8_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cVar_aCrUJC4g_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_8qm7zsQI, 0, m, &cIf_8qm7zsQI_sendMessage);
}

void Heavy_WSTD_DL3Y::cVar_HiMBXEVf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_QWyXFJ7J, 0, m, &cIf_QWyXFJ7J_sendMessage);
}

void Heavy_WSTD_DL3Y::cVar_GdGTBdXt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_ORBky9Pa_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_flswP9LA_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_0w7sGDL9_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_ORBky9Pa_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_GdGTBdXt, 1, m, &cVar_GdGTBdXt_sendMessage);
}

void Heavy_WSTD_DL3Y::cIf_rOEo116H_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cVar_onMessage(_c, &Context(_c)->cVar_igTw5lsY, 0, m, &cVar_igTw5lsY_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cIf_jmGkcm2p_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cVar_onMessage(_c, &Context(_c)->cVar_igTw5lsY, 0, m, &cVar_igTw5lsY_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cVar_mMu9f0wv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_jmGkcm2p, 0, m, &cIf_jmGkcm2p_sendMessage);
}

void Heavy_WSTD_DL3Y::cVar_IVTFQbcY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_rOEo116H, 0, m, &cIf_rOEo116H_sendMessage);
}

void Heavy_WSTD_DL3Y::cVar_eeY8NB78_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_Mgdc7OUE, HV_BINOP_DIVIDE, 0, m, &cBinop_Mgdc7OUE_sendMessage);
}

void Heavy_WSTD_DL3Y::cVar_c1o2M1oB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_D6ub5d1e, HV_BINOP_MULTIPLY, 1, m, &cBinop_D6ub5d1e_sendMessage);
}

void Heavy_WSTD_DL3Y::cSwitchcase_4l2nb1kS_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0xFFFFFFFF: { // "bang"
      cSlice_onMessage(_c, &Context(_c)->cSlice_yIj8W0qV, 0, m, &cSlice_yIj8W0qV_sendMessage);
      break;
    }
    case 0x3E004DAB: { // "set"
      cSlice_onMessage(_c, &Context(_c)->cSlice_dzwQa2OX, 0, m, &cSlice_dzwQa2OX_sendMessage);
      break;
    }
    default: {
      cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_UAb3uaNb_sendMessage);
      cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_nTlHWp39_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_DL3Y::cSlice_yIj8W0qV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cVar_onMessage(_c, &Context(_c)->cVar_ng9Ds6He, 0, m, &cVar_ng9Ds6He_sendMessage);
      break;
    }
    case 1: {
      cVar_onMessage(_c, &Context(_c)->cVar_ng9Ds6He, 0, m, &cVar_ng9Ds6He_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cSlice_dzwQa2OX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cBinop_onMessage(_c, &Context(_c)->cBinop_wnT7OQ3Y, HV_BINOP_NEQ, 1, m, &cBinop_wnT7OQ3Y_sendMessage);
      cVar_onMessage(_c, &Context(_c)->cVar_ng9Ds6He, 1, m, &cVar_ng9Ds6He_sendMessage);
      break;
    }
    case 1: {
      cBinop_onMessage(_c, &Context(_c)->cBinop_wnT7OQ3Y, HV_BINOP_NEQ, 1, m, &cBinop_wnT7OQ3Y_sendMessage);
      cVar_onMessage(_c, &Context(_c)->cVar_ng9Ds6He, 1, m, &cVar_ng9Ds6He_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cVar_ng9Ds6He_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 5000.0f, 0, m, &cBinop_OnPCqIB1_sendMessage);
}

void Heavy_WSTD_DL3Y::cIf_j3JE8sMx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_rUvPEuaH_sendMessage);
      cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_J7XijwiM_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cCast_J7XijwiM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_ng9Ds6He, 0, m, &cVar_ng9Ds6He_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_rUvPEuaH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_wnT7OQ3Y, HV_BINOP_NEQ, 1, m, &cBinop_wnT7OQ3Y_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_wnT7OQ3Y_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_j3JE8sMx, 1, m, &cIf_j3JE8sMx_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_nTlHWp39_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_j3JE8sMx, 0, m, &cIf_j3JE8sMx_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_UAb3uaNb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_wnT7OQ3Y, HV_BINOP_NEQ, 0, m, &cBinop_wnT7OQ3Y_sendMessage);
}

void Heavy_WSTD_DL3Y::cVar_1j9C6T7s_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_YeHMNjNV_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_sOSig4tQ_sendMessage);
}

void Heavy_WSTD_DL3Y::cSwitchcase_vlxOBegH_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x0: { // "0.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_HBWUiXJm_sendMessage);
      break;
    }
    case 0x3F800000: { // "1.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_kdhzTwMw_sendMessage);
      break;
    }
    case 0x40000000: { // "2.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_LyIqzJEQ_sendMessage);
      break;
    }
    case 0x40400000: { // "3.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_34s5Fs8Q_sendMessage);
      break;
    }
    case 0x40800000: { // "4.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_XeQUf52l_sendMessage);
      break;
    }
    case 0x40A00000: { // "5.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_raLr1Pe5_sendMessage);
      break;
    }
    case 0x40C00000: { // "6.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_QpSZevXG_sendMessage);
      break;
    }
    case 0x40E00000: { // "7.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_6mtglD7y_sendMessage);
      break;
    }
    case 0x41000000: { // "8.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_qoLmR9iu_sendMessage);
      break;
    }
    case 0x41100000: { // "9.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_Ij8E1LPn_sendMessage);
      break;
    }
    case 0x41200000: { // "10.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_uBDrLBEG_sendMessage);
      break;
    }
    case 0x41300000: { // "11.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_Ck8tkzcn_sendMessage);
      break;
    }
    case 0x41400000: { // "12.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_NkPxlegC_sendMessage);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_WSTD_DL3Y::cCast_HBWUiXJm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_nhepxGUW_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cCast_kdhzTwMw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_gFOBZlxJ_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cCast_LyIqzJEQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_BWhmfFm8_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cCast_34s5Fs8Q_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_CuONM8Ce_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cCast_XeQUf52l_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_ZSylaqfo_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cCast_raLr1Pe5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_0UEDwicF_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cCast_QpSZevXG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_POwt2Vho_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cCast_6mtglD7y_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_CnQk20Sw_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cCast_qoLmR9iu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_rmVOJaa0_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cCast_Ij8E1LPn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_MYGaMjda_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cCast_uBDrLBEG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_zHAfX6s9_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cCast_Ck8tkzcn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_0aXu55fz_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cCast_NkPxlegC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_Mh4UfesM_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_Mgdc7OUE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_D6ub5d1e, HV_BINOP_MULTIPLY, 0, m, &cBinop_D6ub5d1e_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_D6ub5d1e_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_4l2nb1kS_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cCast_sOSig4tQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_eeY8NB78, 0, m, &cVar_eeY8NB78_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_c1o2M1oB, 0, m, &cVar_c1o2M1oB_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_YeHMNjNV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_Mgdc7OUE, HV_BINOP_DIVIDE, 1, m, &cBinop_Mgdc7OUE_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_C91oe9Gn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_c1o2M1oB, 0, m, &cVar_c1o2M1oB_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_bN3liLWS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_eeY8NB78, 0, m, &cVar_eeY8NB78_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_nhepxGUW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.166667f);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_C91oe9Gn_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_bN3liLWS_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_gFOBZlxJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.2f);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_C91oe9Gn_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_bN3liLWS_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_BWhmfFm8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.25f);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_C91oe9Gn_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_bN3liLWS_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_CuONM8Ce_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.333333f);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_C91oe9Gn_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_bN3liLWS_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_ZSylaqfo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.6f);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_C91oe9Gn_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_bN3liLWS_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_0UEDwicF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.666667f);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_C91oe9Gn_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_bN3liLWS_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_POwt2Vho_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_C91oe9Gn_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_bN3liLWS_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_CnQk20Sw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.5f);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_C91oe9Gn_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_bN3liLWS_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_rmVOJaa0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 2.0f);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_C91oe9Gn_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_bN3liLWS_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_MYGaMjda_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 3.0f);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_C91oe9Gn_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_bN3liLWS_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_zHAfX6s9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 4.0f);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_C91oe9Gn_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_bN3liLWS_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_0aXu55fz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 5.0f);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_C91oe9Gn_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_bN3liLWS_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_Mh4UfesM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 6.0f);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_C91oe9Gn_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_bN3liLWS_sendMessage);
}

void Heavy_WSTD_DL3Y::cVar_pddzqDAH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_quR1j7KP, HV_BINOP_DIVIDE, 0, m, &cBinop_quR1j7KP_sendMessage);
}

void Heavy_WSTD_DL3Y::cVar_NP5dAoqV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_lZYeh6vY, HV_BINOP_MULTIPLY, 1, m, &cBinop_lZYeh6vY_sendMessage);
}

void Heavy_WSTD_DL3Y::cSwitchcase_b1NLxuZZ_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0xFFFFFFFF: { // "bang"
      cSlice_onMessage(_c, &Context(_c)->cSlice_r5TBkaDS, 0, m, &cSlice_r5TBkaDS_sendMessage);
      break;
    }
    case 0x3E004DAB: { // "set"
      cSlice_onMessage(_c, &Context(_c)->cSlice_JW4ShkhI, 0, m, &cSlice_JW4ShkhI_sendMessage);
      break;
    }
    default: {
      cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_6Zxj4BHl_sendMessage);
      cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_NNzK3dTX_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_DL3Y::cSlice_r5TBkaDS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cVar_onMessage(_c, &Context(_c)->cVar_Uf8aCLcY, 0, m, &cVar_Uf8aCLcY_sendMessage);
      break;
    }
    case 1: {
      cVar_onMessage(_c, &Context(_c)->cVar_Uf8aCLcY, 0, m, &cVar_Uf8aCLcY_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cSlice_JW4ShkhI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cBinop_onMessage(_c, &Context(_c)->cBinop_FkW9U8Mp, HV_BINOP_NEQ, 1, m, &cBinop_FkW9U8Mp_sendMessage);
      cVar_onMessage(_c, &Context(_c)->cVar_Uf8aCLcY, 1, m, &cVar_Uf8aCLcY_sendMessage);
      break;
    }
    case 1: {
      cBinop_onMessage(_c, &Context(_c)->cBinop_FkW9U8Mp, HV_BINOP_NEQ, 1, m, &cBinop_FkW9U8Mp_sendMessage);
      cVar_onMessage(_c, &Context(_c)->cVar_Uf8aCLcY, 1, m, &cVar_Uf8aCLcY_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cVar_Uf8aCLcY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 5000.0f, 0, m, &cBinop_z7Lq9vas_sendMessage);
}

void Heavy_WSTD_DL3Y::cIf_ooI6GAvQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_KJDBiovW_sendMessage);
      cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_VqLx9Nsi_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cCast_VqLx9Nsi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_Uf8aCLcY, 0, m, &cVar_Uf8aCLcY_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_KJDBiovW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_FkW9U8Mp, HV_BINOP_NEQ, 1, m, &cBinop_FkW9U8Mp_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_FkW9U8Mp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_ooI6GAvQ, 1, m, &cIf_ooI6GAvQ_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_NNzK3dTX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_ooI6GAvQ, 0, m, &cIf_ooI6GAvQ_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_6Zxj4BHl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_FkW9U8Mp, HV_BINOP_NEQ, 0, m, &cBinop_FkW9U8Mp_sendMessage);
}

void Heavy_WSTD_DL3Y::cVar_FyRMhvMg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_Fp5kXoc7_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_zmwysrAW_sendMessage);
}

void Heavy_WSTD_DL3Y::cSwitchcase_Bmzj1R8g_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x0: { // "0.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_8ihWkKwU_sendMessage);
      break;
    }
    case 0x3F800000: { // "1.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_mScIqPvj_sendMessage);
      break;
    }
    case 0x40000000: { // "2.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_oEenepPg_sendMessage);
      break;
    }
    case 0x40400000: { // "3.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_eC74zK1j_sendMessage);
      break;
    }
    case 0x40800000: { // "4.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_ZHBz2F74_sendMessage);
      break;
    }
    case 0x40A00000: { // "5.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_QnECV2EH_sendMessage);
      break;
    }
    case 0x40C00000: { // "6.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_PojzSemS_sendMessage);
      break;
    }
    case 0x40E00000: { // "7.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_mgLRl79I_sendMessage);
      break;
    }
    case 0x41000000: { // "8.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_5alvEsbU_sendMessage);
      break;
    }
    case 0x41100000: { // "9.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_WWUaX3Pd_sendMessage);
      break;
    }
    case 0x41200000: { // "10.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_6qTd9Nl3_sendMessage);
      break;
    }
    case 0x41300000: { // "11.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_rJA9Zrj6_sendMessage);
      break;
    }
    case 0x41400000: { // "12.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_ZTEDa94Q_sendMessage);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_WSTD_DL3Y::cCast_8ihWkKwU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_Gp5qIFXq_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cCast_mScIqPvj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_lsPQ5YVJ_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cCast_oEenepPg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_pNYC0Dd3_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cCast_eC74zK1j_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_9lAvwWKI_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cCast_ZHBz2F74_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_tvrllueg_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cCast_QnECV2EH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_CcUOLzTN_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cCast_PojzSemS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_rn6C7PZK_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cCast_mgLRl79I_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_2YTIUrJV_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cCast_5alvEsbU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_dIHyZ4OF_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cCast_WWUaX3Pd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_qCuRWsu7_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cCast_6qTd9Nl3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_khHdMMiC_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cCast_rJA9Zrj6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_crIdIG88_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cCast_ZTEDa94Q_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_cvvPmvLq_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_quR1j7KP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_lZYeh6vY, HV_BINOP_MULTIPLY, 0, m, &cBinop_lZYeh6vY_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_lZYeh6vY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_b1NLxuZZ_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cCast_zmwysrAW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_pddzqDAH, 0, m, &cVar_pddzqDAH_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_NP5dAoqV, 0, m, &cVar_NP5dAoqV_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_Fp5kXoc7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_quR1j7KP, HV_BINOP_DIVIDE, 1, m, &cBinop_quR1j7KP_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_8IQ1u2Ho_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_pddzqDAH, 0, m, &cVar_pddzqDAH_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_BaVEQW1F_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_NP5dAoqV, 0, m, &cVar_NP5dAoqV_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_Gp5qIFXq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.166667f);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_BaVEQW1F_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_8IQ1u2Ho_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_lsPQ5YVJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.2f);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_BaVEQW1F_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_8IQ1u2Ho_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_pNYC0Dd3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.25f);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_BaVEQW1F_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_8IQ1u2Ho_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_9lAvwWKI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.333333f);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_BaVEQW1F_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_8IQ1u2Ho_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_tvrllueg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.6f);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_BaVEQW1F_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_8IQ1u2Ho_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_CcUOLzTN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.666667f);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_BaVEQW1F_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_8IQ1u2Ho_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_rn6C7PZK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_BaVEQW1F_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_8IQ1u2Ho_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_2YTIUrJV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.5f);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_BaVEQW1F_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_8IQ1u2Ho_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_dIHyZ4OF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 2.0f);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_BaVEQW1F_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_8IQ1u2Ho_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_qCuRWsu7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 3.0f);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_BaVEQW1F_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_8IQ1u2Ho_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_khHdMMiC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 4.0f);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_BaVEQW1F_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_8IQ1u2Ho_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_crIdIG88_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 5.0f);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_BaVEQW1F_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_8IQ1u2Ho_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_cvvPmvLq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 6.0f);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_BaVEQW1F_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_8IQ1u2Ho_sendMessage);
}

void Heavy_WSTD_DL3Y::cVar_FuwGp9Bn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_nCAOwvtF, HV_BINOP_DIVIDE, 0, m, &cBinop_nCAOwvtF_sendMessage);
}

void Heavy_WSTD_DL3Y::cVar_A9EgloHC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_9ukRBvCU, HV_BINOP_MULTIPLY, 1, m, &cBinop_9ukRBvCU_sendMessage);
}

void Heavy_WSTD_DL3Y::cSwitchcase_ydakOSqZ_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0xFFFFFFFF: { // "bang"
      cSlice_onMessage(_c, &Context(_c)->cSlice_zlbRe5X8, 0, m, &cSlice_zlbRe5X8_sendMessage);
      break;
    }
    case 0x3E004DAB: { // "set"
      cSlice_onMessage(_c, &Context(_c)->cSlice_UkGz3ydT, 0, m, &cSlice_UkGz3ydT_sendMessage);
      break;
    }
    default: {
      cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_AhP9ThZD_sendMessage);
      cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_oCXch49S_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_DL3Y::cSlice_zlbRe5X8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cVar_onMessage(_c, &Context(_c)->cVar_tMPCEVSe, 0, m, &cVar_tMPCEVSe_sendMessage);
      break;
    }
    case 1: {
      cVar_onMessage(_c, &Context(_c)->cVar_tMPCEVSe, 0, m, &cVar_tMPCEVSe_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cSlice_UkGz3ydT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cBinop_onMessage(_c, &Context(_c)->cBinop_JuvvgzPk, HV_BINOP_NEQ, 1, m, &cBinop_JuvvgzPk_sendMessage);
      cVar_onMessage(_c, &Context(_c)->cVar_tMPCEVSe, 1, m, &cVar_tMPCEVSe_sendMessage);
      break;
    }
    case 1: {
      cBinop_onMessage(_c, &Context(_c)->cBinop_JuvvgzPk, HV_BINOP_NEQ, 1, m, &cBinop_JuvvgzPk_sendMessage);
      cVar_onMessage(_c, &Context(_c)->cVar_tMPCEVSe, 1, m, &cVar_tMPCEVSe_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cVar_tMPCEVSe_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 5000.0f, 0, m, &cBinop_izZKufuy_sendMessage);
}

void Heavy_WSTD_DL3Y::cIf_QvZjLH9N_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_EpkgkCIk_sendMessage);
      cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_d7q56dDP_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cCast_d7q56dDP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_tMPCEVSe, 0, m, &cVar_tMPCEVSe_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_EpkgkCIk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_JuvvgzPk, HV_BINOP_NEQ, 1, m, &cBinop_JuvvgzPk_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_JuvvgzPk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_QvZjLH9N, 1, m, &cIf_QvZjLH9N_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_oCXch49S_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_QvZjLH9N, 0, m, &cIf_QvZjLH9N_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_AhP9ThZD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_JuvvgzPk, HV_BINOP_NEQ, 0, m, &cBinop_JuvvgzPk_sendMessage);
}

void Heavy_WSTD_DL3Y::cVar_h9UYmtAg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_JGYy5oqZ_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_CDYpv3bQ_sendMessage);
}

void Heavy_WSTD_DL3Y::cSwitchcase_3XzBt4SQ_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x0: { // "0.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_OfpLdakR_sendMessage);
      break;
    }
    case 0x3F800000: { // "1.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_Seio8qiL_sendMessage);
      break;
    }
    case 0x40000000: { // "2.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_Fhk84qWV_sendMessage);
      break;
    }
    case 0x40400000: { // "3.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_vPxBIUcy_sendMessage);
      break;
    }
    case 0x40800000: { // "4.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_H0TYd4UH_sendMessage);
      break;
    }
    case 0x40A00000: { // "5.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_v3788X3X_sendMessage);
      break;
    }
    case 0x40C00000: { // "6.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_kPNoYWDG_sendMessage);
      break;
    }
    case 0x40E00000: { // "7.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_g79cqDM9_sendMessage);
      break;
    }
    case 0x41000000: { // "8.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_HnHNwtIM_sendMessage);
      break;
    }
    case 0x41100000: { // "9.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_UCsWnqbk_sendMessage);
      break;
    }
    case 0x41200000: { // "10.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_XtDb4XXS_sendMessage);
      break;
    }
    case 0x41300000: { // "11.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_HuciME7Z_sendMessage);
      break;
    }
    case 0x41400000: { // "12.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_R2vVHoHr_sendMessage);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_WSTD_DL3Y::cCast_OfpLdakR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_pbHbTIAk_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cCast_Seio8qiL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_tGeh6yWu_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cCast_Fhk84qWV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_qGAjVkg2_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cCast_vPxBIUcy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_n6VuOm3x_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cCast_H0TYd4UH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_NuKaHpMP_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cCast_v3788X3X_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_mEmDvzwj_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cCast_kPNoYWDG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_Fa8iOvtR_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cCast_g79cqDM9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_xys8D3zC_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cCast_HnHNwtIM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_PWiXhY70_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cCast_UCsWnqbk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_ga1YcqwX_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cCast_XtDb4XXS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_ArDBFMc6_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cCast_HuciME7Z_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_d2FK8khC_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cCast_R2vVHoHr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_wwrv9QzQ_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_nCAOwvtF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_9ukRBvCU, HV_BINOP_MULTIPLY, 0, m, &cBinop_9ukRBvCU_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_9ukRBvCU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_ydakOSqZ_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cCast_JGYy5oqZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_nCAOwvtF, HV_BINOP_DIVIDE, 1, m, &cBinop_nCAOwvtF_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_CDYpv3bQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_FuwGp9Bn, 0, m, &cVar_FuwGp9Bn_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_A9EgloHC, 0, m, &cVar_A9EgloHC_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_P8K3LWzz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_FuwGp9Bn, 0, m, &cVar_FuwGp9Bn_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_FQfNrImC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_A9EgloHC, 0, m, &cVar_A9EgloHC_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_pbHbTIAk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.166667f);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_FQfNrImC_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_P8K3LWzz_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_tGeh6yWu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.2f);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_FQfNrImC_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_P8K3LWzz_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_qGAjVkg2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.25f);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_FQfNrImC_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_P8K3LWzz_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_n6VuOm3x_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.333333f);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_FQfNrImC_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_P8K3LWzz_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_NuKaHpMP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.6f);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_FQfNrImC_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_P8K3LWzz_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_mEmDvzwj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.666667f);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_FQfNrImC_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_P8K3LWzz_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_Fa8iOvtR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_FQfNrImC_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_P8K3LWzz_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_xys8D3zC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.5f);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_FQfNrImC_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_P8K3LWzz_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_PWiXhY70_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 2.0f);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_FQfNrImC_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_P8K3LWzz_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_ga1YcqwX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 3.0f);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_FQfNrImC_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_P8K3LWzz_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_ArDBFMc6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 4.0f);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_FQfNrImC_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_P8K3LWzz_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_d2FK8khC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 5.0f);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_FQfNrImC_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_P8K3LWzz_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_wwrv9QzQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 6.0f);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_FQfNrImC_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_P8K3LWzz_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_X5wrbyTj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "highvol");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_GWW7tEc3_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_KVgikAdd_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cMsg_IYdR7HbO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "midvol");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_GWW7tEc3_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_KVgikAdd_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cMsg_WVd0aNU1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "lowvol");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_GWW7tEc3_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_KVgikAdd_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cMsg_Ud0ieM5m_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "midfreq");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_GWW7tEc3_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_KVgikAdd_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cMsg_X4SqjULN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "midq");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_GWW7tEc3_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_KVgikAdd_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cMsg_VSoOWNll_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1337.0f);
  cVar_onMessage(_c, &Context(_c)->cVar_w56Lrt0V, 0, m, &cVar_w56Lrt0V_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_I1bmMFV1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cVar_onMessage(_c, &Context(_c)->cVar_D8WmDR5Z, 0, m, &cVar_D8WmDR5Z_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_0SWLibYN, 0, m, &cVar_0SWLibYN_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_Iml1QuDm, 0, m, &cVar_Iml1QuDm_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_DeuFJQTD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "mix");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_VQUJ8MAU_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cMsg_tL3Ix4La_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "feedback");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_VQUJ8MAU_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cBinop_PywiQHJw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_CFsMZjiS, 0, m, &cVar_CFsMZjiS_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_pvPlAQh4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_01QURJwf, 0, m, &cVar_01QURJwf_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_c7kZ2DP2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_o2G2AgAP, 0, m, &cVar_o2G2AgAP_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_PJxxQovH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "time");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_VQUJ8MAU_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cMsg_j6IlEQHG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "cross");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_VQUJ8MAU_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cMsg_DrYqhLK8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "mix");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_ANTMaM0b_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cMsg_ZcI23LS7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "feedback");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_ANTMaM0b_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cBinop_TpyaM4Vj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_0us5sJa8, 0, m, &cVar_0us5sJa8_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_a291Kt06_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_QQdUhnd1, 0, m, &cVar_QQdUhnd1_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_irq57jR1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_o7IHboxy, 0, m, &cVar_o7IHboxy_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_uewRwhk6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "time");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_ANTMaM0b_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cMsg_2NcsGtCh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "cross");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_ANTMaM0b_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cMsg_OH1SbBPX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "mix");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_3xOLzmQq_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cMsg_4tRZvW6z_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "feedback");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_3xOLzmQq_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cBinop_eBKibXZS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_XFPMxAe8, 0, m, &cVar_XFPMxAe8_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_CK830VGd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_DCV0EudC, 0, m, &cVar_DCV0EudC_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_XDTyrkcV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_zIqMPq9n, 0, m, &cVar_zIqMPq9n_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_beYweui3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "time");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_3xOLzmQq_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cMsg_9YWiI0BX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "cross");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_3xOLzmQq_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cBinop_OnPCqIB1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_a8jOr47g, 0, m, &cVar_a8jOr47g_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_qB4xk477_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_3dHyp6EU_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_6AVNlO5A_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_Mcy7TCYV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_DgDNg3MK_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_vA2kPtB3_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_DgDNg3MK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_2I9Fp8uQ, 1, m, &cIf_2I9Fp8uQ_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_vA2kPtB3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_KTSNM5qb, 0, m, &cVar_KTSNM5qb_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_6AVNlO5A_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_a8jOr47g, 0, m, &cVar_a8jOr47g_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_3dHyp6EU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_BffxeTAm, 1, m, &cIf_BffxeTAm_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_z7Lq9vas_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_HiMBXEVf, 0, m, &cVar_HiMBXEVf_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_Fv9s4bDq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_1QMYCRep_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_ERNodID4_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_aoxF2aZu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_dEaRWTo1_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_0x8aInvi_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_dEaRWTo1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_8qm7zsQI, 1, m, &cIf_8qm7zsQI_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_0x8aInvi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_aCrUJC4g, 0, m, &cVar_aCrUJC4g_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_1QMYCRep_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_QWyXFJ7J, 1, m, &cIf_QWyXFJ7J_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_ERNodID4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_HiMBXEVf, 0, m, &cVar_HiMBXEVf_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_izZKufuy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_IVTFQbcY, 0, m, &cVar_IVTFQbcY_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_0w7sGDL9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_tpKBH6QY_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_IK60LBef_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_flswP9LA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_MrMRo0eD_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_SHraC8Oz_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_SHraC8Oz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_mMu9f0wv, 0, m, &cVar_mMu9f0wv_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_MrMRo0eD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_jmGkcm2p, 1, m, &cIf_jmGkcm2p_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_tpKBH6QY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_rOEo116H, 1, m, &cIf_rOEo116H_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_IK60LBef_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_IVTFQbcY, 0, m, &cVar_IVTFQbcY_sendMessage);
}

void Heavy_WSTD_DL3Y::cReceive_YIHOaU22_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_D8WmDR5Z, 0, m, &cVar_D8WmDR5Z_sendMessage);
}

void Heavy_WSTD_DL3Y::cReceive_NMuCWEdd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_0SWLibYN, 0, m, &cVar_0SWLibYN_sendMessage);
}

void Heavy_WSTD_DL3Y::cReceive_F1OptNiJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_Iml1QuDm, 0, m, &cVar_Iml1QuDm_sendMessage);
}

void Heavy_WSTD_DL3Y::cReceive_VqCZOEsI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_KdNlQHS7, 0, m, &cVar_KdNlQHS7_sendMessage);
}

void Heavy_WSTD_DL3Y::cReceive_JF2gJat3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_PmtlG92e_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_kaiC1srV_sendMessage);
}

void Heavy_WSTD_DL3Y::cReceive_TVYZuOCE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_vy0mqpbh_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_mdZE6ifP_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_x3lEgOGc_sendMessage);
}

void Heavy_WSTD_DL3Y::cReceive_esqRdfFY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_sRc82d1f_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_ddaT7Lw3_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_c7WDawPm_sendMessage);
}

void Heavy_WSTD_DL3Y::cReceive_i6SEP5JK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_ap0rrPAv_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_cwGSfEqW_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_uetwD1ZC_sendMessage);
}

void Heavy_WSTD_DL3Y::cReceive_PQmPfaKP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_eVCpTord_sendMessage(_c, 0, m);
  cMsg_jex5Xyzv_sendMessage(_c, 0, m);
  cMsg_uqt2724L_sendMessage(_c, 0, m);
  cMsg_5KLLf38c_sendMessage(_c, 0, m);
  cMsg_RyWSmM2b_sendMessage(_c, 0, m);
  cMsg_Zt3zo1zd_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_S2FnHzAa, 0, m, &cVar_S2FnHzAa_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_KdNlQHS7, 0, m, &cVar_KdNlQHS7_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_xwHJrqs3, 0, m, &cVar_xwHJrqs3_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_AESlzgvs, 0, m, &cVar_AESlzgvs_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_15keEgoi, 0, m, &cVar_15keEgoi_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_6yCMuDdD, 0, m, &cVar_6yCMuDdD_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_JiXHpUmq, 0, m, &cVar_JiXHpUmq_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_6t0wcwI8, 0, m, &cVar_6t0wcwI8_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_zGSZ7uMm, 0, m, &cVar_zGSZ7uMm_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_IxYd8BZY, 0, m, &cVar_IxYd8BZY_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_H1z8FLjH, 0, m, &cVar_H1z8FLjH_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_h2BeBiec, 0, m, &cVar_h2BeBiec_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_R87ErOZK, 0, m, &cVar_R87ErOZK_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_3tjMy5FY, 0, m, &cVar_3tjMy5FY_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_zFFsgIX5, 0, m, &cVar_zFFsgIX5_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_sxS9dKVH, 0, m, &cVar_sxS9dKVH_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_zo4jBNa3, 0, m, &cVar_zo4jBNa3_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_N8VtPLd8, 0, m, &cVar_N8VtPLd8_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_k9O3uvFI, 0, m, &cVar_k9O3uvFI_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_MFUbvpCs, 0, m, &cVar_MFUbvpCs_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_w6tysDjU, 0, m, &cVar_w6tysDjU_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_0F1J0yQb, 0, m, &cVar_0F1J0yQb_sendMessage);
  cMsg_0cu241lK_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_hCsFva0g, 0, m, &cVar_hCsFva0g_sendMessage);
  cMsg_ywqiYwcW_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_g4lwAWIL, 0, m, &cVar_g4lwAWIL_sendMessage);
  cMsg_f80m9x40_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_djxw5BXX, 0, m, &cVar_djxw5BXX_sendMessage);
  cMsg_A0puEiWQ_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_LYVXFPe4, 0, m, &cVar_LYVXFPe4_sendMessage);
  cMsg_hMM4gOEp_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_lm9c61Sj, 0, m, &cVar_lm9c61Sj_sendMessage);
  cMsg_6vr575bg_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_wUZ09Bxj, 0, m, &cVar_wUZ09Bxj_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_n68XL8JM, 0, m, &cVar_n68XL8JM_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_wuegmjRK, 0, m, &cVar_wuegmjRK_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_OQKpa1tm, 0, m, &cVar_OQKpa1tm_sendMessage);
  cMsg_l7537s4j_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_dmzwSFPG, 0, m, &cVar_dmzwSFPG_sendMessage);
  cMsg_zA3wx9eW_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_uBowDlEC, 0, m, &cVar_uBowDlEC_sendMessage);
  cMsg_EIBJvzgN_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_866JjA7K, 0, m, &cVar_866JjA7K_sendMessage);
  cMsg_DjFPkLfy_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_TKACTgDx, 0, m, &cVar_TKACTgDx_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_sZ8JogDs, 0, m, &cVar_sZ8JogDs_sendMessage);
  cMsg_g4050QOP_sendMessage(_c, 0, m);
  cMsg_JCj8t1Zn_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_Fw0TLtxH, 0, m, &cVar_Fw0TLtxH_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_kWIOF8hd, 0, m, &cVar_kWIOF8hd_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_bM9Ygxdl, 0, m, &cVar_bM9Ygxdl_sendMessage);
  cMsg_NWV2iISe_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_gz7rIqHf, 0, m, &cVar_gz7rIqHf_sendMessage);
  cMsg_aBWW3h5n_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_hMMLlDmO, 0, m, &cVar_hMMLlDmO_sendMessage);
  cMsg_NylDhsny_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_Hm4udIqr, 0, m, &cVar_Hm4udIqr_sendMessage);
  cMsg_ZL58MV4s_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_W1Et6mJN, 0, m, &cVar_W1Et6mJN_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_BojHGObu, 0, m, &cVar_BojHGObu_sendMessage);
  cMsg_VhYIUcXK_sendMessage(_c, 0, m);
  cMsg_478XRsTX_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_PxFv334s, 0, m, &cVar_PxFv334s_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_qJHoIyBj, 0, m, &cVar_qJHoIyBj_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_gcErxsRk, 0, m, &cVar_gcErxsRk_sendMessage);
  cMsg_qfEHrji8_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_53agGqRN, 0, m, &cVar_53agGqRN_sendMessage);
  cMsg_6GC8SqlV_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_Pe2HEZID, 0, m, &cVar_Pe2HEZID_sendMessage);
  cMsg_ir3dKohv_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_ix2p16dk, 0, m, &cVar_ix2p16dk_sendMessage);
  cMsg_s5PYGZ8H_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_0w4wa58Q, 0, m, &cVar_0w4wa58Q_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_DeJfeGt3, 0, m, &cVar_DeJfeGt3_sendMessage);
  cMsg_KGKMp0Vy_sendMessage(_c, 0, m);
  cMsg_qwCCI4KG_sendMessage(_c, 0, m);
  cMsg_I1bmMFV1_sendMessage(_c, 0, m);
  cMsg_VSoOWNll_sendMessage(_c, 0, m);
  cMsg_s7sQGzLa_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_x88GL5B8, 0, m, &cVar_x88GL5B8_sendMessage);
  cMsg_uYuiA0yP_sendMessage(_c, 0, m);
  cTabhead_onMessage(_c, &Context(_c)->cTabhead_ZKU1HCrI, 0, m, &cTabhead_ZKU1HCrI_sendMessage);
  cMsg_Dns0cXns_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_YFi9AuHy, 0, m, &cVar_YFi9AuHy_sendMessage);
  cMsg_gvrV4clK_sendMessage(_c, 0, m);
  cTabhead_onMessage(_c, &Context(_c)->cTabhead_hZDFpjvk, 0, m, &cTabhead_hZDFpjvk_sendMessage);
  cMsg_gQqJDrO5_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_Hppg8hr8, 0, m, &cVar_Hppg8hr8_sendMessage);
  cMsg_lkaCE40E_sendMessage(_c, 0, m);
  cTabhead_onMessage(_c, &Context(_c)->cTabhead_5sRjkEwK, 0, m, &cTabhead_5sRjkEwK_sendMessage);
  cMsg_CdxZoUjo_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_k0ddEbLk, 0, m, &cVar_k0ddEbLk_sendMessage);
  cMsg_aUOFYcyW_sendMessage(_c, 0, m);
  cTabhead_onMessage(_c, &Context(_c)->cTabhead_Vdsejnn7, 0, m, &cTabhead_Vdsejnn7_sendMessage);
  cMsg_3W5EYgsl_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_0kfGGsqs, 0, m, &cVar_0kfGGsqs_sendMessage);
  cMsg_vGk3oulp_sendMessage(_c, 0, m);
  cTabhead_onMessage(_c, &Context(_c)->cTabhead_YU2Sh6ov, 0, m, &cTabhead_YU2Sh6ov_sendMessage);
  cMsg_y5H9kAUE_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_Ug2j6PCM, 0, m, &cVar_Ug2j6PCM_sendMessage);
  cMsg_1AaO5w9Z_sendMessage(_c, 0, m);
  cTabhead_onMessage(_c, &Context(_c)->cTabhead_eZhNrjyZ, 0, m, &cTabhead_eZhNrjyZ_sendMessage);
}

void Heavy_WSTD_DL3Y::cReceive_bk1bYnJn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_5qxKnxfz, HV_BINOP_MULTIPLY, 0, m, &cBinop_5qxKnxfz_sendMessage);
}

void Heavy_WSTD_DL3Y::cReceive_VuPP32n3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_aAr95BJ1_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_ykm2iT84_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_LGPL9osB_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -2.0f, 0, m, &cBinop_cIoKWf32_sendMessage);
}

void Heavy_WSTD_DL3Y::cReceive_SXWOyGRT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_Acpls1Zx_sendMessage);
  cMsg_2zMzzV0F_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cReceive_OrFggUkN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_bm2cUtUi, HV_BINOP_MULTIPLY, 0, m, &cBinop_bm2cUtUi_sendMessage);
}

void Heavy_WSTD_DL3Y::cReceive_GuN7lIS6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -2.0f, 0, m, &cBinop_ZPSM5ED3_sendMessage);
}

void Heavy_WSTD_DL3Y::cReceive_NPFkF5Ze_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_YvRWZlM4, HV_BINOP_MULTIPLY, 1, m, &cBinop_YvRWZlM4_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_Gr5g7rGX_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_LLDYQNvP_sendMessage);
  cMsg_SjkSmgtc_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cReceive_wETDpJeQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_JWftv52H, HV_BINOP_MULTIPLY, 0, m, &cBinop_JWftv52H_sendMessage);
}

void Heavy_WSTD_DL3Y::cReceive_OrQQzB3r_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_mszXgqye_sendMessage(_c, 0, m);
  cMsg_WftNm2xp_sendMessage(_c, 0, m);
  cMsg_o1KrCWaP_sendMessage(_c, 0, m);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -2.0f, 0, m, &cBinop_84ggeXJ0_sendMessage);
}

void Heavy_WSTD_DL3Y::cReceive_gBpW5Yt5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_9quSnaIz_sendMessage);
  cMsg_kpDsGWy0_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cReceive_8vSBaZHa_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_15keEgoi, 0, m, &cVar_15keEgoi_sendMessage);
}

void Heavy_WSTD_DL3Y::cReceive_7NE2K9x4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_mm9Qmmir_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_jA0iGdk2_sendMessage);
}

void Heavy_WSTD_DL3Y::cReceive_idPyvD2n_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_SDV9UpoW_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_XpZ8J0nj_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_vehAzyNZ_sendMessage);
}

void Heavy_WSTD_DL3Y::cReceive_dWeOKwMe_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_kvaKNELy_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_dvldP1PG_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_6LdahSVH_sendMessage);
}

void Heavy_WSTD_DL3Y::cReceive_ASxy4lNE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_mPeD2e2W_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_ydb0LzKC_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_Kqjn2cPF_sendMessage);
}

void Heavy_WSTD_DL3Y::cReceive_hKoFRC98_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_Dh2xty4y, HV_BINOP_MULTIPLY, 0, m, &cBinop_Dh2xty4y_sendMessage);
}

void Heavy_WSTD_DL3Y::cReceive_EAARJt7o_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_TNfJZOkn_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_npZIzU75_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_d6Jf5VvV_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -2.0f, 0, m, &cBinop_LLUOswtw_sendMessage);
}

void Heavy_WSTD_DL3Y::cReceive_UUr3ft4L_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_ft1GQeyG_sendMessage);
  cMsg_gxUyZ7jO_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cReceive_QLhkeuJu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_PI85FqLh, HV_BINOP_MULTIPLY, 0, m, &cBinop_PI85FqLh_sendMessage);
}

void Heavy_WSTD_DL3Y::cReceive_6tBqTAYJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -2.0f, 0, m, &cBinop_yg95cEHn_sendMessage);
}

void Heavy_WSTD_DL3Y::cReceive_ikRfXfWV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_1GqZGE1O, HV_BINOP_MULTIPLY, 1, m, &cBinop_1GqZGE1O_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_IPd3r4jF_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_cLCw8TId_sendMessage);
  cMsg_PLeIFQXr_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cReceive_M96gQdAE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_RusIjfmo, HV_BINOP_MULTIPLY, 0, m, &cBinop_RusIjfmo_sendMessage);
}

void Heavy_WSTD_DL3Y::cReceive_JlkWrMyG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_v4uW9i0h_sendMessage(_c, 0, m);
  cMsg_8sejfpAl_sendMessage(_c, 0, m);
  cMsg_kIgmrC2p_sendMessage(_c, 0, m);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -2.0f, 0, m, &cBinop_GVl3VQyP_sendMessage);
}

void Heavy_WSTD_DL3Y::cReceive_FOKuksaM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_T4ncjAwp_sendMessage);
  cMsg_YkHi3Bn0_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cReceive_yjbinuyf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_w56Lrt0V, 0, m, &cVar_w56Lrt0V_sendMessage);
}

void Heavy_WSTD_DL3Y::cReceive_B9WQRlvL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 100.0f, 0, m, &cBinop_PywiQHJw_sendMessage);
}

void Heavy_WSTD_DL3Y::cReceive_tW90TCZZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 100.0f, 0, m, &cBinop_pvPlAQh4_sendMessage);
}

void Heavy_WSTD_DL3Y::cReceive_ILSFRh0y_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 100.0f, 0, m, &cBinop_c7kZ2DP2_sendMessage);
}

void Heavy_WSTD_DL3Y::cReceive_9mVOD0l4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 100.0f, 0, m, &cBinop_TpyaM4Vj_sendMessage);
}

void Heavy_WSTD_DL3Y::cReceive_Y38Eq96W_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 100.0f, 0, m, &cBinop_a291Kt06_sendMessage);
}

void Heavy_WSTD_DL3Y::cReceive_m8gNfGIf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 100.0f, 0, m, &cBinop_eBKibXZS_sendMessage);
}

void Heavy_WSTD_DL3Y::cReceive_HmP6TOLw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 100.0f, 0, m, &cBinop_CK830VGd_sendMessage);
}

void Heavy_WSTD_DL3Y::cReceive_a2pVVtLv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 100.0f, 0, m, &cBinop_XDTyrkcV_sendMessage);
}

void Heavy_WSTD_DL3Y::cReceive_H99YO7hC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 100.0f, 0, m, &cBinop_irq57jR1_sendMessage);
}

void Heavy_WSTD_DL3Y::cReceive_ZTVhANfK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_rAooRakH, HV_BINOP_MULTIPLY, 1, m, &cBinop_rAooRakH_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_oux6iRZQ_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_i1MXaYwS, HV_BINOP_MULTIPLY, 1, m, &cBinop_i1MXaYwS_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_gUeCsYQj_sendMessage);
}

void Heavy_WSTD_DL3Y::cReceive_1zBm6Ndd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_gSHCHyqD, m);
  sVarf_onMessage(_c, &Context(_c)->sVarf_iYK4SP5L, m);
}

void Heavy_WSTD_DL3Y::cReceive_mpZs7deU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 1.0f, 0, m, &cBinop_pQPGdTj0_sendMessage);
}

void Heavy_WSTD_DL3Y::cReceive_V4fO0Zpk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 1.0f, 0, m, &cBinop_IU4V3FLq_sendMessage);
}

void Heavy_WSTD_DL3Y::cReceive_QO7LABFT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_qu0z6zJb, HV_BINOP_MULTIPLY, 1, m, &cBinop_qu0z6zJb_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_KqFHaIqV_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_17OZuesF, HV_BINOP_MULTIPLY, 1, m, &cBinop_17OZuesF_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_cDUy8PUK_sendMessage);
}

void Heavy_WSTD_DL3Y::cReceive_AYKlTuOy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_Lcyy7tnU, m);
  sVarf_onMessage(_c, &Context(_c)->sVarf_gnF6iaaJ, m);
}

void Heavy_WSTD_DL3Y::cReceive_61c3LaMw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 1.0f, 0, m, &cBinop_mJlPfVgB_sendMessage);
}

void Heavy_WSTD_DL3Y::cReceive_MQXv8zZU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 1.0f, 0, m, &cBinop_6P5tSjFw_sendMessage);
}

void Heavy_WSTD_DL3Y::cReceive_xw9wQJgG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_GjbQeYqr, HV_BINOP_MULTIPLY, 1, m, &cBinop_GjbQeYqr_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_x9ETNRft_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_dJur6t05, HV_BINOP_MULTIPLY, 1, m, &cBinop_dJur6t05_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_rn220Vq5_sendMessage);
}

void Heavy_WSTD_DL3Y::cReceive_9kpmztE7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_fSuzIh6O, m);
  sVarf_onMessage(_c, &Context(_c)->sVarf_tmovl8yk, m);
}

void Heavy_WSTD_DL3Y::cReceive_NsHFswVU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 1.0f, 0, m, &cBinop_VhGqTpG0_sendMessage);
}

void Heavy_WSTD_DL3Y::cReceive_gh5EyZ09_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 1.0f, 0, m, &cBinop_kPvYakmy_sendMessage);
}

void Heavy_WSTD_DL3Y::cReceive_9tmJ1Jb2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_KTSNM5qb, 0, m, &cVar_KTSNM5qb_sendMessage);
}

void Heavy_WSTD_DL3Y::cReceive_upPohuRU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_z9pSVdBR, 0, m, &cVar_z9pSVdBR_sendMessage);
}

void Heavy_WSTD_DL3Y::cReceive_OSqiHt4f_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_xoh5MjSo, 0, m, &cVar_xoh5MjSo_sendMessage);
}

void Heavy_WSTD_DL3Y::cReceive_F9NO4DpG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_aCrUJC4g, 0, m, &cVar_aCrUJC4g_sendMessage);
}

void Heavy_WSTD_DL3Y::cReceive_1BLRzA3y_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_mMu9f0wv, 0, m, &cVar_mMu9f0wv_sendMessage);
}

void Heavy_WSTD_DL3Y::cReceive_zHY8N3Ma_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_GdGTBdXt, 0, m, &cVar_GdGTBdXt_sendMessage);
}

void Heavy_WSTD_DL3Y::cReceive_c8TSmwsE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_1j9C6T7s, 0, m, &cVar_1j9C6T7s_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_FyRMhvMg, 0, m, &cVar_FyRMhvMg_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_h9UYmtAg, 0, m, &cVar_h9UYmtAg_sendMessage);
}

void Heavy_WSTD_DL3Y::cReceive_pmlaqr8g_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_Bmzj1R8g_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cReceive_r0p3rraM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_vlxOBegH_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cReceive_Fkc8cpm1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_3XzBt4SQ_onMessage(_c, NULL, 0, m, NULL);
}




/*
 * Context Process Implementation
 */

int Heavy_WSTD_DL3Y::process(float **inputBuffers, float **outputBuffers, int n) {
  while (hLp_hasData(&inQueue)) {
    hv_uint32_t numBytes = 0;
    ReceiverMessagePair *p = reinterpret_cast<ReceiverMessagePair *>(hLp_getReadBuffer(&inQueue, &numBytes));
    hv_assert(numBytes >= sizeof(ReceiverMessagePair));
    scheduleMessageForReceiver(p->receiverHash, &p->msg);
    hLp_consume(&inQueue);
  }

  sendBangToReceiver(0xDD21C0EB); // send to __hv_bang~ on next cycle
  const int n4 = n & ~HV_N_SIMD_MASK; // ensure that the block size is a multiple of HV_N_SIMD

  // temporary signal vars
  hv_bufferf_t Bf0, Bf1, Bf2, Bf3, Bf4, Bf5, Bf6, Bf7, Bf8, Bf9, Bf10, Bf11, Bf12, Bf13;

  // input and output vars
  hv_bufferf_t O0, O1;
  hv_bufferf_t I0, I1;

  // declare and init the zero buffer
  hv_bufferf_t ZERO; __hv_zero_f(VOf(ZERO));

  hv_uint32_t nextBlock = blockStartTimestamp;
  for (int n = 0; n < n4; n += HV_N_SIMD) {

    // process all of the messages for this block
    nextBlock += HV_N_SIMD;
    while (mq_hasMessageBefore(&mq, nextBlock)) {
      MessageNode *const node = mq_peek(&mq);
      node->sendMessage(this, node->let, node->m);
      mq_pop(&mq);
    }

    // load input buffers
    __hv_load_f(inputBuffers[0]+n, VOf(I0));
    __hv_load_f(inputBuffers[1]+n, VOf(I1));

    // zero output buffers
    __hv_zero_f(VOf(O0));
    __hv_zero_f(VOf(O1));

    // process all signal functions
    __hv_line_f(&sLine_g1Eeh1gB, VOf(Bf0));
    __hv_line_f(&sLine_dRMCKDYR, VOf(Bf1));
    __hv_line_f(&sLine_T2Ni0VT3, VOf(Bf2));
    __hv_line_f(&sLine_gwJwwESa, VOf(Bf3));
    __hv_line_f(&sLine_8J90UdGH, VOf(Bf4));
    __hv_biquad_f(&sBiquad_s_NLEtRWeG, VIf(I0), VIf(Bf0), VIf(Bf1), VIf(Bf2), VIf(Bf3), VIf(Bf4), VOf(Bf4));
    __hv_varread_f(&sVarf_U6X8BmkL, VOf(Bf3));
    __hv_mul_f(VIf(Bf4), VIf(Bf3), VOf(Bf3));
    __hv_line_f(&sLine_6UHbdru9, VOf(Bf4));
    __hv_zero_f(VOf(Bf2));
    __hv_line_f(&sLine_bUbxW5n0, VOf(Bf1));
    __hv_line_f(&sLine_JPZ6pEbB, VOf(Bf0));
    __hv_line_f(&sLine_kAour652, VOf(Bf5));
    __hv_biquad_f(&sBiquad_s_frfqAQD7, VIf(I0), VIf(Bf4), VIf(Bf2), VIf(Bf1), VIf(Bf0), VIf(Bf5), VOf(Bf5));
    __hv_varread_f(&sVarf_viQfCm71, VOf(Bf0));
    __hv_mul_f(VIf(Bf5), VIf(Bf0), VOf(Bf0));
    __hv_line_f(&sLine_JSwJ1phT, VOf(Bf5));
    __hv_line_f(&sLine_NglVKMHx, VOf(Bf1));
    __hv_line_f(&sLine_fIqxGAS9, VOf(Bf2));
    __hv_line_f(&sLine_FHBvJrMg, VOf(Bf4));
    __hv_line_f(&sLine_ud6Hyy69, VOf(Bf6));
    __hv_biquad_f(&sBiquad_s_dSGD5xHe, VIf(I0), VIf(Bf5), VIf(Bf1), VIf(Bf2), VIf(Bf4), VIf(Bf6), VOf(Bf6));
    __hv_varread_f(&sVarf_dBidPBLo, VOf(Bf4));
    __hv_mul_f(VIf(Bf6), VIf(Bf4), VOf(Bf4));
    __hv_line_f(&sLine_HfB4ww6h, VOf(Bf6));
    __hv_line_f(&sLine_P76tzSnX, VOf(Bf2));
    __hv_line_f(&sLine_IZDVhOxw, VOf(Bf1));
    __hv_line_f(&sLine_ddG77Yei, VOf(Bf5));
    __hv_line_f(&sLine_kqeAIo9A, VOf(Bf7));
    __hv_biquad_f(&sBiquad_s_SEXiaiVy, VIf(I1), VIf(Bf6), VIf(Bf2), VIf(Bf1), VIf(Bf5), VIf(Bf7), VOf(Bf7));
    __hv_varread_f(&sVarf_F5JT6qfq, VOf(Bf5));
    __hv_mul_f(VIf(Bf7), VIf(Bf5), VOf(Bf5));
    __hv_line_f(&sLine_cOlEPnXL, VOf(Bf7));
    __hv_zero_f(VOf(Bf1));
    __hv_line_f(&sLine_JCe7ynWW, VOf(Bf2));
    __hv_line_f(&sLine_eczXoPdH, VOf(Bf6));
    __hv_line_f(&sLine_K1qlTqpL, VOf(Bf8));
    __hv_biquad_f(&sBiquad_s_JpYHwG6u, VIf(I1), VIf(Bf7), VIf(Bf1), VIf(Bf2), VIf(Bf6), VIf(Bf8), VOf(Bf8));
    __hv_varread_f(&sVarf_N6VtI5QJ, VOf(Bf6));
    __hv_mul_f(VIf(Bf8), VIf(Bf6), VOf(Bf6));
    __hv_line_f(&sLine_aa567uGa, VOf(Bf8));
    __hv_line_f(&sLine_UnkWnMXA, VOf(Bf2));
    __hv_line_f(&sLine_CzVHHzoo, VOf(Bf1));
    __hv_line_f(&sLine_cxRAF4cy, VOf(Bf7));
    __hv_line_f(&sLine_mm6FaRHO, VOf(Bf9));
    __hv_biquad_f(&sBiquad_s_lao49dND, VIf(I1), VIf(Bf8), VIf(Bf2), VIf(Bf1), VIf(Bf7), VIf(Bf9), VOf(Bf9));
    __hv_varread_f(&sVarf_Zu64IzXV, VOf(Bf7));
    __hv_mul_f(VIf(Bf9), VIf(Bf7), VOf(Bf7));
    __hv_line_f(&sLine_eLFeYyxW, VOf(Bf9));
    __hv_tabread_f(&sTabread_OvheTdEZ, VOf(Bf1));
    __hv_var_k_f(VOf(Bf2), 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f);
    __hv_min_f(VIf(Bf1), VIf(Bf2), VOf(Bf2));
    __hv_var_k_f(VOf(Bf8), -1.0f, -1.0f, -1.0f, -1.0f, -1.0f, -1.0f, -1.0f, -1.0f);
    __hv_max_f(VIf(Bf2), VIf(Bf8), VOf(Bf8));
    __hv_line_f(&sLine_euBMhtLL, VOf(Bf2));
    __hv_mul_f(VIf(Bf8), VIf(Bf2), VOf(Bf2));
    __hv_fma_f(VIf(Bf3), VIf(Bf9), VIf(Bf2), VOf(Bf2));
    __hv_line_f(&sLine_RbaTnMnt, VOf(Bf9));
    __hv_tabread_f(&sTabread_8ctWDKfL, VOf(Bf8));
    __hv_var_k_f(VOf(Bf10), 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f);
    __hv_min_f(VIf(Bf8), VIf(Bf10), VOf(Bf10));
    __hv_var_k_f(VOf(Bf11), -1.0f, -1.0f, -1.0f, -1.0f, -1.0f, -1.0f, -1.0f, -1.0f);
    __hv_max_f(VIf(Bf10), VIf(Bf11), VOf(Bf11));
    __hv_line_f(&sLine_hPgrwyT6, VOf(Bf10));
    __hv_mul_f(VIf(Bf11), VIf(Bf10), VOf(Bf10));
    __hv_fma_f(VIf(Bf5), VIf(Bf9), VIf(Bf10), VOf(Bf10));
    __hv_varread_f(&sVarf_NVhxYz17, VOf(Bf9));
    __hv_add_f(VIf(Bf3), VIf(Bf9), VOf(Bf9));
    __hv_varread_f(&sVarf_xEsqNN4C, VOf(Bf3));
    __hv_rpole_f(&sRPole_aaMuvHMy, VIf(Bf9), VIf(Bf3), VOf(Bf3));
    __hv_var_k_f(VOf(Bf9), 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f);
    __hv_del1_f(&sDel1_IbnpKMBv, VIf(Bf3), VOf(Bf11));
    __hv_mul_f(VIf(Bf11), VIf(Bf9), VOf(Bf9));
    __hv_sub_f(VIf(Bf3), VIf(Bf9), VOf(Bf9));
    __hv_varread_f(&sVarf_3iu4WzHj, VOf(Bf3));
    __hv_mul_f(VIf(Bf9), VIf(Bf3), VOf(Bf3));
    __hv_tabwrite_f(&sTabwrite_s0NMdATY, VIf(Bf3));
    __hv_varread_f(&sVarf_hKKheQna, VOf(Bf3));
    __hv_add_f(VIf(Bf5), VIf(Bf3), VOf(Bf3));
    __hv_varread_f(&sVarf_dl1kc3ny, VOf(Bf5));
    __hv_rpole_f(&sRPole_tnEYFDVv, VIf(Bf3), VIf(Bf5), VOf(Bf5));
    __hv_var_k_f(VOf(Bf3), 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f);
    __hv_del1_f(&sDel1_ycaVuyAu, VIf(Bf5), VOf(Bf9));
    __hv_mul_f(VIf(Bf9), VIf(Bf3), VOf(Bf3));
    __hv_sub_f(VIf(Bf5), VIf(Bf3), VOf(Bf3));
    __hv_varread_f(&sVarf_k6pZXZGP, VOf(Bf5));
    __hv_mul_f(VIf(Bf3), VIf(Bf5), VOf(Bf5));
    __hv_tabwrite_f(&sTabwrite_lvfmg2UE, VIf(Bf5));
    __hv_varread_f(&sVarf_gSHCHyqD, VOf(Bf5));
    __hv_mul_f(VIf(Bf1), VIf(Bf5), VOf(Bf5));
    __hv_line_f(&sLine_OwNXV51q, VOf(Bf1));
    __hv_varread_f(&sVarf_iYK4SP5L, VOf(Bf3));
    __hv_mul_f(VIf(Bf8), VIf(Bf3), VOf(Bf3));
    __hv_line_f(&sLine_G1Bc92pM, VOf(Bf8));
    __hv_mul_f(VIf(Bf3), VIf(Bf8), VOf(Bf8));
    __hv_fma_f(VIf(Bf5), VIf(Bf1), VIf(Bf8), VOf(Bf8));
    __hv_varread_f(&sVarf_yby2x6zV, VOf(Bf1));
    __hv_varread_f(&sVarf_jlEX39WW, VOf(Bf9));
    __hv_mul_f(VIf(Bf1), VIf(Bf9), VOf(Bf9));
    __hv_varread_f(&sVarf_XqzjSTPr, VOf(Bf1));
    __hv_rpole_f(&sRPole_lY5EPS25, VIf(Bf9), VIf(Bf1), VOf(Bf1));
    __hv_mul_f(VIf(Bf8), VIf(Bf1), VOf(Bf1));
    sEnv_process(this, &sEnv_SwBoBkWr, VIf(Bf8), &sEnv_SwBoBkWr_sendMessage);
    __hv_varread_f(&sVarf_uBA11AWp, VOf(Bf8));
    __hv_mul_f(VIf(Bf1), VIf(Bf8), VOf(Bf8));
    __hv_varread_f(&sVarf_dUh8nEid, VOf(Bf1));
    __hv_rpole_f(&sRPole_L5uNfqq9, VIf(Bf8), VIf(Bf1), VOf(Bf1));
    __hv_varwrite_f(&sVarf_NVhxYz17, VIf(Bf1));
    __hv_line_f(&sLine_vdZxpvBo, VOf(Bf1));
    __hv_line_f(&sLine_JRRCuPP3, VOf(Bf8));
    __hv_mul_f(VIf(Bf5), VIf(Bf8), VOf(Bf8));
    __hv_fma_f(VIf(Bf3), VIf(Bf1), VIf(Bf8), VOf(Bf8));
    __hv_varread_f(&sVarf_hOdtiHRZ, VOf(Bf1));
    __hv_varread_f(&sVarf_xWHUFUGs, VOf(Bf3));
    __hv_mul_f(VIf(Bf1), VIf(Bf3), VOf(Bf3));
    __hv_varread_f(&sVarf_l5xzyGnw, VOf(Bf1));
    __hv_rpole_f(&sRPole_nXld12uL, VIf(Bf3), VIf(Bf1), VOf(Bf1));
    __hv_mul_f(VIf(Bf8), VIf(Bf1), VOf(Bf1));
    sEnv_process(this, &sEnv_0GawZaWN, VIf(Bf8), &sEnv_0GawZaWN_sendMessage);
    __hv_varread_f(&sVarf_ffUJFP7F, VOf(Bf8));
    __hv_mul_f(VIf(Bf1), VIf(Bf8), VOf(Bf8));
    __hv_varread_f(&sVarf_nTEgW7ey, VOf(Bf1));
    __hv_rpole_f(&sRPole_noyK0DU5, VIf(Bf8), VIf(Bf1), VOf(Bf1));
    __hv_varwrite_f(&sVarf_hKKheQna, VIf(Bf1));
    __hv_varwrite_f(&sVarf_jMT5o4VC, VIf(Bf2));
    __hv_varread_f(&sVarf_sIxCYBr1, VOf(Bf2));
    __hv_varread_f(&sVarf_rLTRQHs7, VOf(Bf1));
    __hv_line_f(&sLine_UlqhqerW, VOf(Bf8));
    __hv_tabread_f(&sTabread_b1wGD1vP, VOf(Bf3));
    __hv_var_k_f(VOf(Bf5), 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f);
    __hv_min_f(VIf(Bf3), VIf(Bf5), VOf(Bf5));
    __hv_var_k_f(VOf(Bf9), -1.0f, -1.0f, -1.0f, -1.0f, -1.0f, -1.0f, -1.0f, -1.0f);
    __hv_max_f(VIf(Bf5), VIf(Bf9), VOf(Bf9));
    __hv_line_f(&sLine_muo0BVHG, VOf(Bf5));
    __hv_mul_f(VIf(Bf9), VIf(Bf5), VOf(Bf5));
    __hv_fma_f(VIf(Bf2), VIf(Bf8), VIf(Bf5), VOf(Bf5));
    __hv_line_f(&sLine_t1mUprca, VOf(Bf8));
    __hv_tabread_f(&sTabread_4cuL5DVh, VOf(Bf9));
    __hv_var_k_f(VOf(Bf11), 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f);
    __hv_min_f(VIf(Bf9), VIf(Bf11), VOf(Bf11));
    __hv_var_k_f(VOf(Bf12), -1.0f, -1.0f, -1.0f, -1.0f, -1.0f, -1.0f, -1.0f, -1.0f);
    __hv_max_f(VIf(Bf11), VIf(Bf12), VOf(Bf12));
    __hv_line_f(&sLine_oVRlatCU, VOf(Bf11));
    __hv_mul_f(VIf(Bf12), VIf(Bf11), VOf(Bf11));
    __hv_fma_f(VIf(Bf1), VIf(Bf8), VIf(Bf11), VOf(Bf11));
    __hv_varread_f(&sVarf_u0KSG9uV, VOf(Bf8));
    __hv_add_f(VIf(Bf2), VIf(Bf8), VOf(Bf8));
    __hv_varread_f(&sVarf_1ElL27q5, VOf(Bf2));
    __hv_rpole_f(&sRPole_cs0Qpin6, VIf(Bf8), VIf(Bf2), VOf(Bf2));
    __hv_var_k_f(VOf(Bf8), 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f);
    __hv_del1_f(&sDel1_iQAiFrXd, VIf(Bf2), VOf(Bf12));
    __hv_mul_f(VIf(Bf12), VIf(Bf8), VOf(Bf8));
    __hv_sub_f(VIf(Bf2), VIf(Bf8), VOf(Bf8));
    __hv_varread_f(&sVarf_V9cyL1XR, VOf(Bf2));
    __hv_mul_f(VIf(Bf8), VIf(Bf2), VOf(Bf2));
    __hv_tabwrite_f(&sTabwrite_x8DvrhQE, VIf(Bf2));
    __hv_varread_f(&sVarf_k2DDlCUJ, VOf(Bf2));
    __hv_add_f(VIf(Bf1), VIf(Bf2), VOf(Bf2));
    __hv_varread_f(&sVarf_yBncRYaA, VOf(Bf1));
    __hv_rpole_f(&sRPole_lzswIGnQ, VIf(Bf2), VIf(Bf1), VOf(Bf1));
    __hv_var_k_f(VOf(Bf2), 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f);
    __hv_del1_f(&sDel1_rcLM0Ghv, VIf(Bf1), VOf(Bf8));
    __hv_mul_f(VIf(Bf8), VIf(Bf2), VOf(Bf2));
    __hv_sub_f(VIf(Bf1), VIf(Bf2), VOf(Bf2));
    __hv_varread_f(&sVarf_3Ko9rKiv, VOf(Bf1));
    __hv_mul_f(VIf(Bf2), VIf(Bf1), VOf(Bf1));
    __hv_tabwrite_f(&sTabwrite_fflxi6Am, VIf(Bf1));
    __hv_varread_f(&sVarf_Lcyy7tnU, VOf(Bf1));
    __hv_mul_f(VIf(Bf3), VIf(Bf1), VOf(Bf1));
    __hv_line_f(&sLine_2v2GHjZf, VOf(Bf3));
    __hv_varread_f(&sVarf_gnF6iaaJ, VOf(Bf2));
    __hv_mul_f(VIf(Bf9), VIf(Bf2), VOf(Bf2));
    __hv_line_f(&sLine_Tt7JyTOM, VOf(Bf9));
    __hv_mul_f(VIf(Bf2), VIf(Bf9), VOf(Bf9));
    __hv_fma_f(VIf(Bf1), VIf(Bf3), VIf(Bf9), VOf(Bf9));
    __hv_varread_f(&sVarf_Eo4faav9, VOf(Bf3));
    __hv_varread_f(&sVarf_baK4BTOb, VOf(Bf8));
    __hv_mul_f(VIf(Bf3), VIf(Bf8), VOf(Bf8));
    __hv_varread_f(&sVarf_WlPiwc27, VOf(Bf3));
    __hv_rpole_f(&sRPole_UnYXAxfa, VIf(Bf8), VIf(Bf3), VOf(Bf3));
    __hv_mul_f(VIf(Bf9), VIf(Bf3), VOf(Bf3));
    sEnv_process(this, &sEnv_uJDcVDjK, VIf(Bf9), &sEnv_uJDcVDjK_sendMessage);
    __hv_varread_f(&sVarf_b3kgBa2g, VOf(Bf9));
    __hv_mul_f(VIf(Bf3), VIf(Bf9), VOf(Bf9));
    __hv_varread_f(&sVarf_mAgcoTuU, VOf(Bf3));
    __hv_rpole_f(&sRPole_GUXcdVuZ, VIf(Bf9), VIf(Bf3), VOf(Bf3));
    __hv_varwrite_f(&sVarf_u0KSG9uV, VIf(Bf3));
    __hv_line_f(&sLine_uvhU7sbN, VOf(Bf3));
    __hv_line_f(&sLine_8EwDxbaK, VOf(Bf9));
    __hv_mul_f(VIf(Bf1), VIf(Bf9), VOf(Bf9));
    __hv_fma_f(VIf(Bf2), VIf(Bf3), VIf(Bf9), VOf(Bf9));
    __hv_varread_f(&sVarf_0bdC8Nar, VOf(Bf3));
    __hv_varread_f(&sVarf_5SPkAxKc, VOf(Bf2));
    __hv_mul_f(VIf(Bf3), VIf(Bf2), VOf(Bf2));
    __hv_varread_f(&sVarf_HRTpzk5m, VOf(Bf3));
    __hv_rpole_f(&sRPole_0rKIX4pY, VIf(Bf2), VIf(Bf3), VOf(Bf3));
    __hv_mul_f(VIf(Bf9), VIf(Bf3), VOf(Bf3));
    sEnv_process(this, &sEnv_ja9lRYb7, VIf(Bf9), &sEnv_ja9lRYb7_sendMessage);
    __hv_varread_f(&sVarf_LtVWp1zn, VOf(Bf9));
    __hv_mul_f(VIf(Bf3), VIf(Bf9), VOf(Bf9));
    __hv_varread_f(&sVarf_flRydUO5, VOf(Bf3));
    __hv_rpole_f(&sRPole_qYDgP8Sf, VIf(Bf9), VIf(Bf3), VOf(Bf3));
    __hv_varwrite_f(&sVarf_k2DDlCUJ, VIf(Bf3));
    __hv_varwrite_f(&sVarf_L0ppEIO2, VIf(Bf5));
    __hv_varread_f(&sVarf_c5i95c52, VOf(Bf5));
    __hv_varread_f(&sVarf_a4gsN194, VOf(Bf3));
    __hv_line_f(&sLine_ATUTJXY6, VOf(Bf9));
    __hv_tabread_f(&sTabread_Q6OSucNZ, VOf(Bf2));
    __hv_var_k_f(VOf(Bf1), 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f);
    __hv_min_f(VIf(Bf2), VIf(Bf1), VOf(Bf1));
    __hv_var_k_f(VOf(Bf8), -1.0f, -1.0f, -1.0f, -1.0f, -1.0f, -1.0f, -1.0f, -1.0f);
    __hv_max_f(VIf(Bf1), VIf(Bf8), VOf(Bf8));
    __hv_line_f(&sLine_Ow5hPZrK, VOf(Bf1));
    __hv_mul_f(VIf(Bf8), VIf(Bf1), VOf(Bf1));
    __hv_fma_f(VIf(Bf5), VIf(Bf9), VIf(Bf1), VOf(Bf1));
    __hv_line_f(&sLine_ssh1ghQY, VOf(Bf9));
    __hv_tabread_f(&sTabread_tH4bhOve, VOf(Bf8));
    __hv_var_k_f(VOf(Bf12), 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f);
    __hv_min_f(VIf(Bf8), VIf(Bf12), VOf(Bf12));
    __hv_var_k_f(VOf(Bf13), -1.0f, -1.0f, -1.0f, -1.0f, -1.0f, -1.0f, -1.0f, -1.0f);
    __hv_max_f(VIf(Bf12), VIf(Bf13), VOf(Bf13));
    __hv_line_f(&sLine_3GArsV0h, VOf(Bf12));
    __hv_mul_f(VIf(Bf13), VIf(Bf12), VOf(Bf12));
    __hv_fma_f(VIf(Bf3), VIf(Bf9), VIf(Bf12), VOf(Bf12));
    __hv_varread_f(&sVarf_vm1zqRYb, VOf(Bf9));
    __hv_add_f(VIf(Bf5), VIf(Bf9), VOf(Bf9));
    __hv_varread_f(&sVarf_sJ4hmV62, VOf(Bf5));
    __hv_rpole_f(&sRPole_0oEwLLmh, VIf(Bf9), VIf(Bf5), VOf(Bf5));
    __hv_var_k_f(VOf(Bf9), 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f);
    __hv_del1_f(&sDel1_f7rrKIHA, VIf(Bf5), VOf(Bf13));
    __hv_mul_f(VIf(Bf13), VIf(Bf9), VOf(Bf9));
    __hv_sub_f(VIf(Bf5), VIf(Bf9), VOf(Bf9));
    __hv_varread_f(&sVarf_p0k0jAkU, VOf(Bf5));
    __hv_mul_f(VIf(Bf9), VIf(Bf5), VOf(Bf5));
    __hv_tabwrite_f(&sTabwrite_S3IcX84y, VIf(Bf5));
    __hv_varread_f(&sVarf_gs54m2SV, VOf(Bf5));
    __hv_add_f(VIf(Bf3), VIf(Bf5), VOf(Bf5));
    __hv_varread_f(&sVarf_xzFkSdKT, VOf(Bf3));
    __hv_rpole_f(&sRPole_BgG4PXsF, VIf(Bf5), VIf(Bf3), VOf(Bf3));
    __hv_var_k_f(VOf(Bf5), 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f);
    __hv_del1_f(&sDel1_Jr9Eb9lB, VIf(Bf3), VOf(Bf9));
    __hv_mul_f(VIf(Bf9), VIf(Bf5), VOf(Bf5));
    __hv_sub_f(VIf(Bf3), VIf(Bf5), VOf(Bf5));
    __hv_varread_f(&sVarf_LIaZ958w, VOf(Bf3));
    __hv_mul_f(VIf(Bf5), VIf(Bf3), VOf(Bf3));
    __hv_tabwrite_f(&sTabwrite_KKGLprdo, VIf(Bf3));
    __hv_varread_f(&sVarf_fSuzIh6O, VOf(Bf3));
    __hv_mul_f(VIf(Bf2), VIf(Bf3), VOf(Bf3));
    __hv_line_f(&sLine_Qzr4di1X, VOf(Bf2));
    __hv_varread_f(&sVarf_tmovl8yk, VOf(Bf5));
    __hv_mul_f(VIf(Bf8), VIf(Bf5), VOf(Bf5));
    __hv_line_f(&sLine_QahjCNHW, VOf(Bf8));
    __hv_mul_f(VIf(Bf5), VIf(Bf8), VOf(Bf8));
    __hv_fma_f(VIf(Bf3), VIf(Bf2), VIf(Bf8), VOf(Bf8));
    __hv_varread_f(&sVarf_mwyiqzaM, VOf(Bf2));
    __hv_varread_f(&sVarf_dntFmCh2, VOf(Bf9));
    __hv_mul_f(VIf(Bf2), VIf(Bf9), VOf(Bf9));
    __hv_varread_f(&sVarf_rW7IPVUz, VOf(Bf2));
    __hv_rpole_f(&sRPole_NBnWi4tZ, VIf(Bf9), VIf(Bf2), VOf(Bf2));
    __hv_mul_f(VIf(Bf8), VIf(Bf2), VOf(Bf2));
    sEnv_process(this, &sEnv_bJMBGZcx, VIf(Bf8), &sEnv_bJMBGZcx_sendMessage);
    __hv_varread_f(&sVarf_wAU5nXlk, VOf(Bf8));
    __hv_mul_f(VIf(Bf2), VIf(Bf8), VOf(Bf8));
    __hv_varread_f(&sVarf_gILdzuMN, VOf(Bf2));
    __hv_rpole_f(&sRPole_cU4dtgDg, VIf(Bf8), VIf(Bf2), VOf(Bf2));
    __hv_varwrite_f(&sVarf_vm1zqRYb, VIf(Bf2));
    __hv_line_f(&sLine_NLvvwlFB, VOf(Bf2));
    __hv_line_f(&sLine_fqNIJPDm, VOf(Bf8));
    __hv_mul_f(VIf(Bf3), VIf(Bf8), VOf(Bf8));
    __hv_fma_f(VIf(Bf5), VIf(Bf2), VIf(Bf8), VOf(Bf8));
    __hv_varread_f(&sVarf_qwsBeSut, VOf(Bf2));
    __hv_varread_f(&sVarf_AKDAFGCy, VOf(Bf5));
    __hv_mul_f(VIf(Bf2), VIf(Bf5), VOf(Bf5));
    __hv_varread_f(&sVarf_pZlC9evG, VOf(Bf2));
    __hv_rpole_f(&sRPole_0EO40lMc, VIf(Bf5), VIf(Bf2), VOf(Bf2));
    __hv_mul_f(VIf(Bf8), VIf(Bf2), VOf(Bf2));
    sEnv_process(this, &sEnv_njcGyCDv, VIf(Bf8), &sEnv_njcGyCDv_sendMessage);
    __hv_varread_f(&sVarf_gZP578zs, VOf(Bf8));
    __hv_mul_f(VIf(Bf2), VIf(Bf8), VOf(Bf8));
    __hv_varread_f(&sVarf_MF4FOrg4, VOf(Bf2));
    __hv_rpole_f(&sRPole_7xAjvKYI, VIf(Bf8), VIf(Bf2), VOf(Bf2));
    __hv_varwrite_f(&sVarf_gs54m2SV, VIf(Bf2));
    __hv_varwrite_f(&sVarf_X9quEZW0, VIf(Bf1));
    __hv_varwrite_f(&sVarf_L5N4XZnL, VIf(Bf10));
    __hv_varwrite_f(&sVarf_Ibt1zOG8, VIf(Bf11));
    __hv_varwrite_f(&sVarf_9LIAhPDt, VIf(Bf12));
    __hv_varwrite_f(&sVarf_sIxCYBr1, VIf(Bf0));
    __hv_varwrite_f(&sVarf_rLTRQHs7, VIf(Bf6));
    __hv_varwrite_f(&sVarf_c5i95c52, VIf(Bf4));
    __hv_varwrite_f(&sVarf_a4gsN194, VIf(Bf7));
    __hv_varread_f(&sVarf_L5N4XZnL, VOf(Bf7));
    __hv_varread_f(&sVarf_Ibt1zOG8, VOf(Bf4));
    __hv_varread_f(&sVarf_9LIAhPDt, VOf(Bf6));
    __hv_add_f(VIf(Bf4), VIf(Bf6), VOf(Bf6));
    __hv_add_f(VIf(Bf7), VIf(Bf6), VOf(Bf6));
    __hv_add_f(VIf(Bf6), VIf(O1), VOf(O1));
    __hv_varread_f(&sVarf_jMT5o4VC, VOf(Bf6));
    __hv_varread_f(&sVarf_L0ppEIO2, VOf(Bf7));
    __hv_varread_f(&sVarf_X9quEZW0, VOf(Bf4));
    __hv_add_f(VIf(Bf7), VIf(Bf4), VOf(Bf4));
    __hv_add_f(VIf(Bf6), VIf(Bf4), VOf(Bf4));
    __hv_add_f(VIf(Bf4), VIf(O0), VOf(O0));

    // save output vars to output buffer
    __hv_store_f(outputBuffers[0]+n, VIf(O0));
    __hv_store_f(outputBuffers[1]+n, VIf(O1));
  }

  blockStartTimestamp = nextBlock;

  return n4; // return the number of frames processed

}

int Heavy_WSTD_DL3Y::processInline(float *inputBuffers, float *outputBuffers, int n4) {
  hv_assert(!(n4 & HV_N_SIMD_MASK)); // ensure that n4 is a multiple of HV_N_SIMD

  // define the heavy input buffer for 2 channel(s)
  float **const bIn = reinterpret_cast<float **>(hv_alloca(2*sizeof(float *)));
  bIn[0] = inputBuffers+(0*n4);
  bIn[1] = inputBuffers+(1*n4);

  // define the heavy output buffer for 2 channel(s)
  float **const bOut = reinterpret_cast<float **>(hv_alloca(2*sizeof(float *)));
  bOut[0] = outputBuffers+(0*n4);
  bOut[1] = outputBuffers+(1*n4);

  int n = process(bIn, bOut, n4);
  return n;
}

int Heavy_WSTD_DL3Y::processInlineInterleaved(float *inputBuffers, float *outputBuffers, int n4) {
  hv_assert(n4 & ~HV_N_SIMD_MASK); // ensure that n4 is a multiple of HV_N_SIMD

  // define the heavy input buffer for 2 channel(s), uninterleave
  float *const bIn = reinterpret_cast<float *>(hv_alloca(2*n4*sizeof(float)));
  #if HV_SIMD_SSE || HV_SIMD_AVX
  for (int i = 0, j = 0; j < n4; j += 4, i += 8) {
    __m128 a = _mm_load_ps(inputBuffers+i);                // LRLR
    __m128 b = _mm_load_ps(inputBuffers+4+i);              // LRLR
    __m128 x = _mm_shuffle_ps(a, b, _MM_SHUFFLE(2,0,2,0)); // LLLL
    __m128 y = _mm_shuffle_ps(a, b, _MM_SHUFFLE(3,1,3,1)); // RRRR
    _mm_store_ps(bIn+j, x);
    _mm_store_ps(bIn+n4+j, y);
  }
  #elif HV_SIMD_NEON
  for (int i = 0, j = 0; j < n4; j += 4, i += 8) {
    float32x4x2_t a = vld2q_f32(inputBuffers+i); // load and uninterleave
    vst1q_f32(bIn+j, a.val[0]);
    vst1q_f32(bIn+n4+j, a.val[1]);
  }
  #else // HV_SIMD_NONE
  for (int j = 0; j < n4; ++j) {
    bIn[0*n4+j] = inputBuffers[0+2*j];
    bIn[1*n4+j] = inputBuffers[1+2*j];
  }
  #endif

  // define the heavy output buffer for 2 channel(s)
  float *const bOut = reinterpret_cast<float *>(hv_alloca(2*n4*sizeof(float)));

  int n = processInline(bIn, bOut, n4);

  // interleave the heavy output into the output buffer
  #if HV_SIMD_AVX
  for (int i = 0, j = 0; j < n4; j += 8, i += 16) {
    __m256 x = _mm256_load_ps(bOut+j);    // LLLLLLLL
    __m256 y = _mm256_load_ps(bOut+n4+j); // RRRRRRRR
    __m256 a = _mm256_unpacklo_ps(x, y);  // LRLRLRLR
    __m256 b = _mm256_unpackhi_ps(x, y);  // LRLRLRLR
    _mm256_store_ps(outputBuffers+i, a);
    _mm256_store_ps(outputBuffers+8+i, b);
  }
  #elif HV_SIMD_SSE
  for (int i = 0, j = 0; j < n4; j += 4, i += 8) {
    __m128 x = _mm_load_ps(bOut+j);    // LLLL
    __m128 y = _mm_load_ps(bOut+n4+j); // RRRR
    __m128 a = _mm_unpacklo_ps(x, y);  // LRLR
    __m128 b = _mm_unpackhi_ps(x, y);  // LRLR
    _mm_store_ps(outputBuffers+i, a);
    _mm_store_ps(outputBuffers+4+i, b);
  }
  #elif HV_SIMD_NEON
  // https://community.arm.com/groups/processors/blog/2012/03/13/coding-for-neon--part-5-rearranging-vectors
  for (int i = 0, j = 0; j < n4; j += 4, i += 8) {
    float32x4_t x = vld1q_f32(bOut+j);
    float32x4_t y = vld1q_f32(bOut+n4+j);
    float32x4x2_t z = {x, y};
    vst2q_f32(outputBuffers+i, z); // interleave and store
  }
  #else // HV_SIMD_NONE
  for (int i = 0; i < 2; ++i) {
    for (int j = 0; j < n4; ++j) {
      outputBuffers[i+2*j] = bOut[i*n4+j];
    }
  }
  #endif

  return n;
}
